MapWindow = class(Turbine.UI.Window)

function MapWindow:Constructor()
	self.scale = 1.7
	local width = 1024 / self.scale
	local height = (768 + 16) / self.scale

	self.min_s = 10
	self.max_s = 22
	self.dif_s = self.max_s - self.min_s
	self.min_w = 8.2
	self.max_w = 24.3
	self.dif_w = self.max_w - self.min_w
	self.heading = 0

	Turbine.UI.Window.Constructor(self)

	self:SetSize(width, height)
	self:SetPosition(data.numbers.mapWin_x, data.numbers.mapWin_y)
	self:SetZOrder(1)
	self:SetWantsKeyEvents(true)
	self:SetMouseVisible(false)

	self.DragBar = DragBar(self, L.Map)

	self.map = Turbine.UI.Control()
	self.map:SetParent(self)
	self.map:SetSize(1024, 768)
	self.map:SetBackground(0x41008133)
	self.map:SetStretchMode(1)
	self.map:SetSize(self:GetWidth(), self:GetHeight() - 16)
	self.map:SetTop(16)
	self.map:SetMouseVisible(false)

	-- Position arrow on map
	self.LocationIcon = Turbine.UI.Window()
	self.LocationIcon:SetParent(self.map)
	self.LocationIcon:SetSize(28, 28)
	self.LocationIcon:SetBackground(0x41007f4c)
	self.LocationIcon:SetZOrder(1)
	self.LocationIcon:SetMouseVisible(false)

	self.LocationContainer = Turbine.UI.Control()
	self.LocationContainer:SetParent(self)
	self.LocationContainer:SetStretchMode(3)
	self.LocationContainer:SetSize(138, 31)
	self.LocationContainer:SetPosition(
		self:GetWidth() - self.LocationContainer:GetWidth() - 30,
		self:GetHeight() - self.LocationContainer:GetHeight() - 20
	)

	self.LocationQuickSlot = Turbine.UI.Lotro.Quickslot()
	self.LocationQuickSlot:SetParent(self.LocationContainer)
	self.LocationQuickSlot:SetSize(self.LocationContainer:GetSize())
	self.LocationQuickSlot:SetShortcut(Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, L.Loc))
	self.LocationQuickSlot:SetAllowDrop(false)

	self.LocationOverlay = Turbine.UI.Label()
	self.LocationOverlay:SetParent(self.LocationContainer)
	self.LocationOverlay:SetSize(self.LocationContainer:GetSize())
	self.LocationOverlay:SetForeColor(default_font_color)
	self.LocationOverlay:SetFont(Turbine.UI.Lotro.Font.TrajanPro14)
	self.LocationOverlay:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.LocationOverlay:SetBackground(0x4110932c)
	self.LocationOverlay:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.LocationOverlay:SetText(L.GetOwnPosition)
	self.LocationOverlay:SetMouseVisible(false)

	self.keeps = {}
	self.ports = {}
	self.enemyPositions = {}
	self.hotspots = {}

	local Keep_Positions = {
		[1] = { ["s"] = 16.6, ["w"] = 17.3 }, -- Tol Ascarnen
		[2] = { ["s"] = 11.7, ["w"] = 15.3 }, -- Isendeep Mine
		[3] = { ["s"] = 17.6, ["w"] = 14.5 }, -- Tirith Rhaw
		[4] = { ["s"] = 15.4, ["w"] = 20.1 }, -- Lugazag
		[5] = { ["s"] = 19.3, ["w"] = 17.5 }, -- Grimwood Lumber Camp
		[6] = { ["s"] = 19.9, ["w"] = 19.3 }, -- Hithlad Outpost
		[7] = { ["s"] = 13.4, ["w"] = 14.6 }, -- Arador's End Outpost
		[8] = { ["s"] = 18.4, ["w"] = 20.1 }, -- River Outpost
		[9] = { ["s"] = 14.5, ["w"] = 16.2 }  -- Isendeep Outpost
	}

	for index, position in pairs(Keep_Positions) do
		self.keeps[index] = Turbine.UI.Control()
		self.keeps[index]:SetParent(self.map)
		self.keeps[index]:SetSize(32, 32)
		self.keeps[index]:SetStretchMode(1)
		self.keeps[index]:SetPosition(
			(self.map:GetWidth() - self.map:GetWidth() * (position.w - self.min_w) / self.dif_w -
				self.scale * self.keeps[index]:GetWidth() / 2),
			(self.map:GetHeight() * (position.s - self.min_s) / self.dif_s - self.scale * self.keeps[index]:GetHeight() / 2)
		)
		self.keeps[index]:SetMouseVisible(false)
	end

	local Hotspot_Positions = {
		[1] = { ["s"] = 12.2, ["w"] = 20.9 }, -- Gramsfoot
		[2] = { ["s"] = 20.3, ["w"] = 13.7 }, -- Glân Vraig
		[3] = { ["s"] = 17.0, ["w"] = 22.4 }, -- Dâr-gazag
		[4] = { ["s"] = 17.0, ["w"] = 19.8 }, -- Elf Camp
		[5] = { ["s"] = 19.8, ["w"] = 20.0 }, -- Hoarhallow
		[6] = { ["s"] = 13.0, ["w"] = 12.7 }, -- Grothum
		[7] = { ["s"] = 15.8, ["w"] = 15.2 }, -- Orc Camp
		[8] = { ["s"] = 16.0, ["w"] = 12.2 }  -- Ost Ringdyr
	}

	for index, position in pairs(Hotspot_Positions) do
		self.hotspots[index] = Turbine.UI.Control()
		self.hotspots[index]:SetParent(self.map)
		self.hotspots[index]:SetSize(30, 30)
		self.hotspots[index]:SetStretchMode(1)
		self.hotspots[index]:SetPosition(
			(self.map:GetWidth() - self.map:GetWidth() * (position.w - self.min_w) / self.dif_w -
				self.scale * self.hotspots[index]:GetWidth() / 2),
			(self.map:GetHeight() * (position.s - self.min_s) / self.dif_s - self.scale * self.hotspots[index]:GetHeight() / 2)
		)
		self.hotspots[index]:SetMouseVisible(false)
	end

	if (Turbine.Gameplay.LocalPlayer.GetInstance():GetAlignment() == Turbine.Gameplay.Alignment.MonsterPlayer) then -- Comment this + end for map skills to show for freeps.
		local Port_Positions = {
			[1] = { ["skill"] = 0x70028BC1, ["s"] = 12.34790, ["w"] = 20.88785 },  -- Gramsfoot
			[2] = { ["skill"] = 0x70028BB7, ["s"] = 16.12355, ["w"] = 20.93480 },  -- Crude Lugazag
			[3] = { ["skill"] = 0x70028BB6, ["s"] = 17.09615, ["w"] = 18.60115 },  -- Crude Tol Ascarnen
			[4] = { ["skill"] = 0x70028BBE, ["s"] = 14.63295, ["w"] = 15.78155 },  -- Crude Tirith Rhaw
			[5] = { ["skill"] = 0x70028BB3, ["s"] = 13.39115, ["w"] = 12.78555 },  -- Crude Isendeep Mine
			[6] = { ["skill"] = 0x70028BBF, ["s"] = 18.33575, ["w"] = 18.55405 },  -- Crude Grimwood Lumber Camp
			[7] = { ["skill"] = 0x70028BB2, ["s"] = 14.15050, ["w"] = 20.95640 },  -- Poor Lugazag
			[8] = { ["skill"] = 0x70028BB1, ["s"] = 15.96070, ["w"] = 17.03575 },  -- Poor Tol Ascarnen
			[9] = { ["skill"] = 0x70028BB4, ["s"] = 15.69550, ["w"] = 14.21880 },  -- Poor Tirith Rhaw
			[10] = { ["skill"] = 0x70028BAF, ["s"] = 14.69335, ["w"] = 14.51080 }, -- Poor Isendeep Mine
			[11] = { ["skill"] = 0x70028BB9, ["s"] = 18.85365, ["w"] = 17.94950 }, -- Poor Grimwood Lumber Camp
			[12] = { ["skill"] = 0x70028BB5, ["s"] = 14.53930, ["w"] = 19.07175 }, -- Good Lugazag
			[13] = { ["skill"] = 0x70028BC2, ["s"] = 17.93365, ["w"] = 18.12165 }, -- Good Tol Ascarnen
			[14] = { ["skill"] = 0x70028BB0, ["s"] = 17.84660, ["w"] = 15.33165 }, -- Good Tirith Rhaw
			[15] = { ["skill"] = 0x70028BC0, ["s"] = 11.51970, ["w"] = 19.09745 }, -- Good Isendeep Mine
			[16] = { ["skill"] = 0x70028BBD, ["s"] = 20.34595, ["w"] = 16.82680 }  -- Good Grimwood Lumber Camp
		}

		for index, map in pairs(Port_Positions) do
			self.ports[index] = Turbine.UI.Control()
			self.ports[index]:SetParent(self.map)

			local qs = Turbine.UI.Lotro.Quickslot()
			qs:SetParent(self.ports[index])
			qs:SetSize(self.ports[index]:GetSize())
			qs:SetShortcut(Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Skill, string.format("0x%x", map.skill)))
			qs:SetAllowDrop(false)

			qs.MouseDown = function(sender, args)
				if args.Button == Turbine.UI.MouseButton.Right then
					self:SetVisible(false)
					SecondaryWindow.showhide:SetText(L.ShowMap)
				end
			end

			qs.MouseUp = function(sender, args)
				if args.Button == Turbine.UI.MouseButton.Left then
					self:SetVisible(false)
					SecondaryWindow.showhide:SetText(L.ShowMap)
				end
			end

			if Turbine.Gameplay.LocalPlayer.GetInstance():GetAlignment() == Turbine.Gameplay.Alignment.MonsterPlayer then
				self.ports[index]:SetSize(35, 35)
			else
				self.ports[index]:SetSize(17, 17)
			end

			self.ports[index]:SetStretchMode(1)
			self.ports[index]:SetPosition(
				(self.map:GetWidth() - self.map:GetWidth() * (map.w - self.min_w) / self.dif_w -
					self.scale * self.ports[index]:GetWidth() / 2),
				(self.map:GetHeight() * (map.s - self.min_s) / self.dif_s - self.scale * self.ports[index]:GetHeight() / 2)
			)

			if Turbine.Gameplay.LocalPlayer.GetInstance():GetAlignment() == Turbine.Gameplay.Alignment.FreePeople then
				self.a = Turbine.UI.Control()
				self.a:SetParent(self.ports[index])
				self.a:SetZOrder(1)
				self.a:SetBackground("PvMP_Plus/Resources/port.tga")
				self.a:SetMouseVisible(false)
			end
		end
	end

	self.KeyDown = function(sender, args)
		if args.Action == Turbine.UI.Lotro.Action.Escape then
			self:SetVisible(false)
			SecondaryWindow.showhide:SetText(L.ShowMap)
		end
	end

	self.VisibleChanged = function(sender, args)
		if self:IsVisible() then
			self:ResizeIcons()
		end
	end

	self.PositionChanged = function(sender, args)
		data.numbers.mapWin_x = self:GetLeft()
		data.numbers.mapWin_y = self:GetTop()
	end
end

function MapWindow:UpdateKeepsOnMap()
	for index, keep in pairs(self.keeps) do
		keep:SetBackground(EnemyKeepIcon)
	end
	for i = 1, buff_list:GetCount() do
		local element = buff_list:Get(i):GetName()
		if SetContains(keeps, element) then
			self.keeps[keeps[element]]:SetBackground(AlignedKeepIcon)
		end
	end
	for index, hotspot in pairs(self.hotspots) do
		hotspot:SetBackground(0x41005e5e)
	end
end

function MapWindow:ResizeIcons()
	for player, control in pairs(MapWindow.enemyPositions) do
		control:SetSize(control:GetWidth() * self.scale + 2, control:GetHeight() * self.scale + 2)
	end
	for index, keep in pairs(self.keeps) do
		keep:SetSize(32 * self.scale + 2, 32 * self.scale + 2)
	end
	for index, hotspot in pairs(self.hotspots) do
		hotspot:SetSize(30 * self.scale + 2, 30 * self.scale + 2)
	end
	for index, port in pairs(self.ports) do
		port:SetSize(port:GetWidth() * self.scale + 2, port:GetHeight() * self.scale + 3)
	end
	self.LocationIcon:SetSize(28 * self.scale, 28 * self.scale)
	self.LocationIcon:SetVisible(true)
	self.LocationIcon:SetRotation({ x = 0, y = 0, z = 0 - (self.heading - 90) })
	self.LocationIcon:SetVisible(CurrentPositionCounter ~= 0)
end

function MapWindow:MoveCurrentPosition(west, south, heading)
	self.heading = heading
	if self:IsVisible() then
		self.LocationIcon:SetVisible(true)
		self.LocationIcon:SetRotation({ x = 0, y = 0, z = 0 - (self.heading - 90) })
	end
	self.LocationIcon:SetPosition(
		self.map:GetWidth() - self.map:GetWidth() * (west - self.min_w) / self.dif_w -
		self.scale * self.LocationIcon:GetWidth() / 2,
		self.map:GetHeight() * (south - self.min_s) / self.dif_s - self.scale * self.LocationIcon:GetHeight() / 2
	)
	CurrentPositionCounter = 20 -- In seconds how long icon is shown
end

function MapWindow:AddEnemyPosition(w, s, amount, player)
	local str = player .. ": " .. amount .. " " .. (amount == "1" and L.FreepCreep or L.FreepsCreeps)
	if self.enemyPositions[player] ~= nil then
		self.enemyPositions[player]:SetPosition(
			(self.map:GetWidth() - self.map:GetWidth() * (w - self.min_w) / self.dif_w -
				self.scale * self.enemyPositions[player]:GetWidth() / 2),
			(self.map:GetHeight() * (s - self.min_s) / self.dif_s - self.scale * (self.enemyPositions[player]:GetHeight() - 9))
		)
		self.enemyPositions[player].Timer = enemyPosVisible
		self.enemyPositions[player]:SetText(str)
		self.enemyPositions[player]:SetVisible(true)
		return
	end

	local newTableLength = #self.enemyPositions + 1
	local newOverlay = Turbine.UI.Label()
	newOverlay:SetParent(self.map)
	newOverlay:SetSize(151, 29)
	newOverlay:SetStretchMode(1)
	newOverlay:SetSize(151 * self.scale + 2, 29 * self.scale + 2)
	newOverlay:SetFont(Turbine.UI.Lotro.Font.Arial12)
	newOverlay:SetForeColor(Turbine.UI.Color.Black)
	newOverlay:SetFontStyle(Turbine.UI.FontStyle.Outline)
	newOverlay:SetOutlineColor(Turbine.UI.Color.White)
	newOverlay:SetTextAlignment(Turbine.UI.ContentAlignment.TopCenter)
	newOverlay:SetText(str)
	newOverlay:SetBackground("PvMP_Plus/Resources/enemyPosOverlay.tga")
	newOverlay:SetMouseVisible(false)
	newOverlay:SetPosition(
		(self.map:GetWidth() - self.map:GetWidth() * (w - self.min_w) / self.dif_w -
			self.scale * math.ceil(newOverlay:GetWidth() / 2)),
		(self.map:GetHeight() * (s - self.min_s) / self.dif_s - self.scale * (newOverlay:GetHeight() - 9))
	)
	newOverlay.Timer = enemyPosVisible
	self.enemyPositions[player] = newOverlay
end