OverviewWindow = class(Turbine.UI.Window)

local ownTree			= false
local ownDrake			= false
local ownGary			= false
local ownCrown			= false
local ownCarrock		= false
local ownOutnumbered	= false

local treeTimer			= 0
local drakeTimer		= 0
local garyTimer			= 0
local crownTimer		= 0
local carrockTimer		= 0
local outnumberedTimer	= 0

function OverviewWindow:Constructor()
	Turbine.UI.Window.Constructor(self)
	local width = math.ceil(minimal_width + (Turbine.UI.Display.GetWidth() - minimal_width) * data.numbers.overview_width_ratio)
	local height = 90
	self:SetSize(width, height)

	self:SetPosition(data.numbers.overview_x, data.numbers.overview_y)
	self:SetWantsKeyEvents(true)
	self:SetMouseVisible(false)

	self.DragBar = DragBar(self, "PvMP+")

	self.panel = Turbine.UI.Label()
	self.panel:SetParent(self)
	self.panel:SetSize(width, height)
	self.panel:SetMouseVisible(false)

	self.bar_start	= 50
	self.bar_end	= self:GetWidth() - self.bar_start
	self.bar_length	= self.bar_end - self.bar_start


	-- Percentage Bar Builder for Rank
	self.empty_bar = Turbine.UI.Label()
	self.empty_bar:SetParent(self.panel)
	self.empty_bar:SetSize(self.bar_length, 14)
	self.empty_bar:SetPosition(self.bar_start, 27)
	self.empty_bar:SetBackground(BarBuilder[0])
	self.empty_bar:SetMouseVisible(false)

	self.filled_bar = Turbine.UI.Label()
	self.filled_bar:SetParent(self.panel)
	self.filled_bar:SetSize(0, 14)
	self.filled_bar:SetPosition(self.bar_start, 27)
	self.filled_bar:SetBackground(BarBuilder[1])
	self.filled_bar:SetMouseVisible(false)

	self.left_end = Turbine.UI.Label()
	self.left_end:SetParent(self.panel)
	self.left_end:SetSize(6, 18)
	self.left_end:SetPosition(self.bar_start - 3, 25)
	self.left_end:SetBackground(BarBuilder[2])
	self.left_end:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.left_end:SetMouseVisible(false)

	self.right_end = Turbine.UI.Label()
	self.right_end:SetParent(self.panel)
	self.right_end:SetSize(6, 18)
	self.right_end:SetPosition(self.bar_end - 3, 25)
	self.right_end:SetBackground(BarBuilder[3])
	self.right_end:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.right_end:SetMouseVisible(false)

	self.middle = Turbine.UI.Label()
	self.middle:SetParent(self.panel)
	self.middle:SetSize(self.bar_length - 6, 18)
	self.middle:SetPosition(self.bar_start + 3, 25)
	self.middle:SetBackground(BarBuilder[4])
	self.middle:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.middle:SetMouseVisible(false)

	self.percentage = Turbine.UI.Label()
	self.percentage:SetParent(self.panel)
	self.percentage:SetSize(width, 18)
	self.percentage:SetPosition(0, 25)
	self.percentage:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.percentage:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.percentage:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.percentage:SetMouseVisible(false)


	-- Multiplier and Outpost Container
	self.bonus_panel = Turbine.UI.Label()
	self.bonus_panel:SetParent(self.panel)
	self.bonus_panel:SetSize(95, 30)
	self.bonus_panel:SetPosition(width / 2 - self.bonus_panel:GetSize() / 2, 0)
	self.bonus_panel:SetMouseVisible(false)


	-- Multiplier Label
	self.label_bonus = Turbine.UI.Label()
	self.label_bonus:SetParent(self.bonus_panel)
	self.label_bonus:SetSize(self.bonus_panel:GetSize())
	self.label_bonus:SetTextAlignment(Turbine.UI.ContentAlignment.TopCenter)
	self.label_bonus:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.label_bonus:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.label_bonus:SetMouseVisible(false)
	self.label_bonus:SetVisible(not storage.show_bonus_disabled)


	-- Outpost Labels
	self.outpost1 = Turbine.UI.Label()
	self.outpost1:SetParent(self.bonus_panel)
	self.outpost1:SetSize(20, 3)
	self.outpost1:SetPosition(0, 18)
	self.outpost1:SetMouseVisible(false)
	self.outpost1:SetVisible(not storage.show_outpost_disabled)

	self.outpost1Text = Turbine.UI.Label()
	self.outpost1Text:SetParent(self.bonus_panel)
	self.outpost1Text:SetSize(20, 16)
	self.outpost1Text:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.outpost1Text:SetPosition(0, 11)
	self.outpost1Text:SetMouseVisible(false)
	self.outpost1Text:SetText("")
	self.outpost1Text:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.outpost1Text:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.outpost1Text:SetVisible(not storage.show_outpost_disabled)

	self.outpost2 = Turbine.UI.Label()
	self.outpost2:SetParent(self.bonus_panel)
	self.outpost2:SetSize(20, 3)
	self.outpost2:SetPosition(25, 18)
	self.outpost2:SetMouseVisible(false)
	self.outpost2:SetVisible(not storage.show_outpost_disabled)

	self.outpost2Text = Turbine.UI.Label()
	self.outpost2Text:SetParent(self.bonus_panel)
	self.outpost2Text:SetSize(20, 16)
	self.outpost2Text:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.outpost2Text:SetPosition(25, 11)
	self.outpost2Text:SetMouseVisible(false)
	self.outpost2Text:SetText("")
	self.outpost2Text:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.outpost2Text:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.outpost2Text:SetVisible(not storage.show_outpost_disabled)

	self.outpost3 = Turbine.UI.Label()
	self.outpost3:SetParent(self.bonus_panel)
	self.outpost3:SetSize(20, 3)
	self.outpost3:SetPosition(50, 18)
	self.outpost3:SetMouseVisible(false)
	self.outpost3:SetVisible(not storage.show_outpost_disabled)

	self.outpost3Text = Turbine.UI.Label()
	self.outpost3Text:SetParent(self.bonus_panel)
	self.outpost3Text:SetSize(20, 16)
	self.outpost3Text:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.outpost3Text:SetPosition(50, 11)
	self.outpost3Text:SetMouseVisible(false)
	self.outpost3Text:SetText("")
	self.outpost3Text:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.outpost3Text:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.outpost3Text:SetVisible(not storage.show_outpost_disabled)

	self.outpost4 = Turbine.UI.Label()
	self.outpost4:SetParent(self.bonus_panel)
	self.outpost4:SetSize(20, 3)
	self.outpost4:SetPosition(75, 18)
	self.outpost4:SetMouseVisible(false)
	self.outpost4:SetVisible(not storage.show_outpost_disabled)

	self.outpost4Text = Turbine.UI.Label()
	self.outpost4Text:SetParent(self.bonus_panel)
	self.outpost4Text:SetSize(20, 16)
	self.outpost4Text:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.outpost4Text:SetPosition(75, 11)
	self.outpost4Text:SetMouseVisible(false)
	self.outpost4Text:SetText("")
	self.outpost4Text:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.outpost4Text:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.outpost4Text:SetVisible(not storage.show_outpost_disabled)


	-- Keep Labels
	self.fKeep1 = Turbine.UI.Label()
	self.fKeep1:SetParent(self.panel)
	self.fKeep1:SetSize(24, 24)
	self.fKeep1:SetPosition(self.bonus_panel:GetLeft() - 30, 0)
	self.fKeep1:SetBackground("PvMP_Plus/Resources/KeepIcons/BlueFire.jpg")
	self.fKeep1:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.fKeep1:SetMouseVisible(false)
	self.fKeep1:SetVisible(false)

	self.fKeep1Text = Turbine.UI.Label()
	self.fKeep1Text:SetParent(self.panel)
	self.fKeep1Text:SetSize(24, 24)
	self.fKeep1Text:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.fKeep1Text:SetPosition(self.bonus_panel:GetLeft() - 30, 2)
	self.fKeep1Text:SetMouseVisible(false)
	self.fKeep1Text:SetText("")
	self.fKeep1Text:SetFont(Turbine.UI.Lotro.Font.Verdana16)
	self.fKeep1Text:SetFontStyle(Turbine.UI.FontStyle.Outline)

	self.fKeep2 = Turbine.UI.Label()
	self.fKeep2:SetParent(self.panel)
	self.fKeep2:SetSize(24, 24)
	self.fKeep2:SetPosition(self.fKeep1:GetLeft() - 26, 0)
	self.fKeep2:SetBackground("PvMP_Plus/Resources/KeepIcons/BlueFire.jpg")
	self.fKeep2:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.fKeep2:SetMouseVisible(false)
	self.fKeep2:SetVisible(false)

	self.fKeep2Text = Turbine.UI.Label()
	self.fKeep2Text:SetParent(self.panel)
	self.fKeep2Text:SetSize(24, 24)
	self.fKeep2Text:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.fKeep2Text:SetPosition(self.fKeep1Text:GetLeft() - 26, 2)
	self.fKeep2Text:SetMouseVisible(false)
	self.fKeep2Text:SetText("")
	self.fKeep2Text:SetFont(Turbine.UI.Lotro.Font.Verdana16)
	self.fKeep2Text:SetFontStyle(Turbine.UI.FontStyle.Outline)

	self.fKeep3 = Turbine.UI.Label()
	self.fKeep3:SetParent(self.panel)
	self.fKeep3:SetSize(24, 24)
	self.fKeep3:SetPosition(self.fKeep2:GetLeft() - 26, 0)
	self.fKeep3:SetBackground("PvMP_Plus/Resources/KeepIcons/BlueFire.jpg")
	self.fKeep3:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.fKeep3:SetMouseVisible(false)
	self.fKeep3:SetVisible(false)

	self.fKeep3Text = Turbine.UI.Label()
	self.fKeep3Text:SetParent(self.panel)
	self.fKeep3Text:SetSize(24, 24)
	self.fKeep3Text:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.fKeep3Text:SetPosition(self.fKeep2Text:GetLeft() - 26, 2)
	self.fKeep3Text:SetMouseVisible(false)
	self.fKeep3Text:SetText("")
	self.fKeep3Text:SetFont(Turbine.UI.Lotro.Font.Verdana16)
	self.fKeep3Text:SetFontStyle(Turbine.UI.FontStyle.Outline)

	self.fKeep4 = Turbine.UI.Label()
	self.fKeep4:SetParent(self.panel)
	self.fKeep4:SetSize(24, 24)
	self.fKeep4:SetPosition(self.fKeep3:GetLeft() - 26, 0)
	self.fKeep4:SetBackground("PvMP_Plus/Resources/KeepIcons/BlueFire.jpg")
	self.fKeep4:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.fKeep4:SetMouseVisible(false)
	self.fKeep4:SetVisible(false)

	self.fKeep4Text = Turbine.UI.Label()
	self.fKeep4Text:SetParent(self.panel)
	self.fKeep4Text:SetSize(24, 24)
	self.fKeep4Text:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.fKeep4Text:SetPosition(self.fKeep3Text:GetLeft() - 26, 2)
	self.fKeep4Text:SetMouseVisible(false)
	self.fKeep4Text:SetText("")
	self.fKeep4Text:SetFont(Turbine.UI.Lotro.Font.Verdana16)
	self.fKeep4Text:SetFontStyle(Turbine.UI.FontStyle.Outline)

	self.fKeep5 = Turbine.UI.Label()
	self.fKeep5:SetParent(self.panel)
	self.fKeep5:SetSize(24, 24)
	self.fKeep5:SetPosition(self.fKeep4:GetLeft() - 26, 0)
	self.fKeep5:SetBackground("PvMP_Plus/Resources/KeepIcons/BlueFire.jpg")
	self.fKeep5:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.fKeep5:SetMouseVisible(false)
	self.fKeep5:SetVisible(false)

	self.fKeep5Text = Turbine.UI.Label()
	self.fKeep5Text:SetParent(self.panel)
	self.fKeep5Text:SetSize(24, 24)
	self.fKeep5Text:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.fKeep5Text:SetPosition(self.fKeep4Text:GetLeft() - 26, 2)
	self.fKeep5Text:SetMouseVisible(false)
	self.fKeep5Text:SetText("")
	self.fKeep5Text:SetFont(Turbine.UI.Lotro.Font.Verdana16)
	self.fKeep5Text:SetFontStyle(Turbine.UI.FontStyle.Outline)

	self.cKeep1 = Turbine.UI.Label()
	self.cKeep1:SetParent(self.panel)
	self.cKeep1:SetSize(24, 24)
	self.cKeep1:SetPosition(self.bonus_panel:GetLeft() + self.bonus_panel:GetSize() + 6, 0)
	self.cKeep1:SetBackground("PvMP_Plus/Resources/KeepIcons/RedFire.jpg")
	self.cKeep1:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.cKeep1:SetMouseVisible(false)
	self.cKeep1:SetVisible(false)

	self.cKeep1Text = Turbine.UI.Label()
	self.cKeep1Text:SetParent(self.panel)
	self.cKeep1Text:SetSize(24, 24)
	self.cKeep1Text:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.cKeep1Text:SetPosition(self.bonus_panel:GetLeft() + self.bonus_panel:GetSize() + 6, 2)
	self.cKeep1Text:SetMouseVisible(false)
	self.cKeep1Text:SetText("")
	self.cKeep1Text:SetFont(Turbine.UI.Lotro.Font.Verdana16)
	self.cKeep1Text:SetFontStyle(Turbine.UI.FontStyle.Outline)

	self.cKeep2 = Turbine.UI.Label()
	self.cKeep2:SetParent(self.panel)
	self.cKeep2:SetSize(24, 24)
	self.cKeep2:SetPosition(self.cKeep1:GetLeft() + 26, 0)
	self.cKeep2:SetBackground("PvMP_Plus/Resources/KeepIcons/RedFire.jpg")
	self.cKeep2:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.cKeep2:SetMouseVisible(false)
	self.cKeep2:SetVisible(false)

	self.cKeep2Text = Turbine.UI.Label()
	self.cKeep2Text:SetParent(self.panel)
	self.cKeep2Text:SetSize(24, 24)
	self.cKeep2Text:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.cKeep2Text:SetPosition(self.cKeep1Text:GetLeft() + 26, 2)
	self.cKeep2Text:SetMouseVisible(false)
	self.cKeep2Text:SetText("")
	self.cKeep2Text:SetFont(Turbine.UI.Lotro.Font.Verdana16)
	self.cKeep2Text:SetFontStyle(Turbine.UI.FontStyle.Outline)

	self.cKeep3 = Turbine.UI.Label()
	self.cKeep3:SetParent(self.panel)
	self.cKeep3:SetSize(24, 24)
	self.cKeep3:SetPosition(self.cKeep2:GetLeft() + 26, 0)
	self.cKeep3:SetBackground("PvMP_Plus/Resources/KeepIcons/RedFire.jpg")
	self.cKeep3:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.cKeep3:SetMouseVisible(false)
	self.cKeep3:SetVisible(false)

	self.cKeep3Text = Turbine.UI.Label()
	self.cKeep3Text:SetParent(self.panel)
	self.cKeep3Text:SetSize(24, 24)
	self.cKeep3Text:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.cKeep3Text:SetPosition(self.cKeep2Text:GetLeft() + 26, 2)
	self.cKeep3Text:SetMouseVisible(false)
	self.cKeep3Text:SetText("")
	self.cKeep3Text:SetFont(Turbine.UI.Lotro.Font.Verdana16)
	self.cKeep3Text:SetFontStyle(Turbine.UI.FontStyle.Outline)

	self.cKeep4 = Turbine.UI.Label()
	self.cKeep4:SetParent(self.panel)
	self.cKeep4:SetSize(24, 24)
	self.cKeep4:SetPosition(self.cKeep3:GetLeft() + 26, 0)
	self.cKeep4:SetBackground("PvMP_Plus/Resources/KeepIcons/RedFire.jpg")
	self.cKeep4:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.cKeep4:SetMouseVisible(false)
	self.cKeep4:SetVisible(false)

	self.cKeep4Text = Turbine.UI.Label()
	self.cKeep4Text:SetParent(self.panel)
	self.cKeep4Text:SetSize(24, 24)
	self.cKeep4Text:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.cKeep4Text:SetPosition(self.cKeep3Text:GetLeft() + 26, 2)
	self.cKeep4Text:SetMouseVisible(false)
	self.cKeep4Text:SetText("")
	self.cKeep4Text:SetFont(Turbine.UI.Lotro.Font.Verdana16)
	self.cKeep4Text:SetFontStyle(Turbine.UI.FontStyle.Outline)

	self.cKeep5 = Turbine.UI.Label()
	self.cKeep5:SetParent(self.panel)
	self.cKeep5:SetSize(24, 24)
	self.cKeep5:SetPosition(self.cKeep4:GetLeft() + 26, 0)
	self.cKeep5:SetBackground("PvMP_Plus/Resources/KeepIcons/RedFire.jpg")
	self.cKeep5:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.cKeep5:SetMouseVisible(false)
	self.cKeep5:SetVisible(false)

	self.cKeep5Text = Turbine.UI.Label()
	self.cKeep5Text:SetParent(self.panel)
	self.cKeep5Text:SetSize(24, 24)
	self.cKeep5Text:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.cKeep5Text:SetPosition(self.cKeep4Text:GetLeft() + 26, 2)
	self.cKeep5Text:SetMouseVisible(false)
	self.cKeep5Text:SetText("")
	self.cKeep5Text:SetFont(Turbine.UI.Lotro.Font.Verdana14)
	self.cKeep5Text:SetFontStyle(Turbine.UI.FontStyle.Outline)


	-- Delving Labels
	self.fDelv1Icon = Turbine.UI.Label()
	self.fDelv1Icon:SetParent(self.panel)
	self.fDelv1Icon:SetSize(32, 32)
	self.fDelv1Icon:SetPosition(self.fKeep5:GetLeft() - 27, 0)
	self.fDelv1Icon:SetBackground(0x4112D3CD)
	self.fDelv1Icon:SetStretchMode(1)
	self.fDelv1Icon:SetSize(15, 15)
	self.fDelv1Icon:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.fDelv1Icon:SetMouseVisible(false)
	self.fDelv1Icon:SetVisible(true)

	self.fDelv1Time = Turbine.UI.Label()
	self.fDelv1Time:SetParent(self.panel)
	self.fDelv1Time:SetSize(30, 15)
	self.fDelv1Time:SetTextAlignment(Turbine.UI.ContentAlignment.TopCenter)
	self.fDelv1Time:SetPosition(self.fKeep5:GetLeft() - 35, 13)
	self.fDelv1Time:SetMouseVisible(false)
	self.fDelv1Time:SetText("0:00")
	self.fDelv1Time:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.fDelv1Time:SetFontStyle(Turbine.UI.FontStyle.Outline)

	self.fDelv2Icon = Turbine.UI.Label()
	self.fDelv2Icon:SetParent(self.panel)
	self.fDelv2Icon:SetSize(32, 32)
	self.fDelv2Icon:SetPosition(self.fDelv1Icon:GetLeft() - 28, 0)
	self.fDelv2Icon:SetBackground(0x4112D3CE)
	self.fDelv2Icon:SetStretchMode(1)
	self.fDelv2Icon:SetSize(15, 15)
	self.fDelv2Icon:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.fDelv2Icon:SetMouseVisible(false)
	self.fDelv2Icon:SetVisible(true)

	self.fDelv2Time = Turbine.UI.Label()
	self.fDelv2Time:SetParent(self.panel)
	self.fDelv2Time:SetSize(30, 15)
	self.fDelv2Time:SetTextAlignment(Turbine.UI.ContentAlignment.TopCenter)
	self.fDelv2Time:SetPosition(self.fDelv1Time:GetLeft() - 28, 13)
	self.fDelv2Time:SetMouseVisible(false)
	self.fDelv2Time:SetText("0:00")
	self.fDelv2Time:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.fDelv2Time:SetFontStyle(Turbine.UI.FontStyle.Outline)

	self.fDelv3Icon = Turbine.UI.Label()
	self.fDelv3Icon:SetParent(self.panel)
	self.fDelv3Icon:SetSize(32, 32)
	self.fDelv3Icon:SetPosition(self.fDelv2Icon:GetLeft() - 28, 0)
	self.fDelv3Icon:SetBackground(0x4112D3D0)
	self.fDelv3Icon:SetStretchMode(1)
	self.fDelv3Icon:SetSize(15, 15)
	self.fDelv3Icon:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.fDelv3Icon:SetMouseVisible(false)
	self.fDelv3Icon:SetVisible(true)

	self.fDelv3Time = Turbine.UI.Label()
	self.fDelv3Time:SetParent(self.panel)
	self.fDelv3Time:SetSize(30, 15)
	self.fDelv3Time:SetTextAlignment(Turbine.UI.ContentAlignment.TopCenter)
	self.fDelv3Time:SetPosition(self.fDelv2Time:GetLeft() - 28, 13)
	self.fDelv3Time:SetMouseVisible(false)
	self.fDelv3Time:SetText("0:00")
	self.fDelv3Time:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.fDelv3Time:SetFontStyle(Turbine.UI.FontStyle.Outline)

	self.cDelv1Icon = Turbine.UI.Label()
	self.cDelv1Icon:SetParent(self.panel)
	self.cDelv1Icon:SetSize(32, 32)
	self.cDelv1Icon:SetPosition(self.cKeep5:GetLeft() + 36, 0)
	self.cDelv1Icon:SetBackground(0x4112D3CD)
	self.cDelv1Icon:SetStretchMode(1)
	self.cDelv1Icon:SetSize(15, 15)
	self.cDelv1Icon:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.cDelv1Icon:SetMouseVisible(false)
	self.cDelv1Icon:SetVisible(true)

	self.cDelv1Time = Turbine.UI.Label()
	self.cDelv1Time:SetParent(self.panel)
	self.cDelv1Time:SetSize(30, 15)
	self.cDelv1Time:SetTextAlignment(Turbine.UI.ContentAlignment.TopCenter)
	self.cDelv1Time:SetPosition(self.cKeep5:GetLeft() + 28, 13)
	self.cDelv1Time:SetMouseVisible(false)
	self.cDelv1Time:SetText("0:00")
	self.cDelv1Time:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.cDelv1Time:SetFontStyle(Turbine.UI.FontStyle.Outline)

	self.cDelv2Icon = Turbine.UI.Label()
	self.cDelv2Icon:SetParent(self.panel)
	self.cDelv2Icon:SetSize(32, 32)
	self.cDelv2Icon:SetPosition(self.cDelv1Icon:GetLeft() + 28, 0)
	self.cDelv2Icon:SetBackground(0x4112D3CE)
	self.cDelv2Icon:SetStretchMode(1)
	self.cDelv2Icon:SetSize(15, 15)
	self.cDelv2Icon:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.cDelv2Icon:SetMouseVisible(false)
	self.cDelv2Icon:SetVisible(true)

	self.cDelv2Time = Turbine.UI.Label()
	self.cDelv2Time:SetParent(self.panel)
	self.cDelv2Time:SetSize(30, 15)
	self.cDelv2Time:SetTextAlignment(Turbine.UI.ContentAlignment.TopCenter)
	self.cDelv2Time:SetPosition(self.cDelv1Time:GetLeft() + 28, 13)
	self.cDelv2Time:SetMouseVisible(false)
	self.cDelv2Time:SetText("0:00")
	self.cDelv2Time:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.cDelv2Time:SetFontStyle(Turbine.UI.FontStyle.Outline)

	self.cDelv3Icon = Turbine.UI.Label()
	self.cDelv3Icon:SetParent(self.panel)
	self.cDelv3Icon:SetSize(32, 32)
	self.cDelv3Icon:SetPosition(self.cDelv2Icon:GetLeft() + 28, 0)
	self.cDelv3Icon:SetBackground(0x4112D3D0)
	self.cDelv3Icon:SetStretchMode(1)
	self.cDelv3Icon:SetSize(15, 15)
	self.cDelv3Icon:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.cDelv3Icon:SetMouseVisible(false)
	self.cDelv3Icon:SetVisible(true)

	self.cDelv3Time = Turbine.UI.Label()
	self.cDelv3Time:SetParent(self.panel)
	self.cDelv3Time:SetSize(30, 15)
	self.cDelv3Time:SetTextAlignment(Turbine.UI.ContentAlignment.TopCenter)
	self.cDelv3Time:SetPosition(self.cDelv2Time:GetLeft() + 28, 13)
	self.cDelv3Time:SetMouseVisible(false)
	self.cDelv3Time:SetText("0:00")
	self.cDelv3Time:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.cDelv3Time:SetFontStyle(Turbine.UI.FontStyle.Outline)


	-- Relic Labels
	self.fCarrockRelicIcon = Turbine.UI.Label()
	self.fCarrockRelicIcon:SetParent(self.panel)
	self.fCarrockRelicIcon:SetSize(32, 32)
	self.fCarrockRelicIcon:SetPosition(self.fDelv3Icon:GetLeft() - 35, 0)
	self.fCarrockRelicIcon:SetBackground(0x4112d3c8)
	self.fCarrockRelicIcon:SetStretchMode(1)
	self.fCarrockRelicIcon:SetSize(15, 15)
	self.fCarrockRelicIcon:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.fCarrockRelicIcon:SetMouseVisible(false)
	self.fCarrockRelicIcon:SetVisible(true)

	self.fCarrockRelicTime = Turbine.UI.Label()
	self.fCarrockRelicTime:SetParent(self.panel)
	self.fCarrockRelicTime:SetSize(30, 15)
	self.fCarrockRelicTime:SetTextAlignment(Turbine.UI.ContentAlignment.TopCenter)
	self.fCarrockRelicTime:SetPosition(self.fDelv3Time:GetLeft() - 35, 13)
	self.fCarrockRelicTime:SetMouseVisible(false)
	self.fCarrockRelicTime:SetText("0:00")
	self.fCarrockRelicTime:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.fCarrockRelicTime:SetFontStyle(Turbine.UI.FontStyle.Outline)

	self.fCrownRelicIcon = Turbine.UI.Label()
	self.fCrownRelicIcon:SetParent(self.panel)
	self.fCrownRelicIcon:SetSize(32, 32)
	self.fCrownRelicIcon:SetPosition(self.fCarrockRelicIcon:GetLeft() - 28, 0)
	self.fCrownRelicIcon:SetBackground(0x4112d3c7)
	self.fCrownRelicIcon:SetStretchMode(1)
	self.fCrownRelicIcon:SetSize(15, 15)
	self.fCrownRelicIcon:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.fCrownRelicIcon:SetMouseVisible(false)
	self.fCrownRelicIcon:SetVisible(true)

	self.fCrownRelicTime = Turbine.UI.Label()
	self.fCrownRelicTime:SetParent(self.panel)
	self.fCrownRelicTime:SetSize(30, 15)
	self.fCrownRelicTime:SetTextAlignment(Turbine.UI.ContentAlignment.TopCenter)
	self.fCrownRelicTime:SetPosition(self.fCarrockRelicTime:GetLeft() - 28, 13)
	self.fCrownRelicTime:SetMouseVisible(false)
	self.fCrownRelicTime:SetText("0:00")
	self.fCrownRelicTime:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.fCrownRelicTime:SetFontStyle(Turbine.UI.FontStyle.Outline)

	self.cCrownRelicIcon = Turbine.UI.Label()
	self.cCrownRelicIcon:SetParent(self.panel)
	self.cCrownRelicIcon:SetSize(32, 32)
	self.cCrownRelicIcon:SetPosition(self.cDelv3Icon:GetLeft() + 35, 0)
	self.cCrownRelicIcon:SetBackground(0x4112d3c7)
	self.cCrownRelicIcon:SetStretchMode(1)
	self.cCrownRelicIcon:SetSize(15, 15)
	self.cCrownRelicIcon:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.cCrownRelicIcon:SetMouseVisible(false)
	self.cCrownRelicIcon:SetVisible(true)

	self.cCrownRelicTime = Turbine.UI.Label()
	self.cCrownRelicTime:SetParent(self.panel)
	self.cCrownRelicTime:SetSize(30, 15)
	self.cCrownRelicTime:SetTextAlignment(Turbine.UI.ContentAlignment.TopCenter)
	self.cCrownRelicTime:SetPosition(self.cDelv3Time:GetLeft() + 35, 13)
	self.cCrownRelicTime:SetMouseVisible(false)
	self.cCrownRelicTime:SetText("0:00")
	self.cCrownRelicTime:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.cCrownRelicTime:SetFontStyle(Turbine.UI.FontStyle.Outline)

	self.cCarrockRelicIcon = Turbine.UI.Label()
	self.cCarrockRelicIcon:SetParent(self.panel)
	self.cCarrockRelicIcon:SetSize(32, 32)
	self.cCarrockRelicIcon:SetPosition(self.cCrownRelicIcon:GetLeft() + 28, 0)
	self.cCarrockRelicIcon:SetBackground(0x4112d3c8)
	self.cCarrockRelicIcon:SetStretchMode(1)
	self.cCarrockRelicIcon:SetSize(15, 15)
	self.cCarrockRelicIcon:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.cCarrockRelicIcon:SetMouseVisible(false)
	self.cCarrockRelicIcon:SetVisible(true)

	self.cCarrockRelicTime = Turbine.UI.Label()
	self.cCarrockRelicTime:SetParent(self.panel)
	self.cCarrockRelicTime:SetSize(30, 15)
	self.cCarrockRelicTime:SetTextAlignment(Turbine.UI.ContentAlignment.TopCenter)
	self.cCarrockRelicTime:SetPosition(self.cCrownRelicTime:GetLeft() + 28, 13)
	self.cCarrockRelicTime:SetMouseVisible(false)
	self.cCarrockRelicTime:SetText("0:00")
	self.cCarrockRelicTime:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.cCarrockRelicTime:SetFontStyle(Turbine.UI.FontStyle.Outline)


	-- Outnumbered Labels
	self.fOutnumberedIcon = Turbine.UI.Label()
	self.fOutnumberedIcon:SetParent(self.panel)
	self.fOutnumberedIcon:SetSize(32, 32)
	self.fOutnumberedIcon:SetPosition(self.fCrownRelicIcon:GetLeft() - 35, 0)
	self.fOutnumberedIcon:SetBackground(0x410e6df7)
	self.fOutnumberedIcon:SetStretchMode(1)
	self.fOutnumberedIcon:SetSize(15, 15)
	self.fOutnumberedIcon:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.fOutnumberedIcon:SetMouseVisible(false)
	self.fOutnumberedIcon:SetVisible(true)

	self.fOutnumberedTime = Turbine.UI.Label()
	self.fOutnumberedTime:SetParent(self.panel)
	self.fOutnumberedTime:SetSize(30, 15)
	self.fOutnumberedTime:SetTextAlignment(Turbine.UI.ContentAlignment.TopCenter)
	self.fOutnumberedTime:SetPosition(self.fCrownRelicTime:GetLeft() - 35, 13)
	self.fOutnumberedTime:SetMouseVisible(false)
	self.fOutnumberedTime:SetText("0:00")
	self.fOutnumberedTime:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.fOutnumberedTime:SetFontStyle(Turbine.UI.FontStyle.Outline)
	
	self.cOutnumberedIcon = Turbine.UI.Label()
	self.cOutnumberedIcon:SetParent(self.panel)
	self.cOutnumberedIcon:SetSize(32, 32)
	self.cOutnumberedIcon:SetPosition(self.cCarrockRelicIcon:GetLeft() + 35, 0)
	self.cOutnumberedIcon:SetBackground(0x410e6d15)
	self.cOutnumberedIcon:SetStretchMode(1)
	self.cOutnumberedIcon:SetSize(15, 15)
	self.cOutnumberedIcon:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.cOutnumberedIcon:SetMouseVisible(false)
	self.cOutnumberedIcon:SetVisible(true)

	self.cOutnumberedTime = Turbine.UI.Label()
	self.cOutnumberedTime:SetParent(self.panel)
	self.cOutnumberedTime:SetSize(30, 15)
	self.cOutnumberedTime:SetTextAlignment(Turbine.UI.ContentAlignment.TopCenter)
	self.cOutnumberedTime:SetPosition(self.cCarrockRelicTime:GetLeft() + 35, 13)
	self.cOutnumberedTime:SetMouseVisible(false)
	self.cOutnumberedTime:SetText("0:00")
	self.cOutnumberedTime:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.cOutnumberedTime:SetFontStyle(Turbine.UI.FontStyle.Outline)


	-- Points Label
	self.label_points = Turbine.UI.Label()
	self.label_points:SetParent(self.panel)
	self.label_points:SetSize(width - 108, 20)
	self.label_points:SetForeColor(default_font_color)
	self.label_points:SetPosition(width / 2 - self.label_points:GetSize() / 2, 45)
	self.label_points:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.label_points:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.label_points:SetFontStyle(Turbine.UI.FontStyle.Outline)


	-- Points Footer
	self.points_footer = Turbine.UI.Label()
	self.points_footer:SetParent(self.panel)
	self.points_footer:SetSize(width, 20)
	self.points_footer:SetPosition(0, 70)
	self.points_footer:SetMouseVisible(false)

	self.label_month		= OverviewLabel(self.points_footer, width, 0, default_font_color)
	self.label_day			= OverviewLabel(self.points_footer, width, 1, default_font_color)
	self.label_last_hour	= OverviewLabel(self.points_footer, width, 2, default_font_color)
	self.label_10min		= OverviewLabel(self.points_footer, width, 3, default_font_color)
	self.label_last_fight	= OverviewLabel(self.points_footer, width, 4, default_font_color)


	-- Commendations Footer
	self.comms_footer = Turbine.UI.Label()
	self.comms_footer:SetParent(self.panel)
	self.comms_footer:SetSize(width, 20)
	self.comms_footer:SetPosition(0, 70)
	self.comms_footer:SetMouseVisible(false)
	self.comms_footer:SetVisible(false)

	self.label_month_comms		= OverviewLabel(self.comms_footer, width, 0, default_font_color)
	self.label_day_comms		= OverviewLabel(self.comms_footer, width, 1, default_font_color)
	self.label_last_hour_comms	= OverviewLabel(self.comms_footer, width, 2, default_font_color)
	self.label_10min_comms		= OverviewLabel(self.comms_footer, width, 3, default_font_color)
	self.label_last_fight_comms	= OverviewLabel(self.comms_footer, width, 4, default_font_color)


	-- Frags Footer
	self.frags_footer = Turbine.UI.Label()
	self.frags_footer:SetParent(self.panel)
	self.frags_footer:SetSize(width, 20)
	self.frags_footer:SetPosition(0, 70)
	self.frags_footer:SetMouseVisible(false)
	self.frags_footer:SetVisible(false)

	self.label_month_frags		= OverviewLabel(self.frags_footer, width, 0, temp_disabled_color)
	self.label_day_frags		= OverviewLabel(self.frags_footer, width, 1, temp_disabled_color)
	self.label_last_hour_frags	= OverviewLabel(self.frags_footer, width, 2, temp_disabled_color)
	self.label_10min_frags		= OverviewLabel(self.frags_footer, width, 3, temp_disabled_color)
	self.label_last_fight_frags	= OverviewLabel(self.frags_footer, width, 4, temp_disabled_color)


	-- Commendations Label Toggle
	self.commendations_panel = Turbine.UI.Label()
	self.commendations_panel:SetParent(self.panel)
	self.commendations_panel:SetSize(54, 50)
	self.commendations_panel:SetPosition(width - 54, 18)
	self.commendations_panel.MouseEnter = function()
		if not storage.stats_hidden then
			self.comms_footer:SetVisible(true)
			self.points_footer:SetVisible(false)
			self.frags_footer:SetVisible(false)
		end
	end

	self.commendations_panel.MouseLeave = function()
		if not storage.stats_hidden then
			self.comms_footer:SetVisible(false)
			self.points_footer:SetVisible(not storage.frags_bar_visible)
			self.frags_footer:SetVisible(storage.frags_bar_visible)
		end
	end


	-- Commendations Label
	self.label_commendations = Turbine.UI.Label()
	self.label_commendations:SetParent(self.commendations_panel)
	self.label_commendations:SetSize(54, 20)
	self.label_commendations:SetForeColor(default_font_color)
	self.label_commendations:SetPosition(0, 30)
	self.label_commendations:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.label_commendations:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.label_commendations:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.label_commendations:SetMouseVisible(false)

	self.pic_commendations = Turbine.UI.Control()
	self.pic_commendations:SetParent(self.commendations_panel)
	self.pic_commendations:SetSize(32, 32)
	self.pic_commendations:SetPosition(11, 0)
	self.pic_commendations:SetBackground(0x41123495)
	self.pic_commendations:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.pic_commendations:SetMouseVisible(false)


	-- Rank Label Toggle
	self.rank_panel = Turbine.UI.Label()
	self.rank_panel:SetParent(self.panel)
	self.rank_panel:SetSize(54, 50)
	self.rank_panel:SetPosition(0, 18)
	self.rank_panel.MouseClick = function()
		if not storage.stats_hidden then
			self.frags_footer:SetVisible(not self.frags_footer:IsVisible())
			self.points_footer:SetVisible(not self.points_footer:IsVisible())
			storage.frags_bar_visible = self.frags_footer:IsVisible()
		end
	end


	-- Rank Label
	self.label_rank = Turbine.UI.Label()
	self.label_rank:SetParent(self.rank_panel)
	self.label_rank:SetSize(54, 20)
	self.label_rank:SetForeColor(default_font_color)
	self.label_rank:SetPosition(0, 30)
	self.label_rank:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.label_rank:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.label_rank:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.label_rank:SetMouseVisible(false)

	self.pic_rank = Turbine.UI.Control()
	self.pic_rank:SetParent(self.rank_panel)
	self.pic_rank:SetSize(32, 32)
	self.pic_rank:SetPosition(11, 0)
	self.pic_rank:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend)
	self.pic_rank:SetMouseVisible(false)


	-- Separator
	self.separator = Turbine.UI.Control()
	self.separator:SetParent(self.panel)
	self.separator:SetSize(width, 1)
	self.separator:SetPosition(0, 70)
	self.separator:SetBackColor(default_font_color)
	self.separator:SetMouseVisible(false)


	-- Repositioning
	self.PositionChanged = function(sender, args)
		data.numbers.overview_x = self:GetLeft()
		data.numbers.overview_y = self:GetTop()
		OverviewSettingsPanel:SetPosition(self:GetLeft() + self:GetWidth() - OverviewSettingsPanel:GetWidth(), self:GetTop())	
	end


	-- Points Toggle
	self.label_points.MouseDown = function()
		storage.show_remaining_points = not storage.show_remaining_points
		self:Update()
	end

	self.KeyDown = function(sender, args) 
		if args.Action == Turbine.UI.Lotro.Action.ToggleHUD then
			self:SetVisible(not self:IsVisible()) -- toggle visibility of Overview-Window
			OverviewSettingsPanel:SetVisible(not OverviewSettingsPanel:IsVisible()) -- toggle visibility of Overview-Control
			SecondaryWindow:SetVisible(not (SecondaryWindow:IsVisible() or storage.secondaryMinimized or storage.minimized)) -- toggle visibility of last kills + map
			HitWindow:SetVisible(not (HitWindow:IsVisible() or storage.HitWindowMinimized or storage.minimized)) -- toggle visibility of recent hits
			AlertWindow:SetVisible(not AlertWindow:IsVisible()) -- toggle visibility of Alerts
		end
	end
end

function OverviewWindow:Update()
	local text		= ""
	local hours		= 0
	local minutes	= 0
	local minuteMod	= 0

	commsLast24h, commsLastHour, commsLast10Min		= GetRecentData(data.numbers.recent_comms)
	pointsLast24h, pointsLastHour, pointsLast10Min	= GetRecentData(data.numbers.recent_points)
	fragsLast24h, fragsLastHour, fragsLast10Min		= GetRecentData(data.numbers.recent_frags)

	self.label_commendations:SetText(FormatPoints(current_commendations))

	if self:GetWidth() < 850 then
		if storage.show_remaining_points then
			self.label_points:SetText(L.Stats_Remaining_Points_Short .. FormatPoints(GetRemainingPoints()))
		else
			self.label_points:SetText(L.Stats_Total_Points_Short .. FormatPoints(data.numbers.points_total))
		end
		self.label_month:SetText(L.Stats_Current_Month_Short .. FormatPoints(data.numbers.points_current_month))
		self.label_day:SetText(L.Stats_Current_Day_Short .. FormatPoints(data.numbers.points_current_day))
		self.label_last_hour:SetText(L.Stats_Last_Hour_Short .. pointsLastHour)
		self.label_10min:SetText(L.Stats_Last_10min_Short .. pointsLast10Min)
		self.label_last_fight:SetText(L.Stats_Last_Fight_Short .. FormatPoints(points_last_fight))
		
		self.label_month_comms:SetText(L.Stats_Current_Month_Short .. FormatPoints(data.numbers.comms_current_month))
		self.label_day_comms:SetText(L.Stats_Current_Day_Short .. FormatPoints(data.numbers.comms_current_day))
		self.label_last_hour_comms:SetText(L.Stats_Last_Hour_Short .. commsLastHour)
		self.label_10min_comms:SetText(L.Stats_Last_10min_Short .. commsLast10Min)
		self.label_last_fight_comms:SetText(L.Stats_Last_Fight_Short .. FormatPoints(comms_last_fight))
		
		self.label_month_frags:SetText(L.Stats_Current_Month_Short .. FormatPoints(data.numbers.frags_current_month))
		self.label_day_frags:SetText(L.Stats_Current_Day_Short .. FormatPoints(data.numbers.frags_current_day))
		self.label_last_hour_frags:SetText(L.Stats_Last_Hour_Short .. fragsLastHour)
		self.label_10min_frags:SetText(L.Stats_Last_10min_Short .. fragsLast10Min)
		self.label_last_fight_frags:SetText(L.Stats_Last_Fight_Short .. FormatPoints(frags_last_fight))
	else
		if storage.show_remaining_points then
			self.label_points:SetText(L.Stats_Remaining_Points .. FormatPoints(GetRemainingPoints()))
		else
			self.label_points:SetText(L.Stats_Total_Points .. FormatPoints(data.numbers.points_total))
		end
		self.label_month:SetText(L.Stats_Current_Month .. FormatPoints(data.numbers.points_current_month))
		self.label_day:SetText(L.Stats_Current_Day .. FormatPoints(data.numbers.points_current_day))
		self.label_last_hour:SetText(L.Stats_Last_Hour .. pointsLastHour)
		self.label_10min:SetText(L.Stats_Last_10min .. pointsLast10Min)
		self.label_last_fight:SetText(L.Stats_Last_Fight .. FormatPoints(points_last_fight))
		
		self.label_month_comms:SetText(L.Stats_Current_Month .. FormatPoints(data.numbers.comms_current_month))
		self.label_day_comms:SetText(L.Stats_Current_Day .. FormatPoints(data.numbers.comms_current_day))
		self.label_last_hour_comms:SetText(L.Stats_Last_Hour ..commsLastHour)
		self.label_10min_comms:SetText(L.Stats_Last_10min .. commsLast10Min)
		self.label_last_fight_comms:SetText(L.Stats_Last_Fight .. FormatPoints(comms_last_fight))
		
		self.label_month_frags:SetText(L.Stats_Current_Month .. FormatPoints(data.numbers.frags_current_month))
		self.label_day_frags:SetText(L.Stats_Current_Day .. FormatPoints(data.numbers.frags_current_day))
		self.label_last_hour_frags:SetText(L.Stats_Last_Hour .. fragsLastHour)
		self.label_10min_frags:SetText(L.Stats_Last_10min .. fragsLast10Min)
		self.label_last_fight_frags:SetText(L.Stats_Last_Fight .. FormatPoints(frags_last_fight))
	end
	OverviewSettingsPanel:UpdateChatData()

	-- Resize the icons each iteration
	self.fDelv1Icon:SetSize(15, 15)
	self.fDelv2Icon:SetSize(15, 15)
	self.fDelv3Icon:SetSize(15, 15)
	self.cDelv1Icon:SetSize(15, 15)
	self.cDelv2Icon:SetSize(15, 15)
	self.cDelv3Icon:SetSize(15, 15)
	self.cCrownRelicIcon:SetSize(15, 15)
	self.cCarrockRelicIcon:SetSize(15, 15)
	self.fCrownRelicIcon:SetSize(15, 15)
	self.fCarrockRelicIcon:SetSize(15, 15)
	self.fOutnumberedIcon:SetSize(15, 15)
	self.cOutnumberedIcon:SetSize(15, 15)

	-- Update DOF buff timers
	-- Tree
	treeTimer	= treeTimer + 1
	minuteMod	= math.fmod(treeTimer, 3600)
	minutes		= (minuteMod - math.fmod(minuteMod, 60)) / 60
	hours		= (treeTimer - math.fmod(treeTimer, 3600)) / 3600

	if minutes < 10 then
		text = hours..":0"..minutes
	else
		text = hours..":"..minutes
	end

	if Turbine.Gameplay.LocalPlayer.GetInstance():GetAlignment() == Turbine.Gameplay.Alignment.MonsterPlayer then
		if ownTree then
			-- Enable creep side icon and text and set the text timer
			self.cDelv1Icon:SetVisible(true)
			self.cDelv1Time:SetVisible(true)
			self.cDelv1Time:SetText(text)

			-- Disable freep side icon and text
			self.fDelv1Icon:SetVisible(false)
			self.fDelv1Time:SetVisible(false)
		else
			-- Disable creep side icon and text
			self.cDelv1Icon:SetVisible(false)
			self.cDelv1Time:SetVisible(false)

			-- Enable freep side icon and text and set the text timer
			self.fDelv1Icon:SetVisible(true)
			self.fDelv1Time:SetVisible(true)
			self.fDelv1Time:SetText(text)
		end
	else
		if ownTree then
			-- Enable freep side icon and text and set the text timer
			self.fDelv1Icon:SetVisible(true)
			self.fDelv1Time:SetVisible(true)
			self.fDelv1Time:SetText(text)

			-- Disable creep side icon and text
			self.cDelv1Icon:SetVisible(false)
			self.cDelv1Time:SetVisible(false)
		else
			-- Disable freep side icon and text
			self.fDelv1Icon:SetVisible(false)
			self.fDelv1Time:SetVisible(false)

			-- Enable creep side icon and text and set the text timer
			self.cDelv1Icon:SetVisible(true)
			self.cDelv1Time:SetVisible(true)
			self.cDelv1Time:SetText(text)
		end
	end

	-- Update DOF buff timers
	-- Drake
	drakeTimer	= drakeTimer + 1
	minuteMod	= math.fmod(drakeTimer, 3600)
	minutes		= (minuteMod - math.fmod(minuteMod, 60)) / 60
	hours		= (drakeTimer - math.fmod(drakeTimer, 3600)) / 3600

	if minutes < 10 then
		text = hours..":0"..minutes
	else
		text = hours..":"..minutes
	end

	if Turbine.Gameplay.LocalPlayer.GetInstance():GetAlignment() == Turbine.Gameplay.Alignment.MonsterPlayer then
		if ownDrake then
			-- Enable creep side icon and text and set the text timer
			self.cDelv3Icon:SetVisible(true)
			self.cDelv3Time:SetVisible(true)
			self.cDelv3Time:SetText(text)

			-- Disable freep side icon and text
			self.fDelv3Icon:SetVisible(false)
			self.fDelv3Time:SetVisible(false)
		else
			-- Disable creep side icon and text
			self.cDelv3Icon:SetVisible(false)
			self.cDelv3Time:SetVisible(false)

			-- Enable freep side icon and text and set the text timer
			self.fDelv3Icon:SetVisible(true)
			self.fDelv3Time:SetVisible(true)
			self.fDelv3Time:SetText(text)
		end
	else
		if ownDrake then
			-- Enable freep side icon and text and set the text timer
			self.fDelv3Icon:SetVisible(true)
			self.fDelv3Time:SetVisible(true)
			self.fDelv3Time:SetText(text)

			-- Disable creep side icon and text
			self.cDelv3Icon:SetVisible(false)
			self.cDelv3Time:SetVisible(false)
		else
			-- Disable freep side icon and text
			self.fDelv3Icon:SetVisible(false)
			self.fDelv3Time:SetVisible(false)

			-- Enable creep side icon and text and set the text timer
			self.cDelv3Icon:SetVisible(true)
			self.cDelv3Time:SetVisible(true)
			self.cDelv3Time:SetText(text)
		end
	end

	-- Update DOF buff timers
	-- Gary
	garyTimer	= garyTimer + 1
	minuteMod	= math.fmod(garyTimer, 3600)
	minutes		= (minuteMod - math.fmod(minuteMod, 60)) / 60
	hours		= (garyTimer - math.fmod(garyTimer, 3600)) / 3600

	if minutes < 10 then
		text = hours..":0"..minutes
	else
		text = hours..":"..minutes
	end

	if Turbine.Gameplay.LocalPlayer.GetInstance():GetAlignment() == Turbine.Gameplay.Alignment.MonsterPlayer then
		if ownGary then
			-- Enable creep side icon and text and set the text timer
			self.cDelv2Icon:SetVisible(true)
			self.cDelv2Time:SetVisible(true)
			self.cDelv2Time:SetText(text)

			-- Disable freep side icon and text
			self.fDelv2Icon:SetVisible(false)
			self.fDelv2Time:SetVisible(false)
		else
			-- Disable creep side icon and text
			self.cDelv2Icon:SetVisible(false)
			self.cDelv2Time:SetVisible(false)

			-- Enable freep side icon and text and set the text timer
			self.fDelv2Icon:SetVisible(true)
			self.fDelv2Time:SetVisible(true)
			self.fDelv2Time:SetText(text)
		end
	else
		if ownGary then
			-- Enable freep side icon and text and set the text timer
			self.fDelv2Icon:SetVisible(true)
			self.fDelv2Time:SetVisible(true)
			self.fDelv2Time:SetText(text)

			-- Disable creep side icon and text
			self.cDelv2Icon:SetVisible(false)
			self.cDelv2Time:SetVisible(false)
		else
			-- Disable freep side icon and text
			self.fDelv2Icon:SetVisible(false)
			self.fDelv2Time:SetVisible(false)

			-- Enable creep side icon and text and set the text timer
			self.cDelv2Icon:SetVisible(true)
			self.cDelv2Time:SetVisible(true)
			self.cDelv2Time:SetText(text)
		end
	end

	-- Update Relic timers
	-- Crown
	crownTimer	= crownTimer + 1
	minuteMod	= math.fmod(crownTimer, 3600)
	minutes		= (minuteMod - math.fmod(minuteMod, 60)) / 60
	hours		= (crownTimer - math.fmod(crownTimer, 3600 )) / 3600

	if minutes < 10 then
		text = hours..":0"..minutes
	else
		text = hours..":"..minutes
	end

	if Turbine.Gameplay.LocalPlayer.GetInstance():GetAlignment() == Turbine.Gameplay.Alignment.MonsterPlayer then
		if ownCrown then
			-- Enable creep side icon and text and set the text timer
			self.cCrownRelicIcon:SetVisible(true)
			self.cCrownRelicTime:SetVisible(true)
			self.cCrownRelicTime:SetText(text)

			-- Disable freep side icon and text
			self.fCrownRelicIcon:SetVisible(false)
			self.fCrownRelicTime:SetVisible(false)
		else
			-- Disable creep side icon and text
			self.cCrownRelicIcon:SetVisible(false)
			self.cCrownRelicTime:SetVisible(false)

			-- Enable freep side icon and text and set the text timer
			self.fCrownRelicIcon:SetVisible(true)
			self.fCrownRelicTime:SetVisible(true)
			self.fCrownRelicTime:SetText(text)
		end
	else
		if ownCrown then
			-- Enable freep side icon and text and set the text timer
			self.fCrownRelicIcon:SetVisible(true)
			self.fCrownRelicTime:SetVisible(true)
			self.fCrownRelicTime:SetText(text)

			-- Disable creep side icon and text
			self.cCrownRelicIcon:SetVisible(false)
			self.cCrownRelicTime:SetVisible(false)
		else
			-- Disable freep side icon and text
			self.fCrownRelicIcon:SetVisible(false)
			self.fCrownRelicTime:SetVisible(false)

			-- Enable creep side icon and text and set the text timer
			self.cCrownRelicIcon:SetVisible(true)
			self.cCrownRelicTime:SetVisible(true)
			self.cCrownRelicTime:SetText(text)
		end
	end

	-- Update Relic timers
	-- Carrock
	carrockTimer	= carrockTimer + 1
	minuteMod		= math.fmod(carrockTimer, 3600)
	minutes			= (minuteMod - math.fmod(minuteMod, 60)) / 60
	hours			= (carrockTimer - math.fmod(carrockTimer, 3600)) / 3600

	if minutes < 10 then
		text = hours..":0"..minutes
	else
		text = hours..":"..minutes
	end

	if Turbine.Gameplay.LocalPlayer.GetInstance():GetAlignment() == Turbine.Gameplay.Alignment.MonsterPlayer then
		if ownCarrock then
			-- Enable creep side icon and text and set the text timer
			self.cCarrockRelicIcon:SetVisible(true)
			self.cCarrockRelicTime:SetVisible(true)
			self.cCarrockRelicTime:SetText(text)

			-- Disable freep side icon and text
			self.fCarrockRelicIcon:SetVisible(false)
			self.fCarrockRelicTime:SetVisible(false)
		else
			-- Disable creep side icon and text
			self.cCarrockRelicIcon:SetVisible(false)
			self.cCarrockRelicTime:SetVisible(false)

			-- Enable freep side icon and text and set the text timer
			self.fCarrockRelicIcon:SetVisible(true)
			self.fCarrockRelicTime:SetVisible(true)
			self.fCarrockRelicTime:SetText(text)
		end
	else
		if ownCarrock then
			-- Enable freep side icon and text and set the text timer
			self.fCarrockRelicIcon:SetVisible(true)
			self.fCarrockRelicTime:SetVisible(true)
			self.fCarrockRelicTime:SetText(text)

			-- Disable creep side icon and text
			self.cCarrockRelicIcon:SetVisible(false)
			self.cCarrockRelicTime:SetVisible(false)
		else
			-- Disable freep side icon and text
			self.fCarrockRelicIcon:SetVisible(false)
			self.fCarrockRelicTime:SetVisible(false)

			-- Enable creep side icon and text and set the text timer
			self.cCarrockRelicIcon:SetVisible(true)
			self.cCarrockRelicTime:SetVisible(true)
			self.cCarrockRelicTime:SetText(text)
		end
	end

	-- Update Outnumbered timers
	outnumberedTimer	= outnumberedTimer + 1
	minuteMod			= math.fmod(outnumberedTimer, 3600)
	minutes				= (minuteMod - math.fmod(minuteMod, 60)) / 60
	hours				= (outnumberedTimer - math.fmod(outnumberedTimer, 3600)) / 3600

	if minutes < 10 then
		text = hours..":0"..minutes
	else
		text = hours..":"..minutes
	end

	if Turbine.Gameplay.LocalPlayer.GetInstance():GetAlignment() == Turbine.Gameplay.Alignment.MonsterPlayer then
		if ownOutnumbered then
			-- Enable creep side icon and text and set the text timer
			self.cOutnumberedIcon:SetVisible(true)
			self.cOutnumberedTime:SetVisible(true)
			self.cOutnumberedTime:SetText(text)

			-- Disable freep side icon and text
			self.fOutnumberedIcon:SetVisible(false)
			self.fOutnumberedTime:SetVisible(false)
		else
			-- Disable creep side icon and text
			self.cOutnumberedIcon:SetVisible(false)
			self.cOutnumberedTime:SetVisible(false)
			
			-- Disable freep side icon and text
			self.fOutnumberedIcon:SetVisible(false)
			self.fOutnumberedTime:SetVisible(false)
		end
	else
		if ownOutnumbered then
			-- Enable freep side icon and text and set the text timer
			self.fOutnumberedIcon:SetVisible(true)
			self.fOutnumberedTime:SetVisible(true)
			self.fOutnumberedTime:SetText(text)

			-- Disable creep side icon and text
			self.cOutnumberedIcon:SetVisible(false)
			self.cOutnumberedTime:SetVisible(false)
		else
			-- Disable freep side icon and text
			self.fOutnumberedIcon:SetVisible(false)
			self.fOutnumberedTime:SetVisible(false)

			-- Disable creep side icon and text
			self.cOutnumberedIcon:SetVisible(false)
			self.cOutnumberedTime:SetVisible(false)
		end
	end


	-- Rank Progress
	for i = 0, 14 do
		if (data.numbers.points_total >= Ranks[i] and data.numbers.points_total < Ranks[i+1]) then
			local rank_difference = Ranks[i+1] - Ranks[i]
			local points_since_rankup = data.numbers.points_total - Ranks[i]
			local percentage_done = points_since_rankup / rank_difference
			self.pic_rank:SetBackground(Rank_Icons[i])
			self.label_rank:SetText(L.Strings_Rank..i)
			self:UpdateProgressBar(percentage_done)
			return
		end
	end
	self.pic_rank:SetBackground(Rank_Icons[15])
	self.label_rank:SetText(L.Strings_Rank.."15")
	self:UpdateProgressBar(1) -- Rank 15
end

function OverviewWindow:SetTreeOwner(owner)
	ownTree = owner
end

function OverviewWindow:SetDrakeOwner(owner)
	ownDrake = owner
end

function OverviewWindow:SetGaryOwner(owner)
	ownGary = owner
end

function OverviewWindow:SetCrownOwner(owner)
	ownCrown = owner
end

function OverviewWindow:SetCarrockOwner(owner)
	ownCarrock = owner
end

function OverviewWindow:SetOutnumberedOwner(owner)
	ownOutnumbered = owner
end

function OverviewWindow:IsTreeOwned()
	return ownTree
end

function OverviewWindow:IsDrakeOwned()
	return ownDrake
end

function OverviewWindow:IsGaryOwned()
	return ownGary
end

function OverviewWindow:IsCrownOwned()
	return ownCrown
end

function OverviewWindow:IsCarrockOwned()
	return ownCarrock
end

function OverviewWindow:IsOutnumberedOwned()
	return ownOutnumbered
end

function OverviewWindow:ResetTreeTimer()
	treeTimer = 0
end

function OverviewWindow:ResetDrakeTimer()
	drakeTimer = 0
end

function OverviewWindow:ResetGaryTimer()
	garyTimer = 0
end

function OverviewWindow:ResetCrownTimer()
	crownTimer = 0
end

function OverviewWindow:ResetCarrockTimer()
	carrockTimer = 0
end

function OverviewWindow:ResetOutnumberedTimer()
	outnumberedTimer = 0
end

function OverviewWindow:UpdateProgressBar(percentage_done)
	self.percentage:SetText(math.floor(percentage_done * 10000) / 100 .. "%") -- Sets amount of decimals towards rank
	local filled_pixel = math.floor(self.bar_length * percentage_done)
	self.filled_bar:SetWidth(filled_pixel)
end

function OverviewWindow:UpdatePosition()
	local old_width = self:GetWidth()
	local new_width = math.floor(minimal_width + (Turbine.UI.Display.GetWidth() - minimal_width) * data.numbers.overview_width_ratio)
	if new_width / 2 ~= math.floor((new_width + 1) / 2) then new_width = new_width + 1 end
	data.numbers.overview_x = data.numbers.overview_x - (new_width - old_width) / 2
	if data.numbers.overview_x < 0 then data.numbers.overview_x = 0 end
	if data.numbers.overview_x + new_width > Turbine.UI.Display.GetWidth() then data.numbers.overview_x = Turbine.UI.Display.GetWidth() - new_width end
	self:SetWidth(new_width)
	self:SetPosition(data.numbers.overview_x,data.numbers.overview_y)
	self:UpdateBarLength()
	self.panel:SetWidth(new_width)
	self.separator:SetWidth(new_width)
	self.commendations_panel:SetPosition(self:GetWidth() - 54, 18)
	self.points_footer:SetWidth(new_width)
	self.comms_footer:SetWidth(new_width)
	self.label_points:SetSize(new_width - 108, 20)

	self.label_month:SetSize(new_width / 5, 20)
	self.label_day:SetSize(new_width / 5, 20)
	self.label_day:SetPosition(new_width / 5, 0)
	self.label_last_hour:SetSize(new_width / 5, 20)
	self.label_last_hour:SetPosition(2 * new_width / 5, 0)
	self.label_10min:SetSize(new_width / 5, 20)
	self.label_10min:SetPosition(3 * new_width / 5, 0)
	self.label_last_fight:SetSize(new_width / 5, 20)
	self.label_last_fight:SetPosition(4 * new_width / 5, 0)

	self.label_month_comms:SetSize(new_width / 5, 20)
	self.label_day_comms:SetSize(new_width / 5, 20)
	self.label_day_comms:SetPosition(new_width / 5, 0)
	self.label_last_hour_comms:SetSize(new_width / 5, 20)
	self.label_last_hour_comms:SetPosition(2 * new_width / 5, 0)
	self.label_10min_comms:SetSize(new_width / 5, 20)
	self.label_10min_comms:SetPosition(3 * new_width / 5, 0)
	self.label_last_fight_comms:SetSize(new_width / 5, 20)
	self.label_last_fight_comms:SetPosition(4 * new_width / 5, 0)
	
	self.label_month_frags:SetSize(new_width / 5, 20)
	self.label_day_frags:SetSize(new_width / 5, 20)
	self.label_day_frags:SetPosition(new_width / 5, 0)
	self.label_last_hour_frags:SetSize(new_width / 5, 20)
	self.label_last_hour_frags:SetPosition(2 * new_width / 5, 0)
	self.label_10min_frags:SetSize(new_width / 5, 20)
	self.label_10min_frags:SetPosition(3 * new_width / 5, 0)
	self.label_last_fight_frags:SetSize(new_width / 5, 20)
	self.label_last_fight_frags:SetPosition(4 * new_width / 5, 0)

	self.bonus_panel:SetPosition(new_width / 2 - self.bonus_panel:GetSize() / 2, 0)
	OverviewSettingsPanel:SetPosition(self:GetLeft() + new_width - OverviewSettingsPanel:GetWidth(), self:GetTop())

	-- Update Keep positions
	self.fKeep1:SetPosition(self.bonus_panel:GetLeft() - 30, 0)
	self.fKeep1Text:SetPosition(self.bonus_panel:GetLeft() - 30, 2)
	self.fKeep2:SetPosition(self.fKeep1:GetLeft() - 26, 0)
	self.fKeep2Text:SetPosition(self.fKeep1Text:GetLeft() - 26, 2)
	self.fKeep3:SetPosition(self.fKeep2:GetLeft() - 26, 0)
	self.fKeep3Text:SetPosition(self.fKeep2Text:GetLeft() - 26, 2)
	self.fKeep4:SetPosition(self.fKeep3:GetLeft() - 26, 0)
	self.fKeep4Text:SetPosition(self.fKeep3Text:GetLeft() - 26, 2)
	self.fKeep5:SetPosition(self.fKeep4:GetLeft() - 26, 0)
	self.fKeep5Text:SetPosition(self.fKeep4Text:GetLeft() - 26, 2)

	self.cKeep1:SetPosition(self.bonus_panel:GetLeft() + self.bonus_panel:GetSize() + 6, 0)
	self.cKeep1Text:SetPosition(self.bonus_panel:GetLeft() + self.bonus_panel:GetSize() + 6, 2)
	self.cKeep2:SetPosition(self.cKeep1:GetLeft() + 26, 0)
	self.cKeep2Text:SetPosition(self.cKeep1Text:GetLeft() + 26, 2)
	self.cKeep3:SetPosition(self.cKeep2:GetLeft() + 26, 0)
	self.cKeep3Text:SetPosition(self.cKeep2Text:GetLeft() + 26, 2)
	self.cKeep4:SetPosition(self.cKeep3:GetLeft() + 26, 0)
	self.cKeep4Text:SetPosition(self.cKeep3Text:GetLeft() + 26, 2)
	self.cKeep5:SetPosition(self.cKeep4:GetLeft() + 26, 0)
	self.cKeep5Text:SetPosition(self.cKeep4Text:GetLeft() + 26, 2)

	-- Update DOF positions
	self.fDelv1Icon:SetPosition(self.fKeep5:GetLeft() - 27, 0)
	self.fDelv1Time:SetPosition(self.fKeep5:GetLeft() - 35, 13)
	self.fDelv2Icon:SetPosition(self.fDelv1Icon:GetLeft() - 28, 0)
	self.fDelv2Time:SetPosition(self.fDelv1Time:GetLeft() - 28, 13)
	self.fDelv3Icon:SetPosition(self.fDelv2Icon:GetLeft() - 28, 0)
	self.fDelv3Time:SetPosition(self.fDelv2Time:GetLeft() - 28, 13)

	self.cDelv1Icon:SetPosition(self.cKeep5:GetLeft() + 36, 0)
	self.cDelv1Time:SetPosition(self.cKeep5:GetLeft() + 28, 13)
	self.cDelv2Icon:SetPosition(self.cDelv1Icon:GetLeft() + 28, 0)
	self.cDelv2Time:SetPosition(self.cDelv1Time:GetLeft() + 28, 13)
	self.cDelv3Icon:SetPosition(self.cDelv2Icon:GetLeft() + 28, 0)
	self.cDelv3Time:SetPosition(self.cDelv2Time:GetLeft() + 28, 13)

	--Update Relic positions
	self.fCarrockRelicIcon:SetPosition(self.fDelv3Icon:GetLeft() - 35, 0)
	self.fCarrockRelicTime:SetPosition(self.fDelv3Time:GetLeft() - 35, 13)
	self.fCrownRelicIcon:SetPosition(self.fCarrockRelicIcon:GetLeft() - 28, 0)
	self.fCrownRelicTime:SetPosition(self.fCarrockRelicTime:GetLeft() - 28, 13)

	self.cCrownRelicIcon:SetPosition(self.cDelv3Icon:GetLeft() + 35, 0)
	self.cCrownRelicTime:SetPosition(self.cDelv3Time:GetLeft() + 35, 13)
	self.cCarrockRelicIcon:SetPosition(self.cCrownRelicIcon:GetLeft() + 28, 0)
	self.cCarrockRelicTime:SetPosition(self.cCrownRelicTime:GetLeft() + 28, 13)

	--Update Outnumbered positions
	self.fOutnumberedIcon:SetPosition(self.fCrownRelicIcon:GetLeft() - 35, 0)
	self.fOutnumberedTime:SetPosition(self.fCrownRelicTime:GetLeft() - 35, 13)
	
	self.cOutnumberedIcon:SetPosition(self.cCarrockRelicIcon:GetLeft() + 35, 0)
	self.cOutnumberedTime:SetPosition(self.cCarrockRelicTime:GetLeft() + 35, 13)
	
	-- Resize the icons
	self.fDelv1Icon:SetSize(15, 15)
	self.fDelv2Icon:SetSize(15, 15)
	self.fDelv3Icon:SetSize(15, 15)
	self.cDelv1Icon:SetSize(15, 15)
	self.cDelv2Icon:SetSize(15, 15)
	self.cDelv3Icon:SetSize(15, 15)
	self.cCrownRelicIcon:SetSize(15, 15)
	self.cCarrockRelicIcon:SetSize(15, 15)
	self.fCrownRelicIcon:SetSize(15, 15)
	self.fCarrockRelicIcon:SetSize(15, 15)
	self.fOutnumberedIcon:SetSize(15, 15)
	self.cOutnumberedIcon:SetSize(15, 15)
	self:Update()
end

function OverviewWindow:UpdateBarLength()
	self.bar_start	= 50
	self.bar_end	= self:GetWidth() - self.bar_start
	self.bar_length	= self.bar_end - self.bar_start

	self.empty_bar:SetWidth(self.bar_length)
	self.middle:SetWidth(self.bar_length - 6)
	self.right_end:SetPosition(self.bar_end - 3, 25)
	self.percentage:SetWidth(self:GetWidth())
end

function OverviewWindow:ToggleStatsVisibility()
	storage.stats_hidden = self.separator:IsVisible()
	self:SetStatsVisibility(not storage.stats_hidden)
end

function OverviewWindow:SetStatsVisibility(flag)
	self.separator:SetVisible(flag)
	if storage.frags_bar_visible then
		self.frags_footer:SetVisible(flag)
	else
		self.points_footer:SetVisible(flag)
	end
end