StatsWindow = class(Turbine.UI.Lotro.Window)

local alphabetical_desc	= { ["enum"] = 0, ["funct"] = function(w1,w2) return w1.Name:GetText() < w2.Name:GetText() end }
local alphabetical_asc	= { ["enum"] = 1, ["funct"] = function(w1,w2) return w1.Name:GetText() > w2.Name:GetText() end }
local kills_desc		= { ["enum"] = 2, ["funct"] = function(w1,w2) return tonumber(w1.Kills:GetText()) > tonumber(w2.Kills:GetText()) end }
local kills_asc			= { ["enum"] = 3, ["funct"] = function(w1,w2) return tonumber(w1.Kills:GetText()) < tonumber(w2.Kills:GetText()) end }

function StatsWindow:Constructor()
	local width	= 300
	local height = 575

	Turbine.UI.Lotro.Window.Constructor(self)

	self:SetSize(width, height)
	self:SetPosition(data.numbers.statsWin_x, data.numbers.statsWin_y)
	self:SetZOrder(1)
	self:SetText(L.Statistics)
	self:SetWantsKeyEvents(true)

	-- Tabs
	self.tab_stats = Tab(
		self, L.Statistics_Short, 1, 0, "PvMP_Plus/Resources/Tabs/stats.tga",
		"PvMP_Plus/Resources/Tabs/stats_mouseover.tga",
		"PvMP_Plus/Resources/Tabs/stats_selected.tga",
		"PvMP_Plus/Resources/Tabs/stats_selected_mouseover.tga"
	)
	self.tab_killList = Tab(
		self, L.KillingBlows_Log, 2, 1, "PvMP_Plus/Resources/Tabs/kills.tga",
		"PvMP_Plus/Resources/Tabs/kills_mouseover.tga",
		"PvMP_Plus/Resources/Tabs/kills_selected.tga",
		"PvMP_Plus/Resources/Tabs/kills_selected_mouseover.tga"
	)
	self.tab_barChartPoints = Tab(
		self, L.InfamyRenown, 3, 2, "PvMP_Plus/Resources/Tabs/barChart.tga",
		"PvMP_Plus/Resources/Tabs/barChart_mouseover.tga",
		"PvMP_Plus/Resources/Tabs/barChart_selected.tga",
		"PvMP_Plus/Resources/Tabs/barChart_selected_mouseover.tga"
	)
	self.tab_barChartComms = Tab(
		self, L.Commendations_Short, 4, 3, "PvMP_Plus/Resources/Tabs/barChart.tga",
		"PvMP_Plus/Resources/Tabs/barChart_mouseover.tga",
		"PvMP_Plus/Resources/Tabs/barChart_selected.tga",
		"PvMP_Plus/Resources/Tabs/barChart_selected_mouseover.tga"
	)
	self.tab_barChartFrags = Tab(
		self, L.KillingBlows_Short, 5, 4, "PvMP_Plus/Resources/Tabs/barChart.tga",
		"PvMP_Plus/Resources/Tabs/barChart_mouseover.tga",
		"PvMP_Plus/Resources/Tabs/barChart_selected.tga",
		"PvMP_Plus/Resources/Tabs/barChart_selected_mouseover.tga"
	)
	self.tab_barChartDeaths = Tab(
		self, L.Deaths, 6, 5, "PvMP_Plus/Resources/Tabs/barChart.tga",
		"PvMP_Plus/Resources/Tabs/barChart_mouseover.tga",
		"PvMP_Plus/Resources/Tabs/barChart_selected.tga",
		"PvMP_Plus/Resources/Tabs/barChart_selected_mouseover.tga"
	)
	self.tab_barChartTracks = Tab(
		self, L.Tracks, 7, 6, "PvMP_Plus/Resources/Tabs/barChart.tga",
		"PvMP_Plus/Resources/Tabs/barChart_mouseover.tga",
		"PvMP_Plus/Resources/Tabs/barChart_selected.tga",
		"PvMP_Plus/Resources/Tabs/barChart_selected_mouseover.tga"
	)

	-- Stats Panel
	self.stats_panel = Turbine.UI.Control()
	self.stats_panel:SetParent(self)
	self.stats_panel:SetSize(self:GetWidth() - 50, self:GetHeight() - 90)
	self.stats_panel:SetPosition(self:GetWidth() / 2 - self.stats_panel:GetWidth() / 2, 75)

	-- Rank Labels
	self.rank = Turbine.UI.Label()
	self.rank:SetParent(self.stats_panel)
	self.rank:SetSize(self.stats_panel:GetWidth(), 20)
	self.rank:SetPosition(0, 0)
	self.rank:SetForeColor(default_font_color)
	self.rank:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.rank:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.rank:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.rank:SetText(L.Strings_RankHeader)
	
	self.rank = StatsLabelCenter(self.stats_panel, self.rank:GetTop() + 16)
	self.tier = StatsLabelCenter(self.stats_panel, self.rank:GetTop() + 11)

	-- Points Labels
	self.points = Turbine.UI.Label()
	self.points:SetParent(self.stats_panel)
	self.points:SetSize(self.stats_panel:GetWidth(), 20)
	self.points:SetPosition(0, self.tier:GetTop() + 15)
	self.points:SetForeColor(default_font_color)
	self.points:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.points:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.points:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.points:SetText(L.InfamyRenown)

	self.points_total				= StatsLabelLeft(self.stats_panel, self.points:GetTop() + 16)
	self.points_total_value			= StatsLabelRight(self.stats_panel, self.points:GetTop() + 16)
	self.points_to_rankup			= StatsLabelLeft(self.stats_panel, self.points_total:GetTop() + 11)
	self.points_to_rankup_value		= StatsLabelRight(self.stats_panel, self.points_total:GetTop() + 11)
	self.points_last_24h			= StatsLabelLeft(self.stats_panel, self.points_to_rankup:GetTop() + 11)
	self.points_last_24h_value		= StatsLabelRight(self.stats_panel, self.points_to_rankup:GetTop() + 11)
	self.points_this_day			= StatsLabelLeft(self.stats_panel, self.points_last_24h:GetTop() + 11)
	self.points_this_day_value		= StatsLabelRight(self.stats_panel, self.points_last_24h:GetTop() + 11)
	self.points_last_hour			= StatsLabelLeft(self.stats_panel, self.points_this_day:GetTop() + 11)
	self.points_last_hour_value		= StatsLabelRight(self.stats_panel, self.points_this_day:GetTop() + 11)
	self.points_last_10min			= StatsLabelLeft(self.stats_panel, self.points_last_hour:GetTop() + 11)
	self.points_last_10min_value	= StatsLabelRight(self.stats_panel, self.points_last_hour:GetTop() + 11)
	self.points_last_fight			= StatsLabelLeft(self.stats_panel, self.points_last_10min:GetTop() + 11)
	self.points_last_fight_value	= StatsLabelRight(self.stats_panel, self.points_last_10min:GetTop() + 11)

	-- Commendations Labels
	self.commendations = Turbine.UI.Label()
	self.commendations:SetParent(self.stats_panel)
	self.commendations:SetSize(self.stats_panel:GetWidth(), 20)
	self.commendations:SetPosition(0, self.points_last_fight:GetTop() + 15)
	self.commendations:SetForeColor(default_font_color)
	self.commendations:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.commendations:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.commendations:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.commendations:SetText(L.Comms)

	self.comms_total			= StatsLabelLeft(self.stats_panel, self.commendations:GetTop() + 16)
	self.comms_total_value		= StatsLabelRight(self.stats_panel, self.commendations:GetTop() + 16)
	self.comms_current			= StatsLabelLeft(self.stats_panel, self.comms_total:GetTop() + 11)
	self.comms_current_value	= StatsLabelRight(self.stats_panel, self.comms_total:GetTop() + 11)
	self.comms_last_24h			= StatsLabelLeft(self.stats_panel, self.comms_current:GetTop() + 11)
	self.comms_last_24h_value	= StatsLabelRight(self.stats_panel, self.comms_current:GetTop() + 11)
	self.comms_this_day			= StatsLabelLeft(self.stats_panel, self.comms_last_24h:GetTop() + 11)
	self.comms_this_day_value	= StatsLabelRight(self.stats_panel, self.comms_last_24h:GetTop() + 11)
	self.comms_last_hour		= StatsLabelLeft(self.stats_panel, self.comms_this_day:GetTop() + 11)
	self.comms_last_hour_value	= StatsLabelRight(self.stats_panel, self.comms_this_day:GetTop() + 11)
	self.comms_last_10min		= StatsLabelLeft(self.stats_panel, self.comms_last_hour:GetTop() + 11)
	self.comms_last_10min_value	= StatsLabelRight(self.stats_panel, self.comms_last_hour:GetTop() + 11)
	self.comms_last_fight		= StatsLabelLeft(self.stats_panel, self.comms_last_10min:GetTop() + 11)
	self.comms_last_fight_value	= StatsLabelRight(self.stats_panel, self.comms_last_10min:GetTop() + 11)

	-- Frags Labels
	self.frags = Turbine.UI.Label()
	self.frags:SetParent(self.stats_panel)
	self.frags:SetSize(self.stats_panel:GetWidth(), 20)
	self.frags:SetPosition(0, self.comms_last_fight:GetTop() + 15)
	self.frags:SetForeColor(default_font_color)
	self.frags:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.frags:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.frags:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.frags:SetText(L.KillingBlows)

	self.frags_total			= StatsLabelLeft(self.stats_panel, self.frags:GetTop() + 16)
	self.frags_total_value		= StatsLabelRight(self.stats_panel, self.frags:GetTop() + 16)
	self.frags_to_tierup		= StatsLabelLeft(self.stats_panel, self.frags_total:GetTop() + 11)
	self.frags_to_tierup_value	= StatsLabelRight(self.stats_panel, self.frags_total:GetTop() + 11)
	self.frags_last_24h			= StatsLabelLeft(self.stats_panel, self.frags_to_tierup:GetTop() + 11)
	self.frags_last_24h_value	= StatsLabelRight(self.stats_panel, self.frags_to_tierup:GetTop() + 11)
	self.frags_this_day			= StatsLabelLeft(self.stats_panel, self.frags_last_24h:GetTop() + 11)
	self.frags_this_day_value	= StatsLabelRight(self.stats_panel, self.frags_last_24h:GetTop() + 11)
	self.frags_last_hour		= StatsLabelLeft(self.stats_panel, self.frags_this_day:GetTop() + 11)
	self.frags_last_hour_value	= StatsLabelRight(self.stats_panel, self.frags_this_day:GetTop() + 11)
	self.frags_last_10min		= StatsLabelLeft(self.stats_panel, self.frags_last_hour:GetTop() + 11)
	self.frags_last_10min_value	= StatsLabelRight(self.stats_panel, self.frags_last_hour:GetTop() + 11)
	self.frags_last_fight		= StatsLabelLeft(self.stats_panel, self.frags_last_10min:GetTop() + 11)
	self.frags_last_fight_value	= StatsLabelRight(self.stats_panel, self.frags_last_10min:GetTop() + 11)

	-- Deaths Labels
	self.deaths = Turbine.UI.Label()
	self.deaths:SetParent(self.stats_panel)
	self.deaths:SetSize(self.stats_panel:GetWidth(), 20)
	self.deaths:SetPosition(0, self.frags_last_fight:GetTop() + 15)
	self.deaths:SetForeColor(default_font_color)
	self.deaths:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.deaths:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.deaths:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.deaths:SetText(L.Deaths)

	self.deaths_last_24h			= StatsLabelLeft(self.stats_panel, self.deaths:GetTop() + 16)
	self.deaths_last_24h_value		= StatsLabelRight(self.stats_panel, self.deaths:GetTop() + 16)
	self.deaths_this_day			= StatsLabelLeft(self.stats_panel, self.deaths_last_24h:GetTop() + 11)
	self.deaths_this_day_value		= StatsLabelRight(self.stats_panel, self.deaths_last_24h:GetTop() + 11)
	self.deaths_last_hour			= StatsLabelLeft(self.stats_panel, self.deaths_this_day:GetTop() + 11)
	self.deaths_last_hour_value		= StatsLabelRight(self.stats_panel, self.deaths_this_day:GetTop() + 11)
	self.deaths_last_10min			= StatsLabelLeft(self.stats_panel, self.deaths_last_hour:GetTop() + 11)
	self.deaths_last_10min_value	= StatsLabelRight(self.stats_panel, self.deaths_last_hour:GetTop() + 11)

	-- Tracks Labels
	self.tracks = Turbine.UI.Label()
	self.tracks:SetParent(self.stats_panel)
	self.tracks:SetSize(self.stats_panel:GetWidth(), 20)
	self.tracks:SetPosition(0, self.deaths_last_10min:GetTop() + 15)
	self.tracks:SetForeColor(default_font_color)
	self.tracks:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.tracks:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.tracks:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.tracks:SetText(L.Tracks)

	self.tracks_total				= StatsLabelLeft(self.stats_panel, self.tracks:GetTop() + 16)
	self.tracks_total_value			= StatsLabelRight(self.stats_panel, self.tracks:GetTop() + 16)
	self.tracks_last_24h			= StatsLabelLeft(self.stats_panel, self.tracks_total:GetTop() + 11)
	self.tracks_last_24h_value		= StatsLabelRight(self.stats_panel, self.tracks_total:GetTop() + 11)
	self.tracks_this_day			= StatsLabelLeft(self.stats_panel, self.tracks_last_24h:GetTop() + 11)
	self.tracks_this_day_value		= StatsLabelRight(self.stats_panel, self.tracks_last_24h:GetTop() + 11)
	self.tracks_last_hour			= StatsLabelLeft(self.stats_panel, self.tracks_this_day:GetTop() + 11)
	self.tracks_last_hour_value		= StatsLabelRight(self.stats_panel, self.tracks_this_day:GetTop() + 11)
	self.tracks_last_10min			= StatsLabelLeft(self.stats_panel, self.tracks_last_hour:GetTop() + 11)
	self.tracks_last_10min_value	= StatsLabelRight(self.stats_panel, self.tracks_last_hour:GetTop() + 11)

	-- Frags Log
	self.frag_panel = Turbine.UI.Control()
	self.frag_panel:SetParent(self)
	self.frag_panel:SetSize(self:GetWidth() - 45, self:GetHeight() - 90)
	self.frag_panel:SetPosition(self:GetWidth() / 2 - self.frag_panel:GetWidth() / 2, 78)

	self.search_box_label = Turbine.UI.Label()
	self.search_box_label:SetParent(self.frag_panel)
	self.search_box_label:SetSize(60, 20)
	self.search_box_label:SetPosition(0, 3)
	self.search_box_label:SetForeColor(default_font_color)
	self.search_box_label:SetFont(Turbine.UI.Lotro.Font.TrajanPro18)
	self.search_box_label:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
	self.search_box_label:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.search_box_label:SetText(L.Search)

	self.search_box = Turbine.UI.Lotro.TextBox()
	self.search_box:SetParent(self.frag_panel)
	self.search_box:SetSize(self.frag_panel:GetWidth() - self.search_box_label:GetWidth(), 20)
	self.search_box:SetPosition(self.search_box_label:GetWidth(), 3)
	self.search_box:SetForeColor(default_font_color)
	self.search_box:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.search_box:SetMultiline(false)
	self.search_box.TextChanged = function()
		self:UpdateFragList(self.current_sortmode)
	end

	self.frag_list = Turbine.UI.ListBox()
	self.frag_list:SetParent(self.frag_panel)
	self.frag_list:SetSize(self.frag_panel:GetWidth() - 12, self.frag_panel:GetHeight() - 50)
	self.frag_list:SetPosition(0, 45)

	self.scrollbar_fragList = Turbine.UI.Lotro.ScrollBar()
	self.scrollbar_fragList:SetParent(self.frag_panel)
	self.scrollbar_fragList:SetOrientation(Turbine.UI.Orientation.Vertical)
	self.scrollbar_fragList:SetSize(10, self.frag_list:GetHeight())
	self.scrollbar_fragList:SetPosition(self.frag_list:GetLeft() + self.frag_list:GetWidth() + 2, self.frag_list:GetTop())
	self.frag_list:SetVerticalScrollBar(self.scrollbar_fragList)

	self.name_label = Turbine.UI.Label()
	self.name_label:SetParent(self.frag_panel)
	self.name_label:SetFont(Turbine.UI.Lotro.Font.TrajanPro16)
	self.name_label:SetSize(self.frag_list:GetWidth() / 2, 20)
	self.name_label:SetPosition(0, 25)
	self.name_label:SetForeColor(default_font_color)
	self.name_label:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.name_label:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
	self.name_label:SetText(L.Name)

	self.name_label.MouseDown = function()
		if self.current_sortmode == alphabetical_desc then
			self:SortFragList(alphabetical_asc)
		else
			self:SortFragList(alphabetical_desc)
		end
	end

	self.frags_label = Turbine.UI.Label()
	self.frags_label:SetParent(self.frag_panel)
	self.frags_label:SetFont(Turbine.UI.Lotro.Font.TrajanPro16)
	self.frags_label:SetSize(self.frag_list:GetWidth() / 2, 20)
	self.frags_label:SetPosition(self.name_label:GetWidth(), 25)
	self.frags_label:SetForeColor(default_font_color)
	self.frags_label:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.frags_label:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
	self.frags_label:SetText(L.AmountFrags)

	self.frags_label.MouseDown = function()
		if self.current_sortmode == kills_desc then
			self:SortFragList(kills_asc)
		else
			self:SortFragList(kills_desc)
		end
	end

	-- Points Bar Chart Panel
	self.barChartPoints_panel = Turbine.UI.Control()
	self.barChartPoints_panel:SetParent(self)
	self.barChartPoints_panel:SetSize(self:GetWidth() - 50, self:GetHeight() - 100)
	self.barChartPoints_panel:SetPosition(self:GetWidth() / 2 - self.barChartPoints_panel:GetWidth() / 2, 80)

	-- Points Diagram - Month
	self.barChart_points_heading = Turbine.UI.Label()
	self.barChart_points_heading:SetParent(self.barChartPoints_panel)
	self.barChart_points_heading:SetSize(self.barChartPoints_panel:GetWidth(), 25)
	self.barChart_points_heading:SetForeColor(default_font_color)
	self.barChart_points_heading:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.barChart_points_heading:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.barChart_points_heading:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.barChart_points_heading:SetText(L.InfamyRenown.." "..L.Stats_Last_Month)

	self.barChart_points = Turbine.UI.ListBox()
	self.barChart_points:SetParent(self.barChartPoints_panel)
	self.barChart_points:SetSize(self.barChartPoints_panel:GetWidth(), 160)
	self.barChart_points:SetOrientation(Turbine.UI.Orientation.Horizontal)
	self.barChart_points:SetTop(self.barChart_points_heading:GetHeight())

	self.scrollbar_barChart = Turbine.UI.Lotro.ScrollBar()
	self.scrollbar_barChart:SetParent(self.barChartPoints_panel)
	self.scrollbar_barChart:SetOrientation(Turbine.UI.Orientation.Vertical)
	self.scrollbar_barChart:SetSize(self.barChart_points:GetWidth(), 10)
	self.scrollbar_barChart:SetOrientation(Turbine.UI.Orientation.Horizontal)
	self.scrollbar_barChart:SetPosition(self.barChart_points:GetLeft(), self.barChart_points:GetTop() + self.barChart_points:GetHeight())
	self.barChart_points:SetHorizontalScrollBar(self.scrollbar_barChart)

	self.topline_points = Turbine.UI.Control()
	self.topline_points:SetParent(self.barChart_points)
	self.topline_points:SetSize(self.barChart_points:GetWidth(), 1)
	self.topline_points:SetBackColor(Turbine.UI.Color.White)
	self.topline_points_label = Turbine.UI.Label()
	self.topline_points_label:SetParent(self.barChart_points)
	self.topline_points_label:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.topline_points_label:SetText(topline_points_value)
	self.topline_points_label:SetSize(50, 12)

	self.bottomline_points = Turbine.UI.Control()
	self.bottomline_points:SetParent(self.barChart_points)
	self.bottomline_points:SetSize(self.barChart_points:GetWidth(), 1)
	self.bottomline_points:SetBackColor(Turbine.UI.Color.White)
	self.bottomline_points_label = Turbine.UI.Label()
	self.bottomline_points_label:SetParent(self.barChart_points)
	self.bottomline_points_label:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.bottomline_points_label:SetSize(50, 12)

	self.horiz_separator_points = Turbine.UI.Control()
	self.horiz_separator_points:SetParent(self.barChart_points)
	self.horiz_separator_points:SetSize(self.barChart_points:GetWidth(), 1)
	self.horiz_separator_points:SetBackColor(Turbine.UI.Color.White)
	self.horiz_separator_points:SetTop(self.barChart_points:GetHeight() - 24)

	self.hopping_points_day = Turbine.UI.Label()
	self.hopping_points_day:SetParent(self)
	self.hopping_points_day:SetSize(50, 12)
	self.hopping_points_day:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.hopping_points_day:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.hopping_points_day:SetOutlineColor(Turbine.UI.Color.Black)
	self.hopping_points_day:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.hopping_points_day:SetVisible(false)

	-- Points Diagram - Year
	self.barChart_points_heading2 = Turbine.UI.Label()
	self.barChart_points_heading2:SetParent(self.barChartPoints_panel)
	self.barChart_points_heading2:SetSize(self.barChartPoints_panel:GetWidth(), 15)
	self.barChart_points_heading2:SetPosition(0, self.scrollbar_barChart:GetTop() + self.scrollbar_barChart:GetHeight() + 15)
	self.barChart_points_heading2:SetForeColor(default_font_color)
	self.barChart_points_heading2:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.barChart_points_heading2:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.barChart_points_heading2:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.barChart_points_heading2:SetText(L.InfamyRenown.." "..L.Stats_Last_Year)

	self.barChart_points2 = Turbine.UI.ListBox()
	self.barChart_points2:SetParent(self.barChartPoints_panel)
	self.barChart_points2:SetSize(self.barChartPoints_panel:GetWidth(), 160)
	self.barChart_points2:SetTop(self.barChart_points_heading2:GetTop() + self.barChart_points_heading2:GetHeight())
	self.barChart_points2:SetOrientation(Turbine.UI.Orientation.Horizontal)

	self.scrollbar_barChart2 = Turbine.UI.Lotro.ScrollBar()
	self.scrollbar_barChart2:SetParent(self.barChartPoints_panel)
	self.scrollbar_barChart2:SetOrientation(Turbine.UI.Orientation.Vertical)
	self.scrollbar_barChart2:SetSize(self.barChart_points2:GetWidth(), 10)
	self.scrollbar_barChart2:SetOrientation(Turbine.UI.Orientation.Horizontal)
	self.scrollbar_barChart2:SetPosition(self.barChart_points2:GetLeft(), self.barChart_points2:GetTop() + self.barChart_points2:GetHeight())
	self.barChart_points2:SetHorizontalScrollBar(self.scrollbar_barChart2)

	self.topline_points2 = Turbine.UI.Control()
	self.topline_points2:SetParent(self.barChart_points2)
	self.topline_points2:SetSize(self.barChart_points2:GetWidth(), 1)
	self.topline_points2:SetBackColor(Turbine.UI.Color.White)
	self.topline_points_label2 = Turbine.UI.Label()
	self.topline_points_label2:SetParent(self.barChart_points2)
	self.topline_points_label2:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.topline_points_label2:SetText(topline_points_value)
	self.topline_points_label2:SetSize(50, 12)

	self.bottomline_points2 = Turbine.UI.Control()
	self.bottomline_points2:SetParent(self.barChart_points2)
	self.bottomline_points2:SetSize(self.barChart_points2:GetWidth(), 1)
	self.bottomline_points2:SetBackColor(Turbine.UI.Color.White)
	self.bottomline_points_label2 = Turbine.UI.Label()
	self.bottomline_points_label2:SetParent(self.barChart_points2)
	self.bottomline_points_label2:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.bottomline_points_label2:SetSize(50, 12)

	self.horiz_separator_points2 = Turbine.UI.Control()
	self.horiz_separator_points2:SetParent(self.barChart_points2)
	self.horiz_separator_points2:SetSize(self.barChart_points2:GetWidth(), 1)
	self.horiz_separator_points2:SetBackColor(Turbine.UI.Color.White)
	self.horiz_separator_points2:SetTop(self.barChart_points2:GetHeight() - 24)

	self.hopping_points_month = Turbine.UI.Label()
	self.hopping_points_month:SetParent(self)
	self.hopping_points_month:SetSize(50, 12)
	self.hopping_points_month:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.hopping_points_month:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.hopping_points_month:SetOutlineColor(Turbine.UI.Color.Black)
	self.hopping_points_month:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.hopping_points_month:SetVisible(false)

	self.hopping_points_month_day_avg = Turbine.UI.Label()
	self.hopping_points_month_day_avg:SetParent(self)
	self.hopping_points_month_day_avg:SetSize(50, 12)
	self.hopping_points_month_day_avg:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.hopping_points_month_day_avg:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.hopping_points_month_day_avg:SetOutlineColor(Turbine.UI.Color.Black)
	self.hopping_points_month_day_avg:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.hopping_points_month_day_avg:SetMouseVisible(false)
	self.hopping_points_month_day_avg:SetVisible(false)

	-- Points Diagram - Stats
	self.points_stats = Turbine.UI.Label()
	self.points_stats:SetParent(self.barChartPoints_panel)
	self.points_stats:SetSize(self.barChartPoints_panel:GetWidth(), 20)
	self.points_stats:SetPosition(0, self.scrollbar_barChart2:GetTop() + self.scrollbar_barChart2:GetHeight() + 3)
	self.points_stats:SetForeColor(default_font_color)
	self.points_stats:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.points_stats:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.points_stats:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.points_stats:SetText(L.Statistics)

	self.most_points_fight = Turbine.UI.Label()
	self.most_points_fight:SetParent(self.barChartPoints_panel)
	self.most_points_fight:SetSize(self.barChartPoints_panel:GetWidth(), 12)
	self.most_points_fight:SetTop(self.points_stats:GetTop() + 18)
	self.most_points_fight:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.most_points_fight:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)

	self.most_points_day = Turbine.UI.Label()
	self.most_points_day:SetParent(self.barChartPoints_panel)
	self.most_points_day:SetSize(self.barChartPoints_panel:GetWidth(), 12)
	self.most_points_day:SetTop(self.most_points_fight:GetTop() + 13)
	self.most_points_day:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.most_points_day:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)

	self.most_points_month = Turbine.UI.Label()
	self.most_points_month:SetParent(self.barChartPoints_panel)
	self.most_points_month:SetSize(self.barChartPoints_panel:GetWidth(), 12)
	self.most_points_month:SetTop(self.most_points_day:GetTop() + 13)
	self.most_points_month:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.most_points_month:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)

	self.points_per_frag = Turbine.UI.Label()
	self.points_per_frag:SetParent(self.barChartPoints_panel)
	self.points_per_frag:SetSize(self.barChartPoints_panel:GetWidth(), 12)
	self.points_per_frag:SetTop(self.most_points_month:GetTop() + 18)
	self.points_per_frag:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.points_per_frag:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.points_per_frag:SetVisible(false)

	-- Frags Bar Chart Panel
	self.barChartFrags_panel = Turbine.UI.Control()
	self.barChartFrags_panel:SetParent(self)
	self.barChartFrags_panel:SetSize(self:GetWidth() - 50, self:GetHeight() - 100)
	self.barChartFrags_panel:SetPosition(self:GetWidth() / 2 - self.barChartFrags_panel:GetWidth() / 2, 80)

	-- Frag Diagram - Month
	self.barChart_frags_heading = Turbine.UI.Label()
	self.barChart_frags_heading:SetParent(self.barChartFrags_panel)
	self.barChart_frags_heading:SetSize(self.barChartFrags_panel:GetWidth(), 25)
	self.barChart_frags_heading:SetForeColor(default_font_color)
	self.barChart_frags_heading:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.barChart_frags_heading:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.barChart_frags_heading:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.barChart_frags_heading:SetText(L.KillingBlows.." "..L.Stats_Last_Month)

	self.barChart_frags = Turbine.UI.ListBox()
	self.barChart_frags:SetParent(self.barChartFrags_panel)
	self.barChart_frags:SetSize(self.barChartFrags_panel:GetWidth(), 160)
	self.barChart_frags:SetTop(self.barChart_frags_heading:GetTop() + self.barChart_frags_heading:GetHeight())
	self.barChart_frags:SetOrientation(Turbine.UI.Orientation.Horizontal)

	self.scrollbar_barChart = Turbine.UI.Lotro.ScrollBar()
	self.scrollbar_barChart:SetParent(self.barChartFrags_panel)
	self.scrollbar_barChart:SetOrientation(Turbine.UI.Orientation.Vertical)
	self.scrollbar_barChart:SetSize(self.barChart_frags:GetWidth(), 10)
	self.scrollbar_barChart:SetOrientation(Turbine.UI.Orientation.Horizontal)
	self.scrollbar_barChart:SetPosition(self.barChart_frags:GetLeft(), self.barChart_frags:GetTop() + self.barChart_frags:GetHeight())
	self.barChart_frags:SetHorizontalScrollBar(self.scrollbar_barChart)

	self.topline_frags = Turbine.UI.Control()
	self.topline_frags:SetParent(self.barChart_frags)
	self.topline_frags:SetSize(self.barChart_frags:GetWidth(), 1)
	self.topline_frags:SetBackColor(Turbine.UI.Color.White)
	self.topline_frags_label = Turbine.UI.Label()
	self.topline_frags_label:SetParent(self.barChart_frags)
	self.topline_frags_label:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.topline_frags_label:SetText(topline_points_value)
	self.topline_frags_label:SetSize(50, 12)

	self.bottomline_frags = Turbine.UI.Control()
	self.bottomline_frags:SetParent(self.barChart_frags)
	self.bottomline_frags:SetSize(self.barChart_frags:GetWidth(), 1)
	self.bottomline_frags:SetBackColor(Turbine.UI.Color.White)
	self.bottomline_frags_label = Turbine.UI.Label()
	self.bottomline_frags_label:SetParent(self.barChart_frags)
	self.bottomline_frags_label:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.bottomline_frags_label:SetSize(50, 12)

	self.horiz_separator_frags = Turbine.UI.Control()
	self.horiz_separator_frags:SetParent(self.barChart_frags)
	self.horiz_separator_frags:SetSize(self.barChart_frags:GetWidth(), 1)
	self.horiz_separator_frags:SetBackColor(Turbine.UI.Color.White)
	self.horiz_separator_frags:SetTop(self.barChart_frags:GetHeight() - 24)

	self.hopping_frags_day = Turbine.UI.Label()
	self.hopping_frags_day:SetParent(self)
	self.hopping_frags_day:SetSize(50, 12)
	self.hopping_frags_day:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.hopping_frags_day:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.hopping_frags_day:SetOutlineColor(Turbine.UI.Color.Black)
	self.hopping_frags_day:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.hopping_frags_day:SetVisible(false)

	-- Frags Diagram - Year
	self.barChart_frags_heading2 = Turbine.UI.Label()
	self.barChart_frags_heading2:SetParent(self.barChartFrags_panel)
	self.barChart_frags_heading2:SetSize(self.barChartFrags_panel:GetWidth(), 15)
	self.barChart_frags_heading2:SetPosition(0, self.scrollbar_barChart:GetTop() + self.scrollbar_barChart:GetHeight() + 15)
	self.barChart_frags_heading2:SetForeColor(default_font_color)
	self.barChart_frags_heading2:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.barChart_frags_heading2:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.barChart_frags_heading2:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.barChart_frags_heading2:SetText(L.KillingBlows.." "..L.Stats_Last_Year)

	self.barChart_frags2 = Turbine.UI.ListBox()
	self.barChart_frags2:SetParent(self.barChartFrags_panel)
	self.barChart_frags2:SetSize(self.barChartFrags_panel:GetWidth(), 160)
	self.barChart_frags2:SetTop(self.barChart_frags_heading2:GetTop() + self.barChart_frags_heading2:GetHeight())
	self.barChart_frags2:SetOrientation(Turbine.UI.Orientation.Horizontal)

	self.scrollbar_barChart2 = Turbine.UI.Lotro.ScrollBar()
	self.scrollbar_barChart2:SetParent(self.barChartFrags_panel)
	self.scrollbar_barChart2:SetOrientation(Turbine.UI.Orientation.Vertical)
	self.scrollbar_barChart2:SetSize(self.barChart_frags2:GetWidth(), 10)
	self.scrollbar_barChart2:SetOrientation(Turbine.UI.Orientation.Horizontal)
	self.scrollbar_barChart2:SetPosition(self.barChart_frags2:GetLeft(), self.barChart_frags2:GetTop() + self.barChart_frags2:GetHeight())
	self.barChart_frags2:SetHorizontalScrollBar(self.scrollbar_barChart2)

	self.topline_frags2 = Turbine.UI.Control()
	self.topline_frags2:SetParent(self.barChart_frags2)
	self.topline_frags2:SetSize(self.barChart_frags2:GetWidth(), 1)
	self.topline_frags2:SetBackColor(Turbine.UI.Color.White)
	self.topline_frags_label2 = Turbine.UI.Label()
	self.topline_frags_label2:SetParent(self.barChart_frags2)
	self.topline_frags_label2:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.topline_frags_label2:SetText(topline_frags_value)
	self.topline_frags_label2:SetSize(50, 12)
  
	self.bottomline_frags2 = Turbine.UI.Control()
	self.bottomline_frags2:SetParent(self.barChart_frags2)
	self.bottomline_frags2:SetSize(self.barChart_frags2:GetWidth(), 1)
	self.bottomline_frags2:SetBackColor(Turbine.UI.Color.White)
	self.bottomline_frags_label2 = Turbine.UI.Label()
	self.bottomline_frags_label2:SetParent(self.barChart_frags2)
	self.bottomline_frags_label2:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.bottomline_frags_label2:SetSize(50, 12)

	self.horiz_separator_frags2 = Turbine.UI.Control()
	self.horiz_separator_frags2:SetParent(self.barChart_frags2)
	self.horiz_separator_frags2:SetSize(self.barChart_frags2:GetWidth(), 1)
	self.horiz_separator_frags2:SetBackColor(Turbine.UI.Color.White)
	self.horiz_separator_frags2:SetTop(self.barChart_frags2:GetHeight() - 24)

	self.hopping_frags_month = Turbine.UI.Label()
	self.hopping_frags_month:SetParent(self)
	self.hopping_frags_month:SetSize(50, 12)
	self.hopping_frags_month:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.hopping_frags_month:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.hopping_frags_month:SetOutlineColor(Turbine.UI.Color.Black)
	self.hopping_frags_month:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.hopping_frags_month:SetVisible(false)

	self.hopping_frags_month_day_avg = Turbine.UI.Label()
	self.hopping_frags_month_day_avg:SetParent(self)
	self.hopping_frags_month_day_avg:SetSize(50, 12)
	self.hopping_frags_month_day_avg:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.hopping_frags_month_day_avg:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.hopping_frags_month_day_avg:SetOutlineColor(Turbine.UI.Color.Black)
	self.hopping_frags_month_day_avg:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.hopping_frags_month_day_avg:SetMouseVisible(false)
	self.hopping_frags_month_day_avg:SetVisible(false)

	-- Frags Diagram - Stats
	self.frags_stats = Turbine.UI.Label()
	self.frags_stats:SetParent(self.barChartFrags_panel)
	self.frags_stats:SetSize(self.barChartFrags_panel:GetWidth(), 20)
	self.frags_stats:SetPosition(0, self.scrollbar_barChart2:GetTop() + self.scrollbar_barChart2:GetHeight() + 3)
	self.frags_stats:SetForeColor(default_font_color)
	self.frags_stats:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.frags_stats:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.frags_stats:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.frags_stats:SetText(L.Statistics)

	self.most_frags_day = Turbine.UI.Label()
	self.most_frags_day:SetParent(self.barChartFrags_panel)
	self.most_frags_day:SetSize(self.barChartFrags_panel:GetWidth(), 12)
	self.most_frags_day:SetTop(self.frags_stats:GetTop() + 18)
	self.most_frags_day:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.most_frags_day:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)

	self.most_frags_month = Turbine.UI.Label()
	self.most_frags_month:SetParent(self.barChartFrags_panel)
	self.most_frags_month:SetSize(self.barChartFrags_panel:GetWidth(), 12)
	self.most_frags_month:SetTop(self.most_frags_day:GetTop() + 13)
	self.most_frags_month:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.most_frags_month:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)

	self.frags_per_death = Turbine.UI.Label()
	self.frags_per_death:SetParent(self.barChartFrags_panel)
	self.frags_per_death:SetSize(self.barChartFrags_panel:GetWidth(), 12)
	self.frags_per_death:SetTop(self.most_frags_month:GetTop() + 18)
	self.frags_per_death:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.frags_per_death:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.frags_per_death:SetVisible(false)

	-- Commendations Bar Chart Panel
	self.barChartComms_panel = Turbine.UI.Control()
	self.barChartComms_panel:SetParent(self)
	self.barChartComms_panel:SetSize(self:GetWidth() - 50, self:GetHeight() - 100)
	self.barChartComms_panel:SetPosition(self:GetWidth() / 2 - self.barChartComms_panel:GetWidth() / 2, 80)
	
	-- Commendations Diagram - Month
	self.barChart_comms_heading = Turbine.UI.Label()
	self.barChart_comms_heading:SetParent(self.barChartComms_panel)
	self.barChart_comms_heading:SetSize(self.barChartComms_panel:GetWidth(), 25)
	self.barChart_comms_heading:SetForeColor(default_font_color)
	self.barChart_comms_heading:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.barChart_comms_heading:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.barChart_comms_heading:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.barChart_comms_heading:SetText(L.Comms.." "..L.Stats_Last_Month)

	self.barChart_comms = Turbine.UI.ListBox()
	self.barChart_comms:SetParent(self.barChartComms_panel)
	self.barChart_comms:SetSize(self.barChartComms_panel:GetWidth(), 160)
	self.barChart_comms:SetOrientation(Turbine.UI.Orientation.Horizontal)
	self.barChart_comms:SetTop(self.barChart_comms_heading:GetHeight())

	self.scrollbar_barChart = Turbine.UI.Lotro.ScrollBar()
	self.scrollbar_barChart:SetParent(self.barChartComms_panel)
	self.scrollbar_barChart:SetOrientation(Turbine.UI.Orientation.Vertical)
	self.scrollbar_barChart:SetSize(self.barChart_comms:GetWidth(), 10)
	self.scrollbar_barChart:SetOrientation(Turbine.UI.Orientation.Horizontal)
	self.scrollbar_barChart:SetPosition(self.barChart_comms:GetLeft(), self.barChart_comms:GetTop() + self.barChart_comms:GetHeight())
	self.barChart_comms:SetHorizontalScrollBar(self.scrollbar_barChart)

	self.topline_comms = Turbine.UI.Control()
	self.topline_comms:SetParent(self.barChart_comms)
	self.topline_comms:SetSize(self.barChart_comms:GetWidth(), 1)
	self.topline_comms:SetBackColor(Turbine.UI.Color.White)
	self.topline_comms_label = Turbine.UI.Label()
	self.topline_comms_label:SetParent(self.barChart_comms)
	self.topline_comms_label:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.topline_comms_label:SetText(topline_comms_value)
	self.topline_comms_label:SetSize(50, 12)

	self.bottomline_comms = Turbine.UI.Control()
	self.bottomline_comms:SetParent(self.barChart_comms)
	self.bottomline_comms:SetSize(self.barChart_comms:GetWidth(), 1)
	self.bottomline_comms:SetBackColor(Turbine.UI.Color.White)
	self.bottomline_comms_label = Turbine.UI.Label()
	self.bottomline_comms_label:SetParent(self.barChart_comms)
	self.bottomline_comms_label:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.bottomline_comms_label:SetSize(50, 12)

	self.horiz_separator_comms = Turbine.UI.Control()
	self.horiz_separator_comms:SetParent(self.barChart_comms)
	self.horiz_separator_comms:SetSize(self.barChart_comms:GetWidth(), 1)
	self.horiz_separator_comms:SetBackColor(Turbine.UI.Color.White)
	self.horiz_separator_comms:SetTop(self.barChart_comms:GetHeight() - 24)

	self.hopping_comms_day = Turbine.UI.Label()
	self.hopping_comms_day:SetParent(self)
	self.hopping_comms_day:SetSize(50, 12)
	self.hopping_comms_day:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.hopping_comms_day:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.hopping_comms_day:SetOutlineColor(Turbine.UI.Color.Black)
	self.hopping_comms_day:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.hopping_comms_day:SetVisible(false)

	-- Commendations Diagram - Year
	self.barChart_comms_heading2 = Turbine.UI.Label()
	self.barChart_comms_heading2:SetParent(self.barChartComms_panel)
	self.barChart_comms_heading2:SetSize(self.barChartComms_panel:GetWidth(), 15)
	self.barChart_comms_heading2:SetPosition(0, self.scrollbar_barChart:GetTop() + self.scrollbar_barChart:GetHeight() + 15)
	self.barChart_comms_heading2:SetForeColor(default_font_color)
	self.barChart_comms_heading2:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.barChart_comms_heading2:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.barChart_comms_heading2:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.barChart_comms_heading2:SetText(L.Comms.." "..L.Stats_Last_Year)

	self.barChart_comms2 = Turbine.UI.ListBox()
	self.barChart_comms2:SetParent(self.barChartComms_panel)
	self.barChart_comms2:SetSize(self.barChartComms_panel:GetWidth(), 160)
	self.barChart_comms2:SetTop(self.barChart_comms_heading2:GetTop() + self.barChart_comms_heading2:GetHeight())
	self.barChart_comms2:SetOrientation(Turbine.UI.Orientation.Horizontal)

	self.scrollbar_barChart2 = Turbine.UI.Lotro.ScrollBar()
	self.scrollbar_barChart2:SetParent(self.barChartComms_panel)
	self.scrollbar_barChart2:SetOrientation(Turbine.UI.Orientation.Vertical)
	self.scrollbar_barChart2:SetSize(self.barChart_comms2:GetWidth(), 10)
	self.scrollbar_barChart2:SetOrientation(Turbine.UI.Orientation.Horizontal)
	self.scrollbar_barChart2:SetPosition(self.barChart_comms2:GetLeft(), self.barChart_comms2:GetTop() + self.barChart_comms2:GetHeight())
	self.barChart_comms2:SetHorizontalScrollBar(self.scrollbar_barChart2)

	self.topline_comms2 = Turbine.UI.Control()
	self.topline_comms2:SetParent(self.barChart_comms2)
	self.topline_comms2:SetSize(self.barChart_comms2:GetWidth(), 1)
	self.topline_comms2:SetBackColor(Turbine.UI.Color.White)
	self.topline_comms_label2 = Turbine.UI.Label()
	self.topline_comms_label2:SetParent(self.barChart_comms2)
	self.topline_comms_label2:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.topline_comms_label2:SetText(topline_frags_value)
	self.topline_comms_label2:SetSize(50, 12)
  
	self.bottomline_comms2 = Turbine.UI.Control()
	self.bottomline_comms2:SetParent(self.barChart_comms2)
	self.bottomline_comms2:SetSize(self.barChart_comms2:GetWidth(), 1)
	self.bottomline_comms2:SetBackColor(Turbine.UI.Color.White)
	self.bottomline_comms_label2 = Turbine.UI.Label()
	self.bottomline_comms_label2:SetParent(self.barChart_comms2)
	self.bottomline_comms_label2:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.bottomline_comms_label2:SetSize(50, 12)

	self.horiz_separator_comms2 = Turbine.UI.Control()
	self.horiz_separator_comms2:SetParent(self.barChart_comms2)
	self.horiz_separator_comms2:SetSize(self.barChart_comms2:GetWidth(), 1)
	self.horiz_separator_comms2:SetBackColor(Turbine.UI.Color.White)
	self.horiz_separator_comms2:SetTop(self.barChart_comms2:GetHeight() - 24)

	self.hopping_comms_month = Turbine.UI.Label()
	self.hopping_comms_month:SetParent(self)
	self.hopping_comms_month:SetSize(50, 12)
	self.hopping_comms_month:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.hopping_comms_month:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.hopping_comms_month:SetOutlineColor(Turbine.UI.Color.Black)
	self.hopping_comms_month:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.hopping_comms_month:SetVisible(false)

	self.hopping_comms_month_day_avg = Turbine.UI.Label()
	self.hopping_comms_month_day_avg:SetParent(self)
	self.hopping_comms_month_day_avg:SetSize(50, 12)
	self.hopping_comms_month_day_avg:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.hopping_comms_month_day_avg:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.hopping_comms_month_day_avg:SetOutlineColor(Turbine.UI.Color.Black)
	self.hopping_comms_month_day_avg:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.hopping_comms_month_day_avg:SetMouseVisible(false)
	self.hopping_comms_month_day_avg:SetVisible(false)

	-- Commendations Diagram - Stats
	self.comms_stats = Turbine.UI.Label()
	self.comms_stats:SetParent(self.barChartComms_panel)
	self.comms_stats:SetSize(self.barChartComms_panel:GetWidth(), 20)
	self.comms_stats:SetPosition(0, self.scrollbar_barChart2:GetTop() + self.scrollbar_barChart2:GetHeight() + 3)
	self.comms_stats:SetForeColor(default_font_color)
	self.comms_stats:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.comms_stats:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.comms_stats:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.comms_stats:SetText(L.Statistics)

	self.most_comms_day = Turbine.UI.Label()
	self.most_comms_day:SetParent(self.barChartComms_panel)
	self.most_comms_day:SetSize(self.barChartComms_panel:GetWidth(), 12)
	self.most_comms_day:SetTop(self.comms_stats:GetTop() + 18)
	self.most_comms_day:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.most_comms_day:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)

	self.most_comms_month = Turbine.UI.Label()
	self.most_comms_month:SetParent(self.barChartComms_panel)
	self.most_comms_month:SetSize(self.barChartComms_panel:GetWidth(), 12)
	self.most_comms_month:SetTop(self.most_comms_day:GetTop() + 13)
	self.most_comms_month:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.most_comms_month:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)

	-- Tracks Bar Chart Panel
	self.barChartTracks_panel = Turbine.UI.Control()
	self.barChartTracks_panel:SetParent(self)
	self.barChartTracks_panel:SetSize(self:GetWidth() - 50, self:GetHeight() - 100)
	self.barChartTracks_panel:SetPosition(self:GetWidth() / 2 - self.barChartTracks_panel:GetWidth() / 2, 80)

	-- Tracks Diagram - Month
	self.barChart_tracks_heading = Turbine.UI.Label()
	self.barChart_tracks_heading:SetParent(self.barChartTracks_panel)
	self.barChart_tracks_heading:SetSize(self.barChartTracks_panel:GetWidth(), 25)
	self.barChart_tracks_heading:SetForeColor(default_font_color)
	self.barChart_tracks_heading:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.barChart_tracks_heading:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.barChart_tracks_heading:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.barChart_tracks_heading:SetText(L.Tracks.." "..L.Stats_Last_Month)

	self.barChart_tracks = Turbine.UI.ListBox()
	self.barChart_tracks:SetParent(self.barChartTracks_panel)
	self.barChart_tracks:SetSize(self.barChartTracks_panel:GetWidth(), 160)
	self.barChart_tracks:SetTop(self.barChart_frags_heading:GetTop() + self.barChart_frags_heading:GetHeight())
	self.barChart_tracks:SetOrientation(Turbine.UI.Orientation.Horizontal)

	self.scrollbar_barChart = Turbine.UI.Lotro.ScrollBar()
	self.scrollbar_barChart:SetParent(self.barChartTracks_panel)
	self.scrollbar_barChart:SetOrientation(Turbine.UI.Orientation.Vertical)
	self.scrollbar_barChart:SetSize(self.barChart_tracks:GetWidth(), 10)
	self.scrollbar_barChart:SetOrientation(Turbine.UI.Orientation.Horizontal)
	self.scrollbar_barChart:SetPosition(self.barChart_tracks:GetLeft(), self.barChart_tracks:GetTop() + self.barChart_tracks:GetHeight())
	self.barChart_tracks:SetHorizontalScrollBar(self.scrollbar_barChart)

	self.topline_tracks = Turbine.UI.Control()
	self.topline_tracks:SetParent(self.barChart_tracks)
	self.topline_tracks:SetSize(self.barChart_tracks:GetWidth(), 1)
	self.topline_tracks:SetBackColor(Turbine.UI.Color.White)
	self.topline_tracks_label = Turbine.UI.Label()
	self.topline_tracks_label:SetParent(self.barChart_tracks)
	self.topline_tracks_label:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.topline_tracks_label:SetText(topline_points_value)
	self.topline_tracks_label:SetSize(50, 12)

	self.bottomline_tracks = Turbine.UI.Control()
	self.bottomline_tracks:SetParent(self.barChart_tracks)
	self.bottomline_tracks:SetSize(self.barChart_tracks:GetWidth(), 1)
	self.bottomline_tracks:SetBackColor(Turbine.UI.Color.White)
	self.bottomline_tracks_label = Turbine.UI.Label()
	self.bottomline_tracks_label:SetParent(self.barChart_tracks)
	self.bottomline_tracks_label:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.bottomline_tracks_label:SetSize(50, 12)

	self.horiz_separator_tracks = Turbine.UI.Control()
	self.horiz_separator_tracks:SetParent(self.barChart_tracks)
	self.horiz_separator_tracks:SetSize(self.barChart_tracks:GetWidth(), 1)
	self.horiz_separator_tracks:SetBackColor(Turbine.UI.Color.White)
	self.horiz_separator_tracks:SetTop(self.barChart_tracks:GetHeight() - 24)

	self.hopping_tracks_day = Turbine.UI.Label()
	self.hopping_tracks_day:SetParent(self)
	self.hopping_tracks_day:SetSize(50, 12)
	self.hopping_tracks_day:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.hopping_tracks_day:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.hopping_tracks_day:SetOutlineColor(Turbine.UI.Color.Black)
	self.hopping_tracks_day:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.hopping_tracks_day:SetVisible(false)

	-- Tracks Diagram - Year
	self.barChart_tracks_heading2 = Turbine.UI.Label()
	self.barChart_tracks_heading2:SetParent(self.barChartTracks_panel)
	self.barChart_tracks_heading2:SetSize(self.barChartTracks_panel:GetWidth(), 15)
	self.barChart_tracks_heading2:SetPosition(0, self.scrollbar_barChart:GetTop() + self.scrollbar_barChart:GetHeight() + 15)
	self.barChart_tracks_heading2:SetForeColor(default_font_color)
	self.barChart_tracks_heading2:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.barChart_tracks_heading2:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.barChart_tracks_heading2:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.barChart_tracks_heading2:SetText(L.Tracks.." "..L.Stats_Last_Year)

	self.barChart_tracks2 = Turbine.UI.ListBox()
	self.barChart_tracks2:SetParent(self.barChartTracks_panel)
	self.barChart_tracks2:SetSize(self.barChartTracks_panel:GetWidth(), 160)
	self.barChart_tracks2:SetTop(self.barChart_tracks_heading2:GetTop() + self.barChart_tracks_heading2:GetHeight())
	self.barChart_tracks2:SetOrientation(Turbine.UI.Orientation.Horizontal)

	self.scrollbar_barChart2 = Turbine.UI.Lotro.ScrollBar()
	self.scrollbar_barChart2:SetParent(self.barChartTracks_panel)
	self.scrollbar_barChart2:SetOrientation(Turbine.UI.Orientation.Vertical)
	self.scrollbar_barChart2:SetSize(self.barChart_tracks2:GetWidth(), 10)
	self.scrollbar_barChart2:SetOrientation(Turbine.UI.Orientation.Horizontal)
	self.scrollbar_barChart2:SetPosition(self.barChart_tracks2:GetLeft(), self.barChart_tracks2:GetTop() + self.barChart_tracks2:GetHeight())
	self.barChart_tracks2:SetHorizontalScrollBar(self.scrollbar_barChart2)

	self.topline_tracks2 = Turbine.UI.Control()
	self.topline_tracks2:SetParent(self.barChart_tracks2)
	self.topline_tracks2:SetSize(self.barChart_tracks2:GetWidth(), 1)
	self.topline_tracks2:SetBackColor(Turbine.UI.Color.White)
	self.topline_tracks_label2 = Turbine.UI.Label()
	self.topline_tracks_label2:SetParent(self.barChart_tracks2)
	self.topline_tracks_label2:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.topline_tracks_label2:SetText(topline_frags_value)
	self.topline_tracks_label2:SetSize(50, 12)
  
	self.bottomline_tracks2 = Turbine.UI.Control()
	self.bottomline_tracks2:SetParent(self.barChart_tracks2)
	self.bottomline_tracks2:SetSize(self.barChart_tracks2:GetWidth(), 1)
	self.bottomline_tracks2:SetBackColor(Turbine.UI.Color.White)
	self.bottomline_tracks_label2 = Turbine.UI.Label()
	self.bottomline_tracks_label2:SetParent(self.barChart_tracks2)
	self.bottomline_tracks_label2:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.bottomline_tracks_label2:SetSize(50, 12)

	self.horiz_separator_tracks2 = Turbine.UI.Control()
	self.horiz_separator_tracks2:SetParent(self.barChart_tracks2)
	self.horiz_separator_tracks2:SetSize(self.barChart_tracks2:GetWidth(), 1)
	self.horiz_separator_tracks2:SetBackColor(Turbine.UI.Color.White)
	self.horiz_separator_tracks2:SetTop(self.barChart_tracks2:GetHeight() - 24)

	self.hopping_tracks_month = Turbine.UI.Label()
	self.hopping_tracks_month:SetParent(self)
	self.hopping_tracks_month:SetSize(50, 12)
	self.hopping_tracks_month:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.hopping_tracks_month:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.hopping_tracks_month:SetOutlineColor(Turbine.UI.Color.Black)
	self.hopping_tracks_month:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.hopping_tracks_month:SetVisible(false)

	self.hopping_tracks_month_day_avg = Turbine.UI.Label()
	self.hopping_tracks_month_day_avg:SetParent(self)
	self.hopping_tracks_month_day_avg:SetSize(50, 12)
	self.hopping_tracks_month_day_avg:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.hopping_tracks_month_day_avg:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.hopping_tracks_month_day_avg:SetOutlineColor(Turbine.UI.Color.Black)
	self.hopping_tracks_month_day_avg:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.hopping_tracks_month_day_avg:SetMouseVisible(false)
	self.hopping_tracks_month_day_avg:SetVisible(false)

	-- Tracks Diagram - Stats
	self.tracks_stats = Turbine.UI.Label()
	self.tracks_stats:SetParent(self.barChartTracks_panel)
	self.tracks_stats:SetSize(self.barChartTracks_panel:GetWidth(), 20)
	self.tracks_stats:SetPosition(0, self.scrollbar_barChart2:GetTop() + self.scrollbar_barChart2:GetHeight() + 3)
	self.tracks_stats:SetForeColor(default_font_color)
	self.tracks_stats:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.tracks_stats:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.tracks_stats:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.tracks_stats:SetText(L.Statistics)

	self.most_tracks_day = Turbine.UI.Label()
	self.most_tracks_day:SetParent(self.barChartTracks_panel)
	self.most_tracks_day:SetSize(self.barChartTracks_panel:GetWidth(), 12)
	self.most_tracks_day:SetTop(self.tracks_stats:GetTop() + 18)
	self.most_tracks_day:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.most_tracks_day:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)

	self.most_tracks_month = Turbine.UI.Label()
	self.most_tracks_month:SetParent(self.barChartTracks_panel)
	self.most_tracks_month:SetSize(self.barChartTracks_panel:GetWidth(), 12)
	self.most_tracks_month:SetTop(self.most_tracks_day:GetTop() + 13)
	self.most_tracks_month:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.most_tracks_month:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)

	-- Deaths Bar Chart Panel
	self.barChartDeaths_panel = Turbine.UI.Control()
	self.barChartDeaths_panel:SetParent(self)
	self.barChartDeaths_panel:SetSize(self:GetWidth() - 50, self:GetHeight() - 100)
	self.barChartDeaths_panel:SetPosition(self:GetWidth() / 2 - self.barChartDeaths_panel:GetWidth() / 2, 80)

	-- Deaths Diagram - Month
	self.barChart_deaths_heading = Turbine.UI.Label()
	self.barChart_deaths_heading:SetParent(self.barChartDeaths_panel)
	self.barChart_deaths_heading:SetSize(self.barChartDeaths_panel:GetWidth(), 25)
	self.barChart_deaths_heading:SetForeColor(default_font_color)
	self.barChart_deaths_heading:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.barChart_deaths_heading:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.barChart_deaths_heading:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.barChart_deaths_heading:SetText(L.Deaths.." "..L.Stats_Last_Month)

	self.barChart_deaths = Turbine.UI.ListBox()
	self.barChart_deaths:SetParent(self.barChartDeaths_panel)
	self.barChart_deaths:SetSize(self.barChartDeaths_panel:GetWidth(), 160)
	self.barChart_deaths:SetTop(self.barChart_deaths_heading:GetTop() + self.barChart_deaths_heading:GetHeight())
	self.barChart_deaths:SetOrientation(Turbine.UI.Orientation.Horizontal)

	self.scrollbar_barChart = Turbine.UI.Lotro.ScrollBar()
	self.scrollbar_barChart:SetParent(self.barChartDeaths_panel)
	self.scrollbar_barChart:SetOrientation(Turbine.UI.Orientation.Vertical)
	self.scrollbar_barChart:SetSize(self.barChart_deaths:GetWidth(), 10)
	self.scrollbar_barChart:SetOrientation(Turbine.UI.Orientation.Horizontal)
	self.scrollbar_barChart:SetPosition(self.barChart_deaths:GetLeft(), self.barChart_deaths:GetTop() + self.barChart_deaths:GetHeight())
	self.barChart_deaths:SetHorizontalScrollBar(self.scrollbar_barChart)

	self.topline_deaths = Turbine.UI.Control()
	self.topline_deaths:SetParent(self.barChart_deaths)
	self.topline_deaths:SetSize(self.barChart_deaths:GetWidth(), 1)
	self.topline_deaths:SetBackColor(Turbine.UI.Color.White)
	self.topline_deaths_label = Turbine.UI.Label()
	self.topline_deaths_label:SetParent(self.barChart_deaths)
	self.topline_deaths_label:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.topline_deaths_label:SetText(topline_points_value)
	self.topline_deaths_label:SetSize(50, 12)

	self.bottomline_deaths = Turbine.UI.Control()
	self.bottomline_deaths:SetParent(self.barChart_deaths)
	self.bottomline_deaths:SetSize(self.barChart_deaths:GetWidth(), 1)
	self.bottomline_deaths:SetBackColor(Turbine.UI.Color.White)
	self.bottomline_deaths_label = Turbine.UI.Label()
	self.bottomline_deaths_label:SetParent(self.barChart_deaths)
	self.bottomline_deaths_label:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.bottomline_deaths_label:SetSize(50, 12)

	self.horiz_separator_deaths = Turbine.UI.Control()
	self.horiz_separator_deaths:SetParent(self.barChart_deaths)
	self.horiz_separator_deaths:SetSize(self.barChart_deaths:GetWidth(), 1)
	self.horiz_separator_deaths:SetBackColor(Turbine.UI.Color.White)
	self.horiz_separator_deaths:SetTop(self.barChart_deaths:GetHeight() - 24)

	self.hopping_deaths_day = Turbine.UI.Label()
	self.hopping_deaths_day:SetParent(self)
	self.hopping_deaths_day:SetSize(50, 12)
	self.hopping_deaths_day:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.hopping_deaths_day:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.hopping_deaths_day:SetOutlineColor(Turbine.UI.Color.Black)
	self.hopping_deaths_day:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.hopping_deaths_day:SetVisible(false)

	-- Deaths Diagram - Year
	self.barChart_deaths_heading2 = Turbine.UI.Label()
	self.barChart_deaths_heading2:SetParent(self.barChartDeaths_panel)
	self.barChart_deaths_heading2:SetSize(self.barChartDeaths_panel:GetWidth(), 15)
	self.barChart_deaths_heading2:SetPosition(0, self.scrollbar_barChart:GetTop() + self.scrollbar_barChart:GetHeight() + 15)
	self.barChart_deaths_heading2:SetForeColor(default_font_color)
	self.barChart_deaths_heading2:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.barChart_deaths_heading2:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.barChart_deaths_heading2:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.barChart_deaths_heading2:SetText(L.Deaths.." "..L.Stats_Last_Year)

	self.barChart_deaths2 = Turbine.UI.ListBox()
	self.barChart_deaths2:SetParent(self.barChartDeaths_panel)
	self.barChart_deaths2:SetSize(self.barChartDeaths_panel:GetWidth(), 160)
	self.barChart_deaths2:SetTop(self.barChart_deaths_heading2:GetTop() + self.barChart_deaths_heading2:GetHeight())
	self.barChart_deaths2:SetOrientation(Turbine.UI.Orientation.Horizontal)

	self.scrollbar_barChart2 = Turbine.UI.Lotro.ScrollBar()
	self.scrollbar_barChart2:SetParent(self.barChartDeaths_panel)
	self.scrollbar_barChart2:SetOrientation(Turbine.UI.Orientation.Vertical)
	self.scrollbar_barChart2:SetSize(self.barChart_deaths2:GetWidth(), 10)
	self.scrollbar_barChart2:SetOrientation(Turbine.UI.Orientation.Horizontal)
	self.scrollbar_barChart2:SetPosition(self.barChart_deaths2:GetLeft(), self.barChart_deaths2:GetTop() + self.barChart_deaths2:GetHeight())
	self.barChart_deaths2:SetHorizontalScrollBar(self.scrollbar_barChart2)

	self.topline_deaths2 = Turbine.UI.Control()
	self.topline_deaths2:SetParent(self.barChart_deaths2)
	self.topline_deaths2:SetSize(self.barChart_deaths2:GetWidth(), 1)
	self.topline_deaths2:SetBackColor(Turbine.UI.Color.White)
	self.topline_deaths_label2 = Turbine.UI.Label()
	self.topline_deaths_label2:SetParent(self.barChart_deaths2)
	self.topline_deaths_label2:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.topline_deaths_label2:SetText(topline_frags_value)
	self.topline_deaths_label2:SetSize(50, 12)
  
	self.bottomline_deaths2 = Turbine.UI.Control()
	self.bottomline_deaths2:SetParent(self.barChart_deaths2)
	self.bottomline_deaths2:SetSize(self.barChart_deaths2:GetWidth(), 1)
	self.bottomline_deaths2:SetBackColor(Turbine.UI.Color.White)
	self.bottomline_deaths_label2 = Turbine.UI.Label()
	self.bottomline_deaths_label2:SetParent(self.barChart_deaths2)
	self.bottomline_deaths_label2:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.bottomline_deaths_label2:SetSize(50, 12)

	self.horiz_separator_deaths2 = Turbine.UI.Control()
	self.horiz_separator_deaths2:SetParent(self.barChart_deaths2)
	self.horiz_separator_deaths2:SetSize(self.barChart_deaths2:GetWidth(), 1)
	self.horiz_separator_deaths2:SetBackColor(Turbine.UI.Color.White)
	self.horiz_separator_deaths2:SetTop(self.barChart_deaths2:GetHeight() - 24)

	self.hopping_deaths_month = Turbine.UI.Label()
	self.hopping_deaths_month:SetParent(self)
	self.hopping_deaths_month:SetSize(50, 12)
	self.hopping_deaths_month:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.hopping_deaths_month:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.hopping_deaths_month:SetOutlineColor(Turbine.UI.Color.Black)
	self.hopping_deaths_month:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.hopping_deaths_month:SetVisible(false)

	self.hopping_deaths_month_day_avg = Turbine.UI.Label()
	self.hopping_deaths_month_day_avg:SetParent(self)
	self.hopping_deaths_month_day_avg:SetSize(50, 12)
	self.hopping_deaths_month_day_avg:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.hopping_deaths_month_day_avg:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.hopping_deaths_month_day_avg:SetOutlineColor(Turbine.UI.Color.Black)
	self.hopping_deaths_month_day_avg:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.hopping_deaths_month_day_avg:SetMouseVisible(false)
	self.hopping_deaths_month_day_avg:SetVisible(false)

	-- Deaths Diagram - Stats
	self.deaths_stats = Turbine.UI.Label()
	self.deaths_stats:SetParent(self.barChartDeaths_panel)
	self.deaths_stats:SetSize(self.barChartDeaths_panel:GetWidth(), 20)
	self.deaths_stats:SetPosition(0, self.scrollbar_barChart2:GetTop() + self.scrollbar_barChart2:GetHeight() + 3)
	self.deaths_stats:SetForeColor(default_font_color)
	self.deaths_stats:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
	self.deaths_stats:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.deaths_stats:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.deaths_stats:SetText(L.Statistics)

	self.most_deaths_day = Turbine.UI.Label()
	self.most_deaths_day:SetParent(self.barChartDeaths_panel)
	self.most_deaths_day:SetSize(self.barChartDeaths_panel:GetWidth(), 12)
	self.most_deaths_day:SetTop(self.deaths_stats:GetTop() + 18)
	self.most_deaths_day:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.most_deaths_day:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)

	self.most_deaths_month = Turbine.UI.Label()
	self.most_deaths_month:SetParent(self.barChartDeaths_panel)
	self.most_deaths_month:SetSize(self.barChartDeaths_panel:GetWidth(), 12)
	self.most_deaths_month:SetTop(self.most_deaths_day:GetTop() + 13)
	self.most_deaths_month:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.most_deaths_month:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)

	self.KeyDown = function(sender,args) 
		if args.Action == Turbine.UI.Lotro.Action.Escape then
			self:SetVisible(false)
		end
	end

	self.PositionChanged = function(sender, args)
		data.numbers.statsWin_x = self:GetLeft()
		data.numbers.statsWin_y = self:GetTop()
	end
end

function StatsWindow:UpdateStatsPanel()
	local pointsLast24h, pointsLastHour, pointsLast10Min = GetRecentData(data.numbers.recent_points)
	local commsLast24h, commsLastHour, commsLast10Min = GetRecentData(data.numbers.recent_comms)
	local fragsLast24h, fragsLastHour, fragsLast10Min = GetRecentData(data.numbers.recent_frags)
	local deathsLast24h, deathsLastHour, deathsLast10Min = GetRecentData(data.numbers.recent_deaths)
	local tracksLast24h, tracksLastHour, tracksLast10Min = GetRecentData(data.numbers.recent_tracks)
	local flag1 = true
	local flag2 = true

	for i=0, 14 do
		if (data.numbers.points_total >= Ranks[i] and data.numbers.points_total < Ranks[i+1]) then
			self.rank:SetText(L.Strings_Rank..i.." - "..Rank_Names[i])
			flag1 = false
			break
		end
	end

	for j=0, 7 do
		if (data.numbers.frags_total >= Tiers[j] and data.numbers.frags_total < Tiers[j+1]) then
			self.tier:SetText(L.Strings_Tier..j.." - "..Tier_Names[j])
			flag2 = false
			break
		end
	end

	if flag1 then
		self.rank:SetText(L.Strings_Rank.."15".." - "..Rank_Names[15])
	elseif flag2 then
		self.tier:SetText(L.Strings_Tier.."10".." - "..Tier_Names[8])
	end

	self.points_total:SetText(L.Stats_Total)
	self.points_total_value:SetText(FormatPoints(data.numbers.points_total))
	self.points_to_rankup:SetText(L.Stats_To_RankUp)
	self.points_to_rankup_value:SetText(FormatPoints(GetRemainingPoints()))
	self.points_this_day:SetText(L.Stats_Current_Day)
	self.points_this_day_value:SetText(FormatPoints(data.numbers.points_current_day))
	self.points_last_24h:SetText(L.Stats_Last_24h)
	self.points_last_24h_value:SetText(pointsLast24h)
	self.points_last_hour:SetText(L.Stats_Last_Hour)
	self.points_last_hour_value:SetText(pointsLastHour)
	self.points_last_10min:SetText(L.Stats_Last_10min)
	self.points_last_10min_value:SetText(pointsLast10Min)
	self.points_last_fight:SetText(L.Stats_Last_Fight)
	self.points_last_fight_value:SetText(FormatPoints(points_last_fight))

	
	self.comms_total:SetText(L.Stats_Total)
	self.comms_total_value:SetText(FormatPoints(data.numbers.comms_all_time))
	self.comms_current:SetText(L.Stats_Current)
	self.comms_current_value:SetText(FormatPoints(current_commendations))
	self.comms_this_day:SetText(L.Stats_Current_Day)
	self.comms_this_day_value:SetText(FormatPoints(data.numbers.comms_current_day))
	self.comms_last_24h:SetText(L.Stats_Last_24h)
	self.comms_last_24h_value:SetText(commsLast24h)
	self.comms_last_hour:SetText(L.Stats_Last_Hour)
	self.comms_last_hour_value:SetText(commsLastHour)
	self.comms_last_10min:SetText(L.Stats_Last_10min)
	self.comms_last_10min_value:SetText(commsLast10Min)
	self.comms_last_fight:SetText(L.Stats_Last_Fight)
	self.comms_last_fight_value:SetText(FormatPoints(comms_last_fight))

	self.frags_total:SetText(L.Stats_Total)
	self.frags_total_value:SetText(FormatPoints(data.numbers.frags_total))
	self.frags_to_tierup:SetText(L.Stats_To_TierUp)
	self.frags_to_tierup_value:SetText(FormatPoints(GetRemainingFrags()))
	self.frags_this_day:SetText(L.Stats_Current_Day)
	self.frags_this_day_value:SetText(FormatPoints(data.numbers.frags_current_day))
	self.frags_last_24h:SetText(L.Stats_Last_24h)
	self.frags_last_24h_value:SetText(fragsLast24h)
	self.frags_last_hour:SetText(L.Stats_Last_Hour)
	self.frags_last_hour_value:SetText(fragsLastHour)
	self.frags_last_10min:SetText(L.Stats_Last_10min)
	self.frags_last_10min_value:SetText(fragsLast10Min)
	self.frags_last_fight:SetText(L.Stats_Last_Fight)
	self.frags_last_fight_value:SetText(FormatPoints(frags_last_fight))

	self.deaths_this_day:SetText(L.Stats_Current_Day)
	self.deaths_this_day_value:SetText(FormatPoints(data.numbers.deaths_current_day))
	self.deaths_last_24h:SetText(L.Stats_Last_24h)
	self.deaths_last_24h_value:SetText(deathsLast24h)
	self.deaths_last_hour:SetText(L.Stats_Last_Hour)
	self.deaths_last_hour_value:SetText(deathsLastHour)
	self.deaths_last_10min:SetText(L.Stats_Last_10min)
	self.deaths_last_10min_value:SetText(deathsLast10Min)

	self.tracks_total:SetText(L.Stats_Total)
	self.tracks_total_value:SetText(FormatPoints(data.numbers.tracks_total))
	self.tracks_this_day:SetText(L.Stats_Current_Day)
	self.tracks_this_day_value:SetText(FormatPoints(data.numbers.tracks_current_day))
	self.tracks_last_24h:SetText(L.Stats_Last_24h)
	self.tracks_last_24h_value:SetText(tracksLast24h)
	self.tracks_last_hour:SetText(L.Stats_Last_Hour)
	self.tracks_last_hour_value:SetText(tracksLastHour)
	self.tracks_last_10min:SetText(L.Stats_Last_10min)
	self.tracks_last_10min_value:SetText(tracksLast10Min)
end

function StatsWindow:UpdateFragList(sortmode)
	local totalFragAmount = 0
	local totalVictimAmount = 0
	local separatorColor = Turbine.UI.Color(30/255,30/255,30/255)
	local pattern = string.lower(self.search_box:GetText())
	self.frag_list:ClearItems()

	for name,frags in pairs(data.numbers.frags) do
		if string.match(string.lower(name), pattern) then
			totalVictimAmount = totalVictimAmount + 1
			totalFragAmount = totalFragAmount + frags
			local listItem = Turbine.UI.Control()
			listItem:SetSize(self.frag_list:GetWidth(), 15)

			listItem.Name = Turbine.UI.Label()
			listItem.Name:SetFont(Turbine.UI.Lotro.Font.Verdana14)
			listItem.Name:SetSize(self.frag_list:GetWidth() * 3/4, listItem:GetHeight() - 1)
			listItem.Name:SetParent(listItem)
			listItem.Name:SetText(name)
			listItem.Kills = Turbine.UI.Label()
			listItem.Kills:SetFont(Turbine.UI.Lotro.Font.Verdana14)
			listItem.Kills:SetSize(self.frag_list:GetWidth() * 1/4, listItem:GetHeight() - 1)
			listItem.Kills:SetParent(listItem)
			listItem.Kills:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
			listItem.Kills:SetText(frags)
			listItem.Kills:SetLeft(listItem.Name:GetWidth())
			listItem.separator = Turbine.UI.Control()
			listItem.separator:SetParent(listItem)
			listItem.separator:SetSize(listItem:GetWidth(), 1)
			listItem.separator:SetTop(14)
			listItem.separator:SetBackColor(separatorColor)
			self.frag_list:AddItem(listItem)
		end
	end

	self.name_label:SetText(L.Name.." ("..FormatPoints(totalVictimAmount)..")")
	self.frags_label:SetText(L.AmountFrags.." ("..FormatPoints(totalFragAmount)..")")

	if data.numbers.frags_total == nil then data.numbers.frags_total = totalFragAmount end

	self.frag_list:SetSelectedIndex(1)
	self:SortFragList(sortmode)
end

function StatsWindow:SortFragList(sortmode)
	self.frag_list:Sort(sortmode.funct)
	self.current_sortmode = sortmode
end

function StatsWindow:UpdateBarCharts()
	local current_date = Turbine.Engine.GetDate()
	local barChartColor = Turbine.UI.Color(0.85,0.65,0.125)

	local daysToDisplay = 31
	local monthsToDisplay = 12

	local points_last_days = {}
	local points_last_months = {}
	local comms_last_days = {}
	local comms_last_months = {}
	local frags_last_days = {}
	local frags_last_months = {}
	local deaths_last_days = {}
	local deaths_last_months = {}
	local tracks_last_days = {}
	local tracks_last_months = {}

	local maxValue_points = { 0, nil, nil, nil }
	local maxValue_comms = { 0, nil, nil, nil }
	local maxValue_frags = { 0, nil, nil, nil }
	local maxValue_deaths = { 0, nil, nil, nil }
	local maxValue_tracks = { 0, nil, nil, nil }

	local maxValue_points2 = { 0, nil, nil }
	local maxValue_comms2 = { 0, nil, nil }
	local maxValue_frags2 = { 0, nil, nil }
	local maxValue_deaths2 = { 0, nil, nil }
	local maxValue_tracks2 = { 0, nil, nil }

	self.barChart_points:ClearItems()
	self.barChart_points2:ClearItems()
	self.barChart_comms:ClearItems()
	self.barChart_comms2:ClearItems()
	self.barChart_frags:ClearItems()
	self.barChart_frags2:ClearItems()
	self.barChart_deaths:ClearItems()
	self.barChart_deaths2:ClearItems()
	self.barChart_tracks:ClearItems()
	self.barChart_tracks2:ClearItems()

	for i=1, daysToDisplay - 1 do
		local dayOfYear = current_date.DayOfYear - i
		if dayOfYear < 1 then dayOfYear = dayOfYear + GetDaysPerYear(current_date.Year) end
		local points = data.numbers.history.points[dayOfYear]
		local comms = data.numbers.history.comms[dayOfYear]
		local frags = data.numbers.history.frags[dayOfYear]
		local deaths = data.numbers.history.deaths[dayOfYear]
		local tracks = data.numbers.history.tracks[dayOfYear]
		if dayOfYear == data.numbers.current_day then
			points = data.numbers.points_current_day
			comms = data.numbers.comms_current_day
			frags = data.numbers.frags_current_day
			deaths = data.numbers.deaths_current_day
			tracks = data.numbers.tracks_current_day
		end
		local day = current_date.Day - i
		local month = current_date.Month
		local year = current_date.Year
		while day < 1 do
			month = month - 1
			if month == 0 then
				month = 12
				year = year - 1
			end
			day = GetDaysPerMonth(month) + day
		end

		if (points or 0) >= maxValue_points[1] then maxValue_points = { points or 0, day, month, year } end
		if (comms or 0) >= maxValue_comms[1] then maxValue_comms = { comms or 0, day, month, year } end
		if (frags or 0) >= maxValue_frags[1] then maxValue_frags = { frags or 0, day, month, year } end
		if (deaths or 0) >= maxValue_deaths[1] then maxValue_deaths = { deaths or 0, day, month, year } end
		if (tracks or 0) >= maxValue_tracks[1] then maxValue_tracks = { tracks or 0, day, month, year } end
		points_last_days[daysToDisplay - i] = { day, L.Months[month], points or 0 }
		comms_last_days[daysToDisplay - i] = { day, L.Months[month], comms or 0 }
		frags_last_days[daysToDisplay - i] = { day, L.Months[month], frags or 0 }
		deaths_last_days[daysToDisplay - i] = { day, L.Months[month], deaths or 0 }
		tracks_last_days[daysToDisplay - i] = { day, L.Months[month], tracks or 0 }
	end

	if data.numbers.current_day == current_date.DayOfYear then
		points_last_days[daysToDisplay] = { current_date.Day, L.Months[current_date.Month], data.numbers.points_current_day }
		comms_last_days[daysToDisplay] = { current_date.Day, L.Months[current_date.Month], data.numbers.comms_current_day }
		frags_last_days[daysToDisplay] = { current_date.Day, L.Months[current_date.Month], data.numbers.frags_current_day }
		deaths_last_days[daysToDisplay] = { current_date.Day, L.Months[current_date.Month], data.numbers.deaths_current_day }
		tracks_last_days[daysToDisplay] = { current_date.Day, L.Months[current_date.Month], data.numbers.tracks_current_day }
	end

	for i=1, monthsToDisplay - 1 do
		local monthOfYear = current_date.Month -  i
		if monthOfYear < 1 then monthOfYear = monthOfYear + monthsToDisplay end
		local points = data.numbers.history.pointsMonth[monthOfYear]
		local comms = data.numbers.history.commsMonth[monthOfYear]
		local frags = data.numbers.history.fragsMonth[monthOfYear]
		local deaths = data.numbers.history.deathsMonth[monthOfYear]
		local tracks = data.numbers.history.tracksMonth[monthOfYear]
		if monthOfYear == data.numbers.current_month then
			points = data.numbers.points_current_month
			comms = data.numbers.comms_current_month
			frags = data.numbers.frags_current_month
			deaths = data.numbers.deaths_current_month
			tracks = data.numbers.tracks_current_month
		end
		local month = current_date.Month
		local year = current_date.Year

		if month - i <= 0 then
			month = month + 12
			year = year - 1
		end

		if (points or 0) >= maxValue_points2[1] then maxValue_points2 = { points or 0, month, year } end
		if (comms or 0) >= maxValue_comms2[1] then maxValue_comms2 = { comms or 0, month, year } end
		if (frags or 0) >= maxValue_frags2[1] then maxValue_frags2 = { frags or 0, month, year } end
		if (deaths or 0) >= maxValue_deaths2[1] then maxValue_deaths2 = { deaths or 0, month, year } end
		if (tracks or 0) >= maxValue_tracks2[1] then maxValue_tracks2 = { tracks or 0, month, year } end
		points_last_months[monthsToDisplay - i] = { L.Months[month - i], year, points or 0 }
		comms_last_months[monthsToDisplay - i] = { L.Months[month - i], year, comms or 0 }
		frags_last_months[monthsToDisplay - i] = { L.Months[month - i], year, frags or 0 }
		deaths_last_months[monthsToDisplay - i] = { L.Months[month - i], year, deaths or 0 }
		tracks_last_months[monthsToDisplay - i] = { L.Months[month - i], year, tracks or 0 }
	end

	if data.numbers.current_month == current_date.Month then
		points_last_months[monthsToDisplay] = { L.Months[current_date.Month], current_date.Year, data.numbers.points_current_month }
		comms_last_months[monthsToDisplay] = { L.Months[current_date.Month], current_date.Year, data.numbers.comms_current_month }
		frags_last_months[monthsToDisplay] = { L.Months[current_date.Month], current_date.Year, data.numbers.frags_current_month }
		deaths_last_months[monthsToDisplay] = { L.Months[current_date.Month], current_date.Year, data.numbers.deaths_current_month }
		tracks_last_months[monthsToDisplay] = { L.Months[current_date.Month], current_date.Year, data.numbers.tracks_current_month }
	end

	if data.numbers.points_current_day >= maxValue_points[1] then
		maxValue_points = { data.numbers.points_current_day, current_date.Day, current_date.Month, current_date.Year }
	end
	if data.numbers.comms_current_day >= maxValue_comms[1] then
		maxValue_comms = { data.numbers.comms_current_day, current_date.Day, current_date.Month, current_date.Year }
	end
	if data.numbers.frags_current_day >= maxValue_frags[1] then
		maxValue_frags = { data.numbers.frags_current_day, current_date.Day, current_date.Month, current_date.Year }
	end
	if data.numbers.deaths_current_day >= maxValue_deaths[1] then
		maxValue_deaths = { data.numbers.deaths_current_day, current_date.Day, current_date.Month, current_date.Year }
	end
	if data.numbers.tracks_current_day >= maxValue_tracks[1] then
		maxValue_tracks = { data.numbers.tracks_current_day, current_date.Day, current_date.Month, current_date.Year }
	end

	if data.numbers.points_current_month >= maxValue_points2[1] then
		maxValue_points2 = { data.numbers.points_current_month, current_date.Month, current_date.Year }
	end
	if data.numbers.comms_current_month >= maxValue_comms2[1] then
		maxValue_comms2 = { data.numbers.comms_current_month, current_date.Month, current_date.Year }
	end
	if data.numbers.frags_current_month >= maxValue_frags2[1] then
		maxValue_frags2 = { data.numbers.frags_current_month, current_date.Month, current_date.Year }
	end
	if data.numbers.deaths_current_month >= maxValue_deaths2[1] then
		maxValue_deaths2 = { data.numbers.deaths_current_month, current_date.Month, current_date.Year }
	end
	if data.numbers.tracks_current_month >= maxValue_tracks2[1] then
		maxValue_tracks2 = { data.numbers.tracks_current_month, current_date.Month, current_date.Year }
	end

	maxValue_points = maxValue_points[1]
	maxValue_comms = maxValue_comms[1]
	maxValue_frags = maxValue_frags[1]
	maxValue_deaths = maxValue_deaths[1]
	maxValue_tracks = maxValue_tracks[1]

	maxValue_points2 = maxValue_points2[1]
	maxValue_comms2 = maxValue_comms2[1]
	maxValue_frags2 = maxValue_frags2[1]
	maxValue_deaths2 = maxValue_deaths2[1]
	maxValue_tracks2 = maxValue_tracks2[1]

	-- Points Month
	local diagramHeight = self.barChart_points:GetHeight() - 24

	if maxValue_points - math.floor(maxValue_points / 1000) * 1000 > 500 then
		maxValue_points = math.floor(maxValue_points / 1000) * 1000 + 1000
	end
	if maxValue_points < 1000 then maxValue_points = 1000 end

	local topline_points_value = math.floor(maxValue_points / 1000) * 1000

	if maxValue_points < math.floor(maxValue_points / 1000) * 1000 + maxValue_points * 12 / self.barChart_points:GetHeight() then
		maxValue_points = maxValue_points + maxValue_points * 12 / self.barChart_points:GetHeight()
	end

	for index,points in pairs(points_last_days) do
		local listItem = Turbine.UI.Control()
		listItem:SetSize(self.barChart_points:GetWidth() / 12.5 - 2, self.barChart_points:GetHeight())
		local subItem = Turbine.UI.Label()
		subItem:SetParent(listItem)
		subItem:SetBackColor(barChartColor)
		subItem:SetSize(listItem:GetWidth(), diagramHeight * (points[3] / maxValue_points))
		subItem:SetTop(diagramHeight - subItem:GetHeight())
		local points_amount = Turbine.UI.Label()
		points_amount:SetParent(listItem)
		points_amount:SetText(points[3])
		points_amount:SetVisible(false)
		subItem.MouseEnter = function()
			subItem:SetBackColor(AlignedColor)
			self.hopping_points_day:SetPosition(
				self.barChartPoints_panel:GetLeft() + listItem:GetLeft() + listItem:GetWidth() / 2 - self.hopping_points_day:GetWidth() / 2,
				self.barChartPoints_panel:GetTop() + self.barChart_points:GetTop() + subItem:GetTop() - self.hopping_points_day:GetHeight()
			)
			self.hopping_points_day:SetText(FormatPoints(points_amount:GetText()))
			self.hopping_points_day:SetVisible(true)

			local pointsPerFrag = Round(points[3]/frags_last_days[index][3])
			if frags_last_days[index][3] == 0 then
				pointsPerFrag = Round(points[3]/1)
			end
		
			self.points_per_frag:SetText(L.InfamyRenown..L.Points_Per_KillingBlow..pointsPerFrag)
			self.points_per_frag:SetVisible(true)
		end
		subItem.MouseLeave = function()
			subItem:SetBackColor(barChartColor)
			self.hopping_points_day:SetVisible(false)

			self.points_per_frag:SetVisible(false)
		end
		local dateItemDay = Turbine.UI.Label()
		dateItemDay:SetParent(listItem)
		dateItemDay:SetSize(listItem:GetWidth(), 12)
		dateItemDay:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		dateItemDay:SetFont(Turbine.UI.Lotro.Font.Arial12)
		dateItemDay:SetText(points[1])
		dateItemDay:SetTop(listItem:GetHeight() - dateItemDay:GetHeight() * 2)

		local dateItemMonth = Turbine.UI.Label()
		dateItemMonth:SetParent(listItem)
		dateItemMonth:SetSize(listItem:GetWidth(), 12)
		dateItemMonth:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		dateItemMonth:SetFont(Turbine.UI.Lotro.Font.Arial12)
		dateItemMonth:SetText(points[2])
		dateItemMonth:SetTop(listItem:GetHeight() - dateItemMonth:GetHeight())

		self.barChart_points:AddItem(listItem)

		local separator = Turbine.UI.Control()
		separator:SetSize(2, self.barChart_points:GetHeight())
		self.barChart_points:AddItem(separator)
	end
	self.barChart_points:RemoveItemAt(self.barChart_points:GetItemCount())

	local topline_points_value = topline_points_value
	self.topline_points:SetTop(diagramHeight - diagramHeight * topline_points_value / maxValue_points)
	self.topline_points_label:SetText(FormatPoints(topline_points_value))
	self.topline_points_label:SetTop(self.topline_points:GetTop() - 11)

	local bottomline_points_value = topline_points_value / 2
	self.bottomline_points:SetTop(diagramHeight - diagramHeight * bottomline_points_value / maxValue_points)
	self.bottomline_points_label:SetText(FormatPoints(bottomline_points_value))
	self.bottomline_points_label:SetTop(self.bottomline_points:GetTop() - 11)

	self.barChart_points:SetSelectedIndex(self.barChart_points:GetItemCount())

	-- Points Year
	local diagramHeight = self.barChart_points2:GetHeight() - 24

	if maxValue_points2 - math.floor(maxValue_points2 / 10000) * 10000 > 5000 then
		maxValue_points2 = math.floor(maxValue_points2 / 10000) * 10000 + 10000
	end
	if maxValue_points2 < 10000 then maxValue_points2 = 10000 end

	local topline_points_value2 = math.floor(maxValue_points2 / 10000) * 10000

	if maxValue_points2 < math.floor(maxValue_points2 / 10000) * 10000 + maxValue_points2 * 12 / self.barChart_points2:GetHeight() then
		maxValue_points2 = maxValue_points2 + maxValue_points2 * 12 / self.barChart_points2:GetHeight()
	end

	for index,points in pairs(points_last_months) do
		local listItem = Turbine.UI.Control()
		listItem:SetSize(self.barChart_points2:GetWidth() / 11.5 - 2, self.barChart_points2:GetHeight())
		local subItem = Turbine.UI.Label()
		subItem:SetParent(listItem)
		subItem:SetBackColor(barChartColor)
		subItem:SetSize(listItem:GetWidth(), diagramHeight * (points[3] / maxValue_points2))
		subItem:SetTop(diagramHeight - subItem:GetHeight())
		local points_amount = Turbine.UI.Label()
		points_amount:SetParent(listItem)
		points_amount:SetText(points[3])
		points_amount:SetVisible(false)
		subItem.MouseEnter = function()
			subItem:SetBackColor(AlignedColor)
			self.hopping_points_month:SetPosition(
				self.barChartPoints_panel:GetLeft() + listItem:GetLeft() + listItem:GetWidth() / 2 - self.hopping_points_month:GetWidth() / 2,
				self.barChartPoints_panel:GetTop() + self.barChart_points2:GetTop() + subItem:GetTop() - self.hopping_points_month:GetHeight()
			)
			self.hopping_points_month:SetText(FormatPoints(points_amount:GetText()))
			self.hopping_points_month:SetVisible(true)

			self.hopping_points_month_day_avg:SetPosition(
				self.barChartPoints_panel:GetLeft() + listItem:GetLeft() + listItem:GetWidth() / 2 - self.hopping_points_month_day_avg:GetWidth() / 2,
				self.barChartPoints_panel:GetHeight() - self.hopping_points_month_day_avg:GetHeight() * 3.8
			)
			if points[1] == L.Months[current_date.Month] then
				self.hopping_points_month_day_avg:SetText(FormatPoints(math.floor(points_amount:GetText() / current_date.Day)))
			else
				self.hopping_points_month_day_avg:SetText(FormatPoints(math.floor(points_amount:GetText() / GetDaysPerMonth(points[1], points[2]))))
			end
			self.hopping_points_month_day_avg:SetVisible(true)
		
			local pointsPerFrag = Round(points[3]/frags_last_months[index][3])
			if frags_last_months[index][3] == 0 then
				pointsPerFrag = Round(points[3]/1)
			end
		
			self.points_per_frag:SetText(L.InfamyRenown..L.Points_Per_KillingBlow..pointsPerFrag)
			self.points_per_frag:SetVisible(true)
		end
		subItem.MouseLeave = function()
			subItem:SetBackColor(barChartColor)
			self.hopping_points_month:SetVisible(false)
			self.hopping_points_month_day_avg:SetVisible(false)

			self.points_per_frag:SetVisible(false)
		end

		local dateItemMonth = Turbine.UI.Label()
		dateItemMonth:SetParent(listItem)
		dateItemMonth:SetSize(listItem:GetWidth(), 12)
		dateItemMonth:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		dateItemMonth:SetFont(Turbine.UI.Lotro.Font.Arial12)
		dateItemMonth:SetText(points[1])
		dateItemMonth:SetTop(listItem:GetHeight() - dateItemMonth:GetHeight() * 2)

		local dateItemYear = Turbine.UI.Label()
		dateItemYear:SetParent(listItem)
		dateItemYear:SetSize(listItem:GetWidth(), 12)
		dateItemYear:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		dateItemYear:SetFont(Turbine.UI.Lotro.Font.Arial12)
		dateItemYear:SetText(points[2])
		dateItemYear:SetTop(listItem:GetHeight() - dateItemYear:GetHeight())

		self.barChart_points2:AddItem(listItem)

		local separator = Turbine.UI.Control()
		separator:SetSize(2, self.barChart_points2:GetHeight())
		self.barChart_points2:AddItem(separator)
	end
	self.barChart_points2:RemoveItemAt(self.barChart_points2:GetItemCount())

	local topline_points_value2 = topline_points_value2
	self.topline_points2:SetTop(diagramHeight - diagramHeight * topline_points_value2 / maxValue_points2)
	self.topline_points_label2:SetText(FormatPoints(topline_points_value2))
	self.topline_points_label2:SetTop(self.topline_points2:GetTop() - 11)

	local bottomline_points_value2 = topline_points_value2 / 2
	self.bottomline_points2:SetTop(diagramHeight - diagramHeight * bottomline_points_value2 / maxValue_points2)
	self.bottomline_points_label2:SetText(FormatPoints(bottomline_points_value2))
	self.bottomline_points_label2:SetTop(self.bottomline_points2:GetTop() - 11)

	self.barChart_points2:SetSelectedIndex(self.barChart_points2:GetItemCount())

	-- Points Stats
	self.most_points_fight:SetText(L.Maximum_Fight..FormatPoints(data.numbers.most_points_a_fight[1]).." ("..
	data.numbers.most_points_a_fight[2].." "..L.Months[data.numbers.most_points_a_fight[3]].." "..data.numbers.most_points_a_fight[4]..")")

	self.most_points_day:SetText(L.Maximum_Day..FormatPoints(data.numbers.most_points_a_day[1]).." ("..
	data.numbers.most_points_a_day[2].." "..L.Months[data.numbers.most_points_a_day[3]].." "..data.numbers.most_points_a_day[4]..")")

	self.most_points_month:SetText(L.Maximum_Month..FormatPoints(data.numbers.most_points_a_month[1]).." ("..
	L.Months[data.numbers.most_points_a_month[2]].." "..data.numbers.most_points_a_month[3]..")")

	-- Comms Month
	local diagramHeight = self.barChart_comms:GetHeight() - 24

	if maxValue_comms - math.floor(maxValue_comms / 1000) * 1000 > 500 then
		maxValue_comms = math.floor(maxValue_comms / 1000) * 1000 + 1000
	end
	if maxValue_comms < 1000 then maxValue_comms = 1000 end

	local topline_comms_value = math.floor(maxValue_comms / 1000) * 1000

	if maxValue_comms < math.floor(maxValue_comms / 1000) * 1000 + maxValue_comms * 12 / self.barChart_comms:GetHeight() then
		maxValue_comms = maxValue_comms + maxValue_comms * 12 / self.barChart_comms:GetHeight()
	end

	for index,comms in pairs(comms_last_days) do
		local listItem = Turbine.UI.Control()
		listItem:SetSize(self.barChart_comms:GetWidth() / 12.5 - 2, self.barChart_comms:GetHeight())
		local subItem = Turbine.UI.Label()
		subItem:SetParent(listItem)
		subItem:SetBackColor(barChartColor)
		subItem:SetSize(listItem:GetWidth(), diagramHeight * (comms[3] / maxValue_comms))
		subItem:SetTop(diagramHeight - subItem:GetHeight())
		local comms_amount = Turbine.UI.Label()
		comms_amount:SetParent(listItem)
		comms_amount:SetText(comms[3])
		comms_amount:SetVisible(false)
		subItem.MouseEnter = function()
			subItem:SetBackColor(AlignedColor)
			self.hopping_comms_day:SetPosition(
				self.barChartComms_panel:GetLeft() + listItem:GetLeft() + listItem:GetWidth() / 2 - self.hopping_comms_day:GetWidth() / 2,
				self.barChartComms_panel:GetTop() + self.barChart_comms:GetTop() + subItem:GetTop() - self.hopping_comms_day:GetHeight()
			)
			self.hopping_comms_day:SetText(FormatPoints(comms_amount:GetText()))
			self.hopping_comms_day:SetVisible(true)
		end
		subItem.MouseLeave = function()
			subItem:SetBackColor(barChartColor)
			self.hopping_comms_day:SetVisible(false)
		end
		local dateItemDay = Turbine.UI.Label()
		dateItemDay:SetParent(listItem)
		dateItemDay:SetSize(listItem:GetWidth(), 12)
		dateItemDay:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		dateItemDay:SetFont(Turbine.UI.Lotro.Font.Arial12)
		dateItemDay:SetText(comms[1])
		dateItemDay:SetTop(listItem:GetHeight() - dateItemDay:GetHeight() * 2)

		local dateItemMonth = Turbine.UI.Label()
		dateItemMonth:SetParent(listItem)
		dateItemMonth:SetSize(listItem:GetWidth(), 12)
		dateItemMonth:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		dateItemMonth:SetFont(Turbine.UI.Lotro.Font.Arial12)
		dateItemMonth:SetText(comms[2])
		dateItemMonth:SetTop(listItem:GetHeight() - dateItemMonth:GetHeight())

		self.barChart_comms:AddItem(listItem)

		local separator = Turbine.UI.Control()
		separator:SetSize(2, self.barChart_comms:GetHeight())
		self.barChart_comms:AddItem(separator)
	end
	self.barChart_comms:RemoveItemAt(self.barChart_comms:GetItemCount())

	local topline_comms_value = topline_comms_value
	self.topline_comms:SetTop(diagramHeight - diagramHeight * topline_comms_value / maxValue_comms)
	self.topline_comms_label:SetText(FormatPoints(topline_comms_value))
	self.topline_comms_label:SetTop(self.topline_comms:GetTop() - 11)

	local bottomline_comms_value = topline_comms_value / 2
	self.bottomline_comms:SetTop(diagramHeight - diagramHeight * bottomline_comms_value / maxValue_comms)
	self.bottomline_comms_label:SetText(FormatPoints(bottomline_comms_value))
	self.bottomline_comms_label:SetTop(self.bottomline_comms:GetTop() - 11)

	self.barChart_comms:SetSelectedIndex(self.barChart_comms:GetItemCount())

	-- Comms Year
	local diagramHeight = self.barChart_comms2:GetHeight() - 24

	if maxValue_comms2 - math.floor(maxValue_comms2 / 10000) * 10000 > 5000 then
		maxValue_comms2 = math.floor(maxValue_comms2 / 10000) * 10000 + 10000
	end
	if maxValue_comms2 < 10000 then maxValue_comms2 = 10000 end

	local topline_comms_value2 = math.floor(maxValue_comms2 / 10000) * 10000

	if maxValue_comms2 < math.floor(maxValue_comms2 / 10000) * 10000 + maxValue_comms2 * 12 / self.barChart_comms2:GetHeight() then
		maxValue_comms2 = maxValue_comms2 + maxValue_comms2 * 12 / self.barChart_comms2:GetHeight()
	end

	for index,comms in pairs(comms_last_months) do
		local listItem = Turbine.UI.Control()
		listItem:SetSize(self.barChart_comms2:GetWidth() / 11.5 - 2, self.barChart_comms2:GetHeight())
		local subItem = Turbine.UI.Label()
		subItem:SetParent(listItem)
		subItem:SetBackColor(barChartColor)
		subItem:SetSize(listItem:GetWidth(), diagramHeight * (comms[3] / maxValue_comms2))
		subItem:SetTop(diagramHeight - subItem:GetHeight())
		local comms_amount = Turbine.UI.Label()
		comms_amount:SetParent(listItem)
		comms_amount:SetText(comms[3])
		comms_amount:SetVisible(false)
		subItem.MouseEnter = function()
			subItem:SetBackColor(AlignedColor)
			self.hopping_comms_month:SetPosition(
				self.barChartComms_panel:GetLeft() + listItem:GetLeft() + listItem:GetWidth() / 2 - self.hopping_comms_month:GetWidth() / 2,
				self.barChartComms_panel:GetTop() + self.barChart_comms2:GetTop() + subItem:GetTop() - self.hopping_comms_month:GetHeight()
			)
			self.hopping_comms_month:SetText(FormatPoints(comms_amount:GetText()))
			self.hopping_comms_month:SetVisible(true)

			self.hopping_comms_month_day_avg:SetPosition(
				self.barChartComms_panel:GetLeft() + listItem:GetLeft() + listItem:GetWidth() / 2 - self.hopping_comms_month_day_avg:GetWidth() / 2,
				self.barChartComms_panel:GetHeight() - self.hopping_comms_month_day_avg:GetHeight() * 3.8
			)
			if comms[1] == L.Months[current_date.Month] then
				self.hopping_comms_month_day_avg:SetText(FormatPoints(math.floor(comms_amount:GetText() / current_date.Day)))
			else
				self.hopping_comms_month_day_avg:SetText(FormatPoints(math.floor(comms_amount:GetText() / GetDaysPerMonth(comms[1], comms[2]))))
			end
			self.hopping_comms_month_day_avg:SetVisible(true)
		end
		subItem.MouseLeave = function()
			subItem:SetBackColor(barChartColor)
			self.hopping_comms_month:SetVisible(false)
			self.hopping_comms_month_day_avg:SetVisible(false)
		end

		local dateItemMonth = Turbine.UI.Label()
		dateItemMonth:SetParent(listItem)
		dateItemMonth:SetSize(listItem:GetWidth(), 12)
		dateItemMonth:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		dateItemMonth:SetFont(Turbine.UI.Lotro.Font.Arial12)
		dateItemMonth:SetText(comms[1])
		dateItemMonth:SetTop(listItem:GetHeight() - dateItemMonth:GetHeight() * 2)

		local dateItemYear = Turbine.UI.Label()
		dateItemYear:SetParent(listItem)
		dateItemYear:SetSize(listItem:GetWidth(), 12)
		dateItemYear:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		dateItemYear:SetFont(Turbine.UI.Lotro.Font.Arial12)
		dateItemYear:SetText(comms[2])
		dateItemYear:SetTop(listItem:GetHeight() - dateItemYear:GetHeight())

		self.barChart_comms2:AddItem(listItem)

		local separator = Turbine.UI.Control()
		separator:SetSize(2, self.barChart_comms2:GetHeight())
		self.barChart_comms2:AddItem(separator)
	end
	self.barChart_comms2:RemoveItemAt(self.barChart_comms2:GetItemCount())

	local topline_comms_value2 = topline_comms_value2
	self.topline_comms2:SetTop(diagramHeight - diagramHeight * topline_comms_value2 / maxValue_comms2)
	self.topline_comms_label2:SetText(FormatPoints(topline_comms_value2))
	self.topline_comms_label2:SetTop(self.topline_comms2:GetTop() - 11)

	local bottomline_comms_value2 = topline_comms_value2 / 2
	self.bottomline_comms2:SetTop(diagramHeight - diagramHeight * bottomline_comms_value2 / maxValue_comms2)
	self.bottomline_comms_label2:SetText(FormatPoints(bottomline_comms_value2))
	self.bottomline_comms_label2:SetTop(self.bottomline_comms2:GetTop() - 11)

	self.barChart_comms2:SetSelectedIndex(self.barChart_comms2:GetItemCount())

	-- Comms Stats
	self.most_comms_day:SetText(L.Maximum_Day..FormatPoints(data.numbers.most_comms_a_day[1]).." ("..
	data.numbers.most_comms_a_day[2].." "..L.Months[data.numbers.most_comms_a_day[3]].." "..data.numbers.most_comms_a_day[4]..")")

	self.most_comms_month:SetText(L.Maximum_Month..FormatPoints(data.numbers.most_comms_a_month[1]).." ("..
	L.Months[data.numbers.most_comms_a_month[2]].." "..data.numbers.most_comms_a_month[3]..")")

	-- Frags Month
	diagramHeight = self.barChart_frags:GetHeight() - 24

	if maxValue_frags - math.floor(maxValue_frags / 10) * 10 > 5 then
		maxValue_frags = math.floor(maxValue_frags / 10) * 10 + 10
	end
	if maxValue_frags < 10 then maxValue_frags = 10 end

	local topline_frags_value = math.floor(maxValue_frags / 10) * 10

	if maxValue_frags < math.floor(maxValue_frags / 10) * 10 + maxValue_frags * 12 / self.barChart_frags:GetHeight() then
		maxValue_frags = maxValue_frags + maxValue_frags * 12 / self.barChart_frags:GetHeight()
	end

	for index,frags in pairs(frags_last_days) do
		local listItem = Turbine.UI.Control()
		listItem:SetSize(self.barChart_frags:GetWidth() / 12.5 - 2, self.barChart_frags:GetHeight())
		local subItem = Turbine.UI.Label()
		subItem:SetParent(listItem)
		subItem:SetBackColor(barChartColor)
		subItem:SetSize(listItem:GetWidth(), diagramHeight * (frags[3] / maxValue_frags))
		subItem:SetTop(diagramHeight - subItem:GetHeight())
		local frags_amount = Turbine.UI.Label()
		frags_amount:SetParent(listItem)
		frags_amount:SetText(frags[3])
		frags_amount:SetVisible(false)
		subItem.MouseEnter = function()
			subItem:SetBackColor(AlignedColor)
			self.hopping_frags_day:SetPosition(
				self.barChartFrags_panel:GetLeft() + listItem:GetLeft() + listItem:GetWidth() / 2 - self.hopping_frags_day:GetWidth() / 2,
				self.barChartFrags_panel:GetTop() + self.barChart_frags:GetTop() + subItem:GetTop() - self.hopping_frags_day:GetHeight()
			)
			self.hopping_frags_day:SetText(frags_amount:GetText())
			self.hopping_frags_day:SetVisible(true)

			local kbPerDeath = Round(frags[3]/deaths_last_days[index][3])
			if deaths_last_days[index][3] == 0 then
				kbPerDeath = Round(frags[3]/1)
			end

			self.frags_per_death:SetText(L.KillingBlows_Per_Death..kbPerDeath.." ("..frags[3].." : "..deaths_last_days[index][3]..")")
			self.frags_per_death:SetVisible(true)
		end
		subItem.MouseLeave = function()
			subItem:SetBackColor(barChartColor)
			self.hopping_frags_day:SetVisible(false)
			
			self.frags_per_death:SetVisible(false)
		end
		local dateItemDay = Turbine.UI.Label()
		dateItemDay:SetParent(listItem)
		dateItemDay:SetSize(listItem:GetWidth(), 12)
		dateItemDay:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		dateItemDay:SetFont(Turbine.UI.Lotro.Font.Arial12)
		dateItemDay:SetText(frags[1])
		dateItemDay:SetTop(listItem:GetHeight() - dateItemDay:GetHeight() * 2)
		local dateItemMonth = Turbine.UI.Label()
		dateItemMonth:SetParent(listItem)
		dateItemMonth:SetSize(listItem:GetWidth(), 12)
		dateItemMonth:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		dateItemMonth:SetFont(Turbine.UI.Lotro.Font.Arial12)
		dateItemMonth:SetText(frags[2])
		dateItemMonth:SetTop(listItem:GetHeight() - dateItemMonth:GetHeight())

		self.barChart_frags:AddItem(listItem)

		local separator = Turbine.UI.Control()
		separator:SetSize(2, self.barChart_frags:GetHeight())
		self.barChart_frags:AddItem(separator)
	end
	self.barChart_frags:RemoveItemAt(self.barChart_frags:GetItemCount())

	local topline_frags_value = topline_frags_value
	self.topline_frags:SetTop(diagramHeight - diagramHeight * topline_frags_value / maxValue_frags)
	self.topline_frags_label:SetText(topline_frags_value)
	self.topline_frags_label:SetTop(self.topline_frags:GetTop() - 11)

	local bottomline_frags_value = topline_frags_value / 2
	self.bottomline_frags:SetTop(diagramHeight - diagramHeight * bottomline_frags_value / maxValue_frags)
	self.bottomline_frags_label:SetText(bottomline_frags_value)
	self.bottomline_frags_label:SetTop(self.bottomline_frags:GetTop() - 11)

	self.barChart_frags:SetSelectedIndex(self.barChart_frags:GetItemCount())

	-- Frags Year
	local diagramHeight = self.barChart_frags2:GetHeight() - 24

	if maxValue_frags2 - math.floor(maxValue_frags2 / 100) * 100 > 50 then
		maxValue_frags2 = math.floor(maxValue_frags2 / 100) * 100 + 100
	end
	if maxValue_frags2 < 100 then maxValue_frags2 = 100 end

	local topline_frags_value2 = math.floor(maxValue_frags2 / 100) * 100

	if maxValue_frags2 < math.floor(maxValue_frags2 / 100) * 100 + maxValue_frags2 * 12 / self.barChart_frags2:GetHeight() then
		maxValue_frags2 = maxValue_frags2 + maxValue_frags2 * 12 / self.barChart_frags2:GetHeight()
	end

	for index,frags in pairs(frags_last_months) do
		local listItem = Turbine.UI.Control()
		listItem:SetSize(self.barChart_frags2:GetWidth() / 11.5 - 2, self.barChart_frags2:GetHeight())
		local subItem = Turbine.UI.Label()
		subItem:SetParent(listItem)
		subItem:SetBackColor(barChartColor)
		subItem:SetSize(listItem:GetWidth(), diagramHeight * (frags[3] / maxValue_frags2))
		subItem:SetTop(diagramHeight - subItem:GetHeight())
		local frags_amount = Turbine.UI.Label()
		frags_amount:SetParent(listItem)
		frags_amount:SetText(frags[3])
		frags_amount:SetVisible(false)
		subItem.MouseEnter = function()
			subItem:SetBackColor(AlignedColor)
			self.hopping_frags_month:SetPosition(
				self.barChartFrags_panel:GetLeft() + listItem:GetLeft() + listItem:GetWidth() / 2 - self.hopping_frags_month:GetWidth() / 2,
				self.barChartFrags_panel:GetTop() + self.barChart_frags2:GetTop() + subItem:GetTop() - self.hopping_frags_month:GetHeight()
			)
			self.hopping_frags_month:SetText(FormatPoints(frags_amount:GetText()))
			self.hopping_frags_month:SetVisible(true)

			self.hopping_frags_month_day_avg:SetPosition(
				self.barChartFrags_panel:GetLeft() + listItem:GetLeft() + listItem:GetWidth() / 2 - self.hopping_frags_month_day_avg:GetWidth() / 2,
				self.barChartFrags_panel:GetHeight() - self.hopping_frags_month_day_avg:GetHeight() * 3.8
			)
			if frags[1] == L.Months[current_date.Month] then
				self.hopping_frags_month_day_avg:SetText(Round(frags_amount:GetText() / current_date.Day))
			else
				self.hopping_frags_month_day_avg:SetText(Round(frags_amount:GetText() / GetDaysPerMonth(frags[1], frags[2])))
			end
			self.hopping_frags_month_day_avg:SetVisible(true)

			local kbPerDeath = Round(frags[3]/deaths_last_months[index][3])
			if deaths_last_months[index][3] == 0 then
				kbPerDeath = Round(frags[3]/1)
			end

			self.frags_per_death:SetText(L.KillingBlows_Per_Death..kbPerDeath.." ("..frags[3].." : "..deaths_last_months[index][3]..")")
			self.frags_per_death:SetVisible(true)
		end
		subItem.MouseLeave = function()
			subItem:SetBackColor(barChartColor)
			self.hopping_frags_month:SetVisible(false)
			self.hopping_frags_month_day_avg:SetVisible(false)
			
			self.frags_per_death:SetVisible(false)
		end

		local dateItemMonth = Turbine.UI.Label()
		dateItemMonth:SetParent(listItem)
		dateItemMonth:SetSize(listItem:GetWidth(), 12)
		dateItemMonth:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		dateItemMonth:SetFont(Turbine.UI.Lotro.Font.Arial12)
		dateItemMonth:SetText(frags[1])
		dateItemMonth:SetTop(listItem:GetHeight() - dateItemMonth:GetHeight() * 2)

		local dateItemYear = Turbine.UI.Label()
		dateItemYear:SetParent(listItem)
		dateItemYear:SetSize(listItem:GetWidth(), 12)
		dateItemYear:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		dateItemYear:SetFont(Turbine.UI.Lotro.Font.Arial12)
		dateItemYear:SetText(frags[2])
		dateItemYear:SetTop(listItem:GetHeight() - dateItemYear:GetHeight())

		self.barChart_frags2:AddItem(listItem)

		local separator = Turbine.UI.Control()
		separator:SetSize(2, self.barChart_frags2:GetHeight())
		self.barChart_frags2:AddItem(separator)
	end
	self.barChart_frags2:RemoveItemAt(self.barChart_frags2:GetItemCount())

	local topline_frags_value2 = topline_frags_value2
	self.topline_frags2:SetTop(diagramHeight - diagramHeight * topline_frags_value2 / maxValue_frags2)
	self.topline_frags_label2:SetText(FormatPoints(topline_frags_value2))
	self.topline_frags_label2:SetTop(self.topline_frags2:GetTop() - 11)

	local bottomline_frags_value2 = topline_frags_value2 / 2
	self.bottomline_frags2:SetTop(diagramHeight - diagramHeight * bottomline_frags_value2 / maxValue_frags2)
	self.bottomline_frags_label2:SetText(FormatPoints(bottomline_frags_value2))
	self.bottomline_frags_label2:SetTop(self.bottomline_frags2:GetTop() - 11)

	self.barChart_frags2:SetSelectedIndex(self.barChart_frags2:GetItemCount())

	-- Frags Stats
	self.most_frags_day:SetText(L.Maximum_Day..data.numbers.most_frags_a_day[1].." ("..
	data.numbers.most_frags_a_day[2].." "..L.Months[data.numbers.most_frags_a_day[3]].." "..data.numbers.most_frags_a_day[4]..")")

	self.most_frags_month:SetText(L.Maximum_Month..FormatPoints(data.numbers.most_frags_a_month[1]).." ("..
	L.Months[data.numbers.most_frags_a_month[2]].." "..data.numbers.most_frags_a_month[3]..")")

	-- Deaths Month
	diagramHeight = self.barChart_deaths:GetHeight() - 24

	if maxValue_deaths - math.floor(maxValue_deaths / 10) * 10 > 5 then
		maxValue_deaths = math.floor(maxValue_deaths / 10) * 10 + 10
	end
	if maxValue_deaths < 10 then maxValue_deaths = 10 end

	local topline_deaths_value = math.floor(maxValue_deaths / 10) * 10

	if maxValue_deaths < math.floor(maxValue_deaths / 10) * 10 + maxValue_deaths * 12 / self.barChart_deaths:GetHeight() then
		maxValue_deaths = maxValue_deaths + maxValue_deaths * 12 / self.barChart_deaths:GetHeight()
	end

	for index,deaths in pairs(deaths_last_days) do
		local listItem = Turbine.UI.Control()
		listItem:SetSize(self.barChart_deaths:GetWidth() / 12.5 - 2, self.barChart_deaths:GetHeight())
		local subItem = Turbine.UI.Label()
		subItem:SetParent(listItem)
		subItem:SetBackColor(barChartColor)
		subItem:SetSize(listItem:GetWidth(), diagramHeight * (deaths[3] / maxValue_deaths))
		subItem:SetTop(diagramHeight - subItem:GetHeight())
		local deaths_amount = Turbine.UI.Label()
		deaths_amount:SetParent(listItem)
		deaths_amount:SetText(deaths[3])
		deaths_amount:SetVisible(false)
		subItem.MouseEnter = function()
			subItem:SetBackColor(AlignedColor)
			self.hopping_deaths_day:SetPosition(
				self.barChartDeaths_panel:GetLeft() + listItem:GetLeft() + listItem:GetWidth() / 2 - self.hopping_deaths_day:GetWidth() / 2,
				self.barChartDeaths_panel:GetTop() + self.barChart_deaths:GetTop() + subItem:GetTop() - self.hopping_deaths_day:GetHeight()
			)
			self.hopping_deaths_day:SetText(deaths_amount:GetText())
			self.hopping_deaths_day:SetVisible(true)
		end
		subItem.MouseLeave = function()
			subItem:SetBackColor(barChartColor)
			self.hopping_deaths_day:SetVisible(false)
		end
		local dateItemDay = Turbine.UI.Label()
		dateItemDay:SetParent(listItem)
		dateItemDay:SetSize(listItem:GetWidth(), 12)
		dateItemDay:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		dateItemDay:SetFont(Turbine.UI.Lotro.Font.Arial12)
		dateItemDay:SetText(deaths[1])
		dateItemDay:SetTop(listItem:GetHeight() - dateItemDay:GetHeight() * 2)
		local dateItemMonth = Turbine.UI.Label()
		dateItemMonth:SetParent(listItem)
		dateItemMonth:SetSize(listItem:GetWidth(), 12)
		dateItemMonth:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		dateItemMonth:SetFont(Turbine.UI.Lotro.Font.Arial12)
		dateItemMonth:SetText(deaths[2])
		dateItemMonth:SetTop(listItem:GetHeight() - dateItemMonth:GetHeight())

		self.barChart_deaths:AddItem(listItem)

		local separator = Turbine.UI.Control()
		separator:SetSize(2, self.barChart_deaths:GetHeight())
		self.barChart_deaths:AddItem(separator)
	end
	self.barChart_deaths:RemoveItemAt(self.barChart_deaths:GetItemCount())

	local topline_deaths_value = topline_deaths_value
	self.topline_deaths:SetTop(diagramHeight - diagramHeight * topline_deaths_value / maxValue_deaths)
	self.topline_deaths_label:SetText(topline_deaths_value)
	self.topline_deaths_label:SetTop(self.topline_deaths:GetTop() - 11)

	local bottomline_deaths_value = topline_deaths_value / 2
	self.bottomline_deaths:SetTop(diagramHeight - diagramHeight * bottomline_deaths_value / maxValue_deaths)
	self.bottomline_deaths_label:SetText(bottomline_deaths_value)
	self.bottomline_deaths_label:SetTop(self.bottomline_deaths:GetTop() - 11)

	self.barChart_deaths:SetSelectedIndex(self.barChart_deaths:GetItemCount())

	-- Deaths Year
	local diagramHeight = self.barChart_deaths2:GetHeight() - 24

	if maxValue_deaths2 - math.floor(maxValue_deaths2 / 100) * 100 > 50 then
		maxValue_deaths2 = math.floor(maxValue_deaths2 / 100) * 100 + 100
	end
	if maxValue_deaths2 < 100 then maxValue_deaths2 = 100 end

	local topline_deaths_value2 = math.floor(maxValue_deaths2 / 100) * 100

	if maxValue_deaths2 < math.floor(maxValue_deaths2 / 100) * 100 + maxValue_deaths2 * 12 / self.barChart_deaths2:GetHeight() then
		maxValue_deaths2 = maxValue_deaths2 + maxValue_deaths2 * 12 / self.barChart_deaths2:GetHeight()
	end

	for index,deaths in pairs(deaths_last_months) do
		local listItem = Turbine.UI.Control()
		listItem:SetSize(self.barChart_deaths2:GetWidth() / 11.5 - 2, self.barChart_deaths2:GetHeight())
		local subItem = Turbine.UI.Label()
		subItem:SetParent(listItem)
		subItem:SetBackColor(barChartColor)
		subItem:SetSize(listItem:GetWidth(), diagramHeight * (deaths[3] / maxValue_deaths2))
		subItem:SetTop(diagramHeight - subItem:GetHeight())
		local deaths_amount = Turbine.UI.Label()
		deaths_amount:SetParent(listItem)
		deaths_amount:SetText(deaths[3])
		deaths_amount:SetVisible(false)
		subItem.MouseEnter = function()
			subItem:SetBackColor(AlignedColor)
			self.hopping_deaths_month:SetPosition(
				self.barChartDeaths_panel:GetLeft() + listItem:GetLeft() + listItem:GetWidth() / 2 - self.hopping_deaths_month:GetWidth() / 2,
				self.barChartDeaths_panel:GetTop() + self.barChart_deaths2:GetTop() + subItem:GetTop() - self.hopping_deaths_month:GetHeight()
			)
			self.hopping_deaths_month:SetText(FormatPoints(deaths_amount:GetText()))
			self.hopping_deaths_month:SetVisible(true)

			self.hopping_deaths_month_day_avg:SetPosition(
				self.barChartDeaths_panel:GetLeft() + listItem:GetLeft() + listItem:GetWidth() / 2 - self.hopping_deaths_month_day_avg:GetWidth() / 2,
				self.barChartDeaths_panel:GetHeight() - self.hopping_deaths_month_day_avg:GetHeight() * 3.8
			)
			if deaths[1] == L.Months[current_date.Month] then
				self.hopping_deaths_month_day_avg:SetText(Round(deaths_amount:GetText() / current_date.Day))
			else
				self.hopping_deaths_month_day_avg:SetText(Round(deaths_amount:GetText() / GetDaysPerMonth(deaths[1], deaths[2])))
			end
			self.hopping_deaths_month_day_avg:SetVisible(true)
		end
		subItem.MouseLeave = function()
			subItem:SetBackColor(barChartColor)
			self.hopping_deaths_month:SetVisible(false)
			self.hopping_deaths_month_day_avg:SetVisible(false)
		end

		local dateItemMonth = Turbine.UI.Label()
		dateItemMonth:SetParent(listItem)
		dateItemMonth:SetSize(listItem:GetWidth(), 12)
		dateItemMonth:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		dateItemMonth:SetFont(Turbine.UI.Lotro.Font.Arial12)
		dateItemMonth:SetText(deaths[1])
		dateItemMonth:SetTop(listItem:GetHeight() - dateItemMonth:GetHeight() * 2)

		local dateItemYear = Turbine.UI.Label()
		dateItemYear:SetParent(listItem)
		dateItemYear:SetSize(listItem:GetWidth(), 12)
		dateItemYear:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		dateItemYear:SetFont(Turbine.UI.Lotro.Font.Arial12)
		dateItemYear:SetText(deaths[2])
		dateItemYear:SetTop(listItem:GetHeight() - dateItemYear:GetHeight())

		self.barChart_deaths2:AddItem(listItem)

		local separator = Turbine.UI.Control()
		separator:SetSize(2, self.barChart_deaths2:GetHeight())
		self.barChart_deaths2:AddItem(separator)
	end
	self.barChart_deaths2:RemoveItemAt(self.barChart_deaths2:GetItemCount())

	local topline_deaths_value2 = topline_deaths_value2
	self.topline_deaths2:SetTop(diagramHeight - diagramHeight * topline_deaths_value2 / maxValue_deaths2)
	self.topline_deaths_label2:SetText(FormatPoints(topline_deaths_value2))
	self.topline_deaths_label2:SetTop(self.topline_deaths2:GetTop() - 11)

	local bottomline_deaths_value2 = topline_deaths_value2 / 2
	self.bottomline_deaths2:SetTop(diagramHeight - diagramHeight * bottomline_deaths_value2 / maxValue_deaths2)
	self.bottomline_deaths_label2:SetText(FormatPoints(bottomline_deaths_value2))
	self.bottomline_deaths_label2:SetTop(self.bottomline_deaths2:GetTop() - 11)

	self.barChart_deaths2:SetSelectedIndex(self.barChart_deaths2:GetItemCount())

	-- Deaths Stats
	self.most_deaths_day:SetText(L.Maximum_Day..data.numbers.most_deaths_a_day[1].." ("..
	data.numbers.most_deaths_a_day[2].." "..L.Months[data.numbers.most_deaths_a_day[3]].." "..data.numbers.most_deaths_a_day[4]..")")

	self.most_deaths_month:SetText(L.Maximum_Month..FormatPoints(data.numbers.most_deaths_a_month[1]).." ("..
	L.Months[data.numbers.most_deaths_a_month[2]].." "..data.numbers.most_deaths_a_month[3]..")")

	-- Tracks Month
	diagramHeight = self.barChart_tracks:GetHeight() - 24

	if maxValue_tracks - math.floor(maxValue_tracks / 10) * 10 > 5 then
		maxValue_tracks = math.floor(maxValue_tracks / 10) * 10 + 10
	end
	if maxValue_tracks < 10 then maxValue_tracks = 10 end

	local topline_tracks_value = math.floor(maxValue_tracks / 10) * 10

	if maxValue_tracks < math.floor(maxValue_tracks / 10) * 10 + maxValue_tracks * 12 / self.barChart_tracks:GetHeight() then
		maxValue_tracks = maxValue_tracks + maxValue_tracks * 12 / self.barChart_tracks:GetHeight()
	end

	for index,tracks in pairs(tracks_last_days) do
		local listItem = Turbine.UI.Control()
		listItem:SetSize(self.barChart_tracks:GetWidth() / 12.5 - 2, self.barChart_tracks:GetHeight())
		local subItem = Turbine.UI.Label()
		subItem:SetParent(listItem)
		subItem:SetBackColor(barChartColor)
		subItem:SetSize(listItem:GetWidth(), diagramHeight * (tracks[3] / maxValue_tracks))
		subItem:SetTop(diagramHeight - subItem:GetHeight())
		local tracks_amount = Turbine.UI.Label()
		tracks_amount:SetParent(listItem)
		tracks_amount:SetText(tracks[3])
		tracks_amount:SetVisible(false)
		subItem.MouseEnter = function()
			subItem:SetBackColor(AlignedColor)
			self.hopping_tracks_day:SetPosition(
				self.barChartTracks_panel:GetLeft() + listItem:GetLeft() + listItem:GetWidth() / 2 - self.hopping_tracks_day:GetWidth() / 2,
				self.barChartTracks_panel:GetTop() + self.barChart_tracks:GetTop() + subItem:GetTop() - self.hopping_tracks_day:GetHeight()
			)
			self.hopping_tracks_day:SetText(tracks_amount:GetText())
			self.hopping_tracks_day:SetVisible(true)
		end
		subItem.MouseLeave = function()
			subItem:SetBackColor(barChartColor)
			self.hopping_tracks_day:SetVisible(false)
		end
		local dateItemDay = Turbine.UI.Label()
		dateItemDay:SetParent(listItem)
		dateItemDay:SetSize(listItem:GetWidth(), 12)
		dateItemDay:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		dateItemDay:SetFont(Turbine.UI.Lotro.Font.Arial12)
		dateItemDay:SetText(tracks[1])
		dateItemDay:SetTop(listItem:GetHeight() - dateItemDay:GetHeight() * 2)
		local dateItemMonth = Turbine.UI.Label()
		dateItemMonth:SetParent(listItem)
		dateItemMonth:SetSize(listItem:GetWidth(), 12)
		dateItemMonth:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		dateItemMonth:SetFont(Turbine.UI.Lotro.Font.Arial12)
		dateItemMonth:SetText(tracks[2])
		dateItemMonth:SetTop(listItem:GetHeight() - dateItemMonth:GetHeight())

		self.barChart_tracks:AddItem(listItem)

		local separator = Turbine.UI.Control()
		separator:SetSize(2, self.barChart_tracks:GetHeight())
		self.barChart_tracks:AddItem(separator)
	end
	self.barChart_tracks:RemoveItemAt(self.barChart_tracks:GetItemCount())

	local topline_tracks_value = topline_tracks_value
	self.topline_tracks:SetTop(diagramHeight - diagramHeight * topline_tracks_value / maxValue_tracks)
	self.topline_tracks_label:SetText(topline_tracks_value)
	self.topline_tracks_label:SetTop(self.topline_tracks:GetTop() - 11)

	local bottomline_tracks_value = topline_tracks_value / 2
	self.bottomline_tracks:SetTop(diagramHeight - diagramHeight * bottomline_tracks_value / maxValue_tracks)
	self.bottomline_tracks_label:SetText(bottomline_tracks_value)
	self.bottomline_tracks_label:SetTop(self.bottomline_tracks:GetTop() - 11)

	self.barChart_tracks:SetSelectedIndex(self.barChart_tracks:GetItemCount())

	-- Tracks Year
	local diagramHeight = self.barChart_tracks2:GetHeight() - 24

	if maxValue_tracks2 - math.floor(maxValue_tracks2 / 100) * 100 > 50 then
		maxValue_tracks2 = math.floor(maxValue_tracks2 / 100) * 100 + 100
	end
	if maxValue_tracks2 < 100 then maxValue_tracks2 = 100 end

	local topline_tracks_value2 = math.floor(maxValue_tracks2 / 100) * 100

	if maxValue_tracks2 < math.floor(maxValue_tracks2 / 100) * 100 + maxValue_tracks2 * 12 / self.barChart_tracks2:GetHeight() then
		maxValue_tracks2 = maxValue_tracks2 + maxValue_tracks2 * 12 / self.barChart_tracks2:GetHeight()
	end

	for index,tracks in pairs(tracks_last_months) do
		local listItem = Turbine.UI.Control()
		listItem:SetSize(self.barChart_tracks2:GetWidth() / 11.5 - 2, self.barChart_tracks2:GetHeight())
		local subItem = Turbine.UI.Label()
		subItem:SetParent(listItem)
		subItem:SetBackColor(barChartColor)
		subItem:SetSize(listItem:GetWidth(), diagramHeight * (tracks[3] / maxValue_tracks2))
		subItem:SetTop(diagramHeight - subItem:GetHeight())
		local tracks_amount = Turbine.UI.Label()
		tracks_amount:SetParent(listItem)
		tracks_amount:SetText(tracks[3])
		tracks_amount:SetVisible(false)
		subItem.MouseEnter = function()
			subItem:SetBackColor(AlignedColor)
			self.hopping_tracks_month:SetPosition(
				self.barChartTracks_panel:GetLeft() + listItem:GetLeft() + listItem:GetWidth() / 2 - self.hopping_tracks_month:GetWidth() / 2,
				self.barChartTracks_panel:GetTop() + self.barChart_tracks2:GetTop() + subItem:GetTop() - self.hopping_tracks_month:GetHeight()
			)
			self.hopping_tracks_month:SetText(FormatPoints(tracks_amount:GetText()))
			self.hopping_tracks_month:SetVisible(true)

			self.hopping_tracks_month_day_avg:SetPosition(
				self.barChartTracks_panel:GetLeft() + listItem:GetLeft() + listItem:GetWidth() / 2 - self.hopping_tracks_month_day_avg:GetWidth() / 2,
				self.barChartTracks_panel:GetHeight() - self.hopping_tracks_month_day_avg:GetHeight() * 3.8
			)
			if tracks[1] == L.Months[current_date.Month] then
				self.hopping_tracks_month_day_avg:SetText(Round(tracks_amount:GetText() / current_date.Day))
			else
				self.hopping_tracks_month_day_avg:SetText(Round(tracks_amount:GetText() / GetDaysPerMonth(tracks[1], tracks[2])))
			end
			self.hopping_tracks_month_day_avg:SetVisible(true)
		end
		subItem.MouseLeave = function()
			subItem:SetBackColor(barChartColor)
			self.hopping_tracks_month:SetVisible(false)
			self.hopping_tracks_month_day_avg:SetVisible(false)
		end

		local dateItemMonth = Turbine.UI.Label()
		dateItemMonth:SetParent(listItem)
		dateItemMonth:SetSize(listItem:GetWidth(), 12)
		dateItemMonth:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		dateItemMonth:SetFont(Turbine.UI.Lotro.Font.Arial12)
		dateItemMonth:SetText(tracks[1])
		dateItemMonth:SetTop(listItem:GetHeight() - dateItemMonth:GetHeight() * 2)

		local dateItemYear = Turbine.UI.Label()
		dateItemYear:SetParent(listItem)
		dateItemYear:SetSize(listItem:GetWidth(), 12)
		dateItemYear:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		dateItemYear:SetFont(Turbine.UI.Lotro.Font.Arial12)
		dateItemYear:SetText(tracks[2])
		dateItemYear:SetTop(listItem:GetHeight() - dateItemYear:GetHeight())

		self.barChart_tracks2:AddItem(listItem)

		local separator = Turbine.UI.Control()
		separator:SetSize(2, self.barChart_tracks2:GetHeight())
		self.barChart_tracks2:AddItem(separator)
	end
	self.barChart_tracks2:RemoveItemAt(self.barChart_tracks2:GetItemCount())

	local topline_tracks_value2 = topline_tracks_value2
	self.topline_tracks2:SetTop(diagramHeight - diagramHeight * topline_tracks_value2 / maxValue_tracks2)
	self.topline_tracks_label2:SetText(FormatPoints(topline_tracks_value2))
	self.topline_tracks_label2:SetTop(self.topline_tracks2:GetTop() - 11)

	local bottomline_tracks_value2 = topline_tracks_value2 / 2
	self.bottomline_tracks2:SetTop(diagramHeight - diagramHeight * bottomline_tracks_value2 / maxValue_tracks2)
	self.bottomline_tracks_label2:SetText(FormatPoints(bottomline_tracks_value2))
	self.bottomline_tracks_label2:SetTop(self.bottomline_tracks2:GetTop() - 11)

	self.barChart_tracks2:SetSelectedIndex(self.barChart_tracks2:GetItemCount())

	-- Tracks Stats
	self.most_tracks_day:SetText(L.Maximum_Day..data.numbers.most_tracks_a_day[1].." ("..
	data.numbers.most_tracks_a_day[2].." "..L.Months[data.numbers.most_tracks_a_day[3]].." "..data.numbers.most_tracks_a_day[4]..")")

	self.most_tracks_month:SetText(L.Maximum_Month..FormatPoints(data.numbers.most_tracks_a_month[1]).." ("..
	L.Months[data.numbers.most_tracks_a_month[2]].." "..data.numbers.most_tracks_a_month[3]..")")
end

function StatsWindow:ShowTab(tab)
	self.stats_panel:SetVisible(false)
	self.frag_panel:SetVisible(false)
	self.barChartPoints_panel:SetVisible(false)
	self.barChartComms_panel:SetVisible(false)
	self.barChartFrags_panel:SetVisible(false)
	self.barChartDeaths_panel:SetVisible(false)
	self.barChartTracks_panel:SetVisible(false)

	if tab == self.tab_stats.index then
		self:UpdateStatsPanel()
		self.stats_panel:SetVisible(true)
	elseif tab == self.tab_killList.index then
		self.search_box:SetText("")
		self:UpdateFragList(kills_desc)
		self.frag_panel:SetVisible(true)
	elseif tab == self.tab_barChartPoints.index then
		self:UpdateBarCharts()
		self.barChartPoints_panel:SetVisible(true)
	elseif tab == self.tab_barChartComms.index then
		self:UpdateBarCharts()
		self.barChartComms_panel:SetVisible(true)
	elseif tab == self.tab_barChartFrags.index then
		self:UpdateBarCharts()
		self.barChartFrags_panel:SetVisible(true)
	elseif tab == self.tab_barChartDeaths.index then
		self:UpdateBarCharts()
		self.barChartDeaths_panel:SetVisible(true)
	elseif tab == self.tab_barChartTracks.index then
		self:UpdateBarCharts()
		self.barChartTracks_panel:SetVisible(true)
	end
end